/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

GtkWidget*
create_main_window (void)
{
  GtkWidget *main_window;
  GdkPixbuf *main_window_icon_pixbuf;
  GtkWidget *vbox1;
  GtkWidget *menubar1;
  GtkWidget *menu_file;
  GtkWidget *menu_file_menu;
  GtkWidget *menu_new;
  GtkWidget *menu_open;
  GtkWidget *menu_load_last_save;
  GtkWidget *image2725;
  GtkWidget *menu_save;
  GtkWidget *menu_save_as;
  GtkWidget *trennlinie1;
  GtkWidget *menu_quit;
  GtkWidget *menu_options;
  GtkWidget *menu_options_menu;
  GtkWidget *menu_preferences;
  GtkWidget *image2726;
  GtkWidget *trennlinie7;
  GtkWidget *menu_job_offers;
  GtkWidget *menu_live_game;
  GtkWidget *menu_overwrite;
  GtkWidget *trennlinie14;
  GtkWidget *menu_save_window_geometry;
  GtkWidget *image2727;
  GtkWidget *menu_figures;
  GtkWidget *menu_figures_menu;
  GtkWidget *menu_fixtures_week;
  GtkWidget *image2728;
  GtkWidget *menu_fixtures;
  GtkWidget *image2729;
  GtkWidget *menu_tables;
  GtkWidget *image2730;
  GtkWidget *menu_my_league_results;
  GtkWidget *image2731;
  GtkWidget *menu_season_results;
  GtkWidget *image2732;
  GtkWidget *menu_team;
  GtkWidget *menu_team_menu;
  GtkWidget *menu_playing_style;
  GtkWidget *image2733;
  GtkWidget *menu_playing_style_menu;
  GSList *menu_all_out_defend_group = NULL;
  GtkWidget *menu_all_out_defend;
  GtkWidget *menu_defend;
  GtkWidget *menu_balanced;
  GtkWidget *menu_attack;
  GtkWidget *menu_all_out_attack;
  GtkWidget *menu_scout;
  GtkWidget *image2734;
  GtkWidget *menu_scout_menu;
  GSList *menu_scout_best_group = NULL;
  GtkWidget *menu_scout_best;
  GtkWidget *menu_scout_good;
  GtkWidget *menu_scout_average;
  GtkWidget *menu_scout_bad;
  GtkWidget *menu_physio;
  GtkWidget *image2735;
  GtkWidget *menu_physio_menu;
  GSList *menu_physio_best_group = NULL;
  GtkWidget *menu_physio_best;
  GtkWidget *menu_physio_good;
  GtkWidget *menu_physio_average;
  GtkWidget *menu_physio_bad;
  GtkWidget *menu_youth_academy;
  GtkWidget *image2736;
  GtkWidget *menu_youth_academy_menu;
  GtkWidget *menu_show_youth_academy;
  GtkWidget *youth_coach1;
  GtkWidget *youth_coach1_menu;
  GSList *menu_yc_best_group = NULL;
  GtkWidget *menu_yc_best;
  GtkWidget *menu_yc_good;
  GtkWidget *menu_yc_average;
  GtkWidget *menu_yc_bad;
  GtkWidget *recruiting_preference1;
  GtkWidget *recruiting_preference1_menu;
  GSList *menu_recruit0_group = NULL;
  GtkWidget *menu_recruit0;
  GtkWidget *menu_recruit1;
  GtkWidget *menu_recruit2;
  GtkWidget *menu_recruit3;
  GtkWidget *menu_recruit4;
  GtkWidget *menu_set_investment;
  GtkWidget *menu_boost;
  GtkWidget *image2737;
  GtkWidget *menu_boost_menu;
  GSList *menu_boost_on_group = NULL;
  GtkWidget *menu_boost_on;
  GtkWidget *menu_boost_off;
  GtkWidget *menu_boost_anti;
  GtkWidget *trennlinie11;
  GtkWidget *menu_training_camp;
  GtkWidget *trennlinie18;
  GtkWidget *menu_reset_players;
  GtkWidget *image2738;
  GtkWidget *menu_custom_structure;
  GtkWidget *image2739;
  GtkWidget *menu_rearrange_team;
  GtkWidget *image2740;
  GtkWidget *trennlinie8;
  GtkWidget *menu_browse_teams;
  GtkWidget *image2741;
  GtkWidget *trennlinie16;
  GtkWidget *menu_show_job_exchange;
  GtkWidget *menu_player;
  GtkWidget *menu_player_menu;
  GtkWidget *menu_show_info;
  GtkWidget *image2742;
  GtkWidget *menu_put_on_transfer_list;
  GtkWidget *image2743;
  GtkWidget *menu_remove_from_transfer_list;
  GtkWidget *image2744;
  GtkWidget *menu_offer_new_contract;
  GtkWidget *image2745;
  GtkWidget *menu_fire;
  GtkWidget *image2746;
  GtkWidget *menu_shoots_penalties;
  GtkWidget *image2747;
  GtkWidget *menu_move_to_youth_academy;
  GtkWidget *image2748;
  GtkWidget *menu_edit_name;
  GtkWidget *image2749;
  GtkWidget *trennlinie10;
  GtkWidget *menu_browse_players;
  GtkWidget *image2750;
  GtkWidget *menu_user;
  GtkWidget *menu_user_menu;
  GtkWidget *menu_user_show_last_match;
  GtkWidget *image2751;
  GtkWidget *menu_user_show_last_stats;
  GtkWidget *image2752;
  GtkWidget *menu_user_show_coming_matches;
  GtkWidget *image2753;
  GtkWidget *trennlinie9;
  GtkWidget *menu_next_user;
  GtkWidget *image2754;
  GtkWidget *menu_previous_user;
  GtkWidget *image2755;
  GtkWidget *menu_manage_users;
  GtkWidget *image2756;
  GtkWidget *menu_finances_stadium;
  GtkWidget *menu_finances_stadium_menu;
  GtkWidget *menu_show_finances;
  GtkWidget *image2757;
  GtkWidget *menu_show_stadium;
  GtkWidget *image2758;
  GtkWidget *automatic_loan_repayment;
  GtkWidget *trennlinie15;
  GtkWidget *menu_betting;
  GtkWidget *stats1;
  GtkWidget *stats1_menu;
  GtkWidget *menu_news;
  GtkWidget *menu_league_stats;
  GtkWidget *image2759;
  GtkWidget *menu_season_history;
  GtkWidget *image2760;
  GtkWidget *menu_user_show_history;
  GtkWidget *image2761;
  GtkWidget *memorable_matches;
  GtkWidget *image2762;
  GtkWidget *memorable_matches_menu;
  GtkWidget *mm_add_last_match;
  GtkWidget *image2763;
  GtkWidget *mm_manage_matches;
  GtkWidget *image2764;
  GtkWidget *menu_help1;
  GtkWidget *menu_help1_menu;
  GtkWidget *menu_about;
  GtkWidget *image2765;
  GtkWidget *menu_contributors;
  GtkWidget *image2766;
  GtkWidget *menu_help;
  GtkWidget *image2767;
  GtkWidget *hbox1;
  GtkWidget *button_load;
  GtkWidget *image11;
  GtkWidget *button_save;
  GtkWidget *image12;
  GtkWidget *button_quit;
  GtkWidget *image13;
  GtkWidget *vseparator1;
  GtkWidget *vseparator11;
  GtkWidget *button_back_to_main;
  GtkWidget *image20;
  GtkWidget *button_transfers;
  GtkWidget *image32;
  GtkWidget *vseparator16;
  GtkWidget *button_new_week;
  GtkWidget *image23;
  GtkWidget *entry_message;
  GtkWidget *hseparator1;
  GtkWidget *eventbox_main_info;
  GtkWidget *hbox18;
  GtkWidget *label_user;
  GtkWidget *label23;
  GtkWidget *label_season;
  GtkWidget *label25;
  GtkWidget *label_week;
  GtkWidget *label13114;
  GtkWidget *label_round;
  GtkWidget *vseparator14;
  GtkWidget *hbox48;
  GtkWidget *eventbox_style;
  GtkWidget *image_style;
  GtkWidget *eventbox_boost;
  GtkWidget *image_boost;
  GtkWidget *eventbox_team_name;
  GtkWidget *label_team;
  GtkWidget *label_league;
  GtkWidget *eventbox_rank;
  GtkWidget *hbox49;
  GtkWidget *label29;
  GtkWidget *label_rank;
  GtkWidget *vseparator15;
  GtkWidget *label34;
  GtkWidget *label_money;
  GtkWidget *vseparator17;
  GtkWidget *eventbox1;
  GtkWidget *hbox50;
  GtkWidget *label69;
  GtkWidget *label_av_skills;
  GtkWidget *hbox7;
  GtkWidget *hpaned2;
  GtkWidget *vbox3;
  GtkWidget *scrolledwindow2;
  GtkWidget *viewport1;
  GtkWidget *notebook_player;
  GtkWidget *player_list1;
  GtkWidget *label71;
  GtkWidget *player_list2;
  GtkWidget *label72;
  GtkWidget *button_reset_players;
  GtkWidget *image298;
  GtkWidget *vbox8;
  GtkWidget *hbox_14;
  GtkWidget *button_cl_back;
  GtkWidget *image215;
  GtkWidget *button_cl_forward;
  GtkWidget *image216;
  GtkWidget *button_browse_back;
  GtkWidget *image10;
  GtkWidget *button_browse_forward;
  GtkWidget *image9;
  GtkWidget *scrolledwindow3;
  GtkWidget *treeview_right;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (main_window), 6);
  gtk_window_set_position (GTK_WINDOW (main_window), GTK_WIN_POS_CENTER);
  gtk_window_set_default_size (GTK_WINDOW (main_window), 300, 600);
  main_window_icon_pixbuf = create_pixbuf ("bygfoot_icon.png");
  if (main_window_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (main_window), main_window_icon_pixbuf);
      gdk_pixbuf_unref (main_window_icon_pixbuf);
    }

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (main_window), vbox1);

  menubar1 = gtk_menu_bar_new ();
  gtk_widget_show (menubar1);
  gtk_box_pack_start (GTK_BOX (vbox1), menubar1, FALSE, FALSE, 0);

  menu_file = gtk_menu_item_new_with_mnemonic (_("_File"));
  gtk_widget_show (menu_file);
  gtk_container_add (GTK_CONTAINER (menubar1), menu_file);

  menu_file_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_file), menu_file_menu);

  menu_new = gtk_image_menu_item_new_from_stock ("gtk-new", accel_group);
  gtk_widget_show (menu_new);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_new);

  menu_open = gtk_image_menu_item_new_from_stock ("gtk-open", accel_group);
  gtk_widget_show (menu_open);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_open);

  menu_load_last_save = gtk_image_menu_item_new_with_mnemonic (_("L_oad last save"));
  gtk_widget_show (menu_load_last_save);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_load_last_save);
  gtk_widget_add_accelerator (menu_load_last_save, "activate", accel_group,
                              GDK_l, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2725 = gtk_image_new_from_stock ("gtk-revert-to-saved", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2725);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_load_last_save), image2725);

  menu_save = gtk_image_menu_item_new_from_stock ("gtk-save", accel_group);
  gtk_widget_show (menu_save);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_save);

  menu_save_as = gtk_image_menu_item_new_from_stock ("gtk-save-as", accel_group);
  gtk_widget_show (menu_save_as);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_save_as);

  trennlinie1 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie1);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), trennlinie1);
  gtk_widget_set_sensitive (trennlinie1, FALSE);

  menu_quit = gtk_image_menu_item_new_from_stock ("gtk-quit", accel_group);
  gtk_widget_show (menu_quit);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_quit);

  menu_options = gtk_menu_item_new_with_mnemonic (_("_Options"));
  gtk_widget_show (menu_options);
  gtk_container_add (GTK_CONTAINER (menubar1), menu_options);

  menu_options_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_options), menu_options_menu);

  menu_preferences = gtk_image_menu_item_new_with_mnemonic (_("Preferences"));
  gtk_widget_show (menu_preferences);
  gtk_container_add (GTK_CONTAINER (menu_options_menu), menu_preferences);
  gtk_widget_add_accelerator (menu_preferences, "activate", accel_group,
                              GDK_p, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2726 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2726);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_preferences), image2726);

  trennlinie7 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie7);
  gtk_container_add (GTK_CONTAINER (menu_options_menu), trennlinie7);
  gtk_widget_set_sensitive (trennlinie7, FALSE);

  menu_job_offers = gtk_check_menu_item_new_with_mnemonic (_("Job offers"));
  gtk_widget_show (menu_job_offers);
  gtk_container_add (GTK_CONTAINER (menu_options_menu), menu_job_offers);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_job_offers), TRUE);

  menu_live_game = gtk_check_menu_item_new_with_mnemonic (_("Live game"));
  gtk_widget_show (menu_live_game);
  gtk_container_add (GTK_CONTAINER (menu_options_menu), menu_live_game);

  menu_overwrite = gtk_check_menu_item_new_with_mnemonic (_("Overwrite"));
  gtk_widget_show (menu_overwrite);
  gtk_container_add (GTK_CONTAINER (menu_options_menu), menu_overwrite);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_overwrite), TRUE);

  trennlinie14 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie14);
  gtk_container_add (GTK_CONTAINER (menu_options_menu), trennlinie14);
  gtk_widget_set_sensitive (trennlinie14, FALSE);

  menu_save_window_geometry = gtk_image_menu_item_new_with_mnemonic (_("Save window geometry"));
  gtk_widget_show (menu_save_window_geometry);
  gtk_container_add (GTK_CONTAINER (menu_options_menu), menu_save_window_geometry);
  gtk_tooltips_set_tip (tooltips, menu_save_window_geometry, _("Save window size, position and vertical divider"), NULL);

  image2727 = create_pixmap (main_window, "menu_save_geometry.png");
  gtk_widget_show (image2727);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_save_window_geometry), image2727);

  menu_figures = gtk_menu_item_new_with_mnemonic (_("F_igures"));
  gtk_widget_show (menu_figures);
  gtk_container_add (GTK_CONTAINER (menubar1), menu_figures);

  menu_figures_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_figures), menu_figures_menu);

  menu_fixtures_week = gtk_image_menu_item_new_with_mnemonic (_("Fixtures (week)"));
  gtk_widget_show (menu_fixtures_week);
  gtk_container_add (GTK_CONTAINER (menu_figures_menu), menu_fixtures_week);
  gtk_widget_add_accelerator (menu_fixtures_week, "activate", accel_group,
                              GDK_F3, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2728 = create_pixmap (main_window, "menu_fixtures.png");
  gtk_widget_show (image2728);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_fixtures_week), image2728);

  menu_fixtures = gtk_image_menu_item_new_with_mnemonic (_("Fixtures (competitions)"));
  gtk_widget_show (menu_fixtures);
  gtk_container_add (GTK_CONTAINER (menu_figures_menu), menu_fixtures);
  gtk_widget_add_accelerator (menu_fixtures, "activate", accel_group,
                              GDK_F4, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2729 = create_pixmap (main_window, "menu_fixtures_comp.png");
  gtk_widget_show (image2729);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_fixtures), image2729);

  menu_tables = gtk_image_menu_item_new_with_mnemonic (_("Tables"));
  gtk_widget_show (menu_tables);
  gtk_container_add (GTK_CONTAINER (menu_figures_menu), menu_tables);
  gtk_widget_add_accelerator (menu_tables, "activate", accel_group,
                              GDK_F5, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2730 = create_pixmap (main_window, "menu_table.png");
  gtk_widget_show (image2730);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_tables), image2730);

  menu_my_league_results = gtk_image_menu_item_new_with_mnemonic (_("My league results"));
  gtk_widget_show (menu_my_league_results);
  gtk_container_add (GTK_CONTAINER (menu_figures_menu), menu_my_league_results);
  gtk_widget_add_accelerator (menu_my_league_results, "activate", accel_group,
                              GDK_F6, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2731 = create_pixmap (main_window, "menu_league_results.png");
  gtk_widget_show (image2731);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_my_league_results), image2731);

  menu_season_results = gtk_image_menu_item_new_with_mnemonic (_("Season results"));
  gtk_widget_show (menu_season_results);
  gtk_container_add (GTK_CONTAINER (menu_figures_menu), menu_season_results);
  gtk_widget_add_accelerator (menu_season_results, "activate", accel_group,
                              GDK_s, (GdkModifierType) GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);

  image2732 = create_pixmap (main_window, "menu_season_res.png");
  gtk_widget_show (image2732);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_season_results), image2732);

  menu_team = gtk_menu_item_new_with_mnemonic (_("_Team"));
  gtk_widget_show (menu_team);
  gtk_container_add (GTK_CONTAINER (menubar1), menu_team);

  menu_team_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_team), menu_team_menu);

  menu_playing_style = gtk_image_menu_item_new_with_mnemonic (_("Playing style"));
  gtk_widget_show (menu_playing_style);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_playing_style);

  image2733 = create_pixmap (main_window, "menu_style.png");
  gtk_widget_show (image2733);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_playing_style), image2733);

  menu_playing_style_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_playing_style), menu_playing_style_menu);

  menu_all_out_defend = gtk_radio_menu_item_new_with_mnemonic (menu_all_out_defend_group, _("All Out Defend"));
  menu_all_out_defend_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_all_out_defend));
  gtk_widget_show (menu_all_out_defend);
  gtk_container_add (GTK_CONTAINER (menu_playing_style_menu), menu_all_out_defend);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_all_out_defend), TRUE);

  menu_defend = gtk_radio_menu_item_new_with_mnemonic (menu_all_out_defend_group, _("Defend"));
  menu_all_out_defend_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_defend));
  gtk_widget_show (menu_defend);
  gtk_container_add (GTK_CONTAINER (menu_playing_style_menu), menu_defend);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_defend), TRUE);

  menu_balanced = gtk_radio_menu_item_new_with_mnemonic (menu_all_out_defend_group, _("Balanced"));
  menu_all_out_defend_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_balanced));
  gtk_widget_show (menu_balanced);
  gtk_container_add (GTK_CONTAINER (menu_playing_style_menu), menu_balanced);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_balanced), TRUE);

  menu_attack = gtk_radio_menu_item_new_with_mnemonic (menu_all_out_defend_group, _("Attack"));
  menu_all_out_defend_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_attack));
  gtk_widget_show (menu_attack);
  gtk_container_add (GTK_CONTAINER (menu_playing_style_menu), menu_attack);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_attack), TRUE);

  menu_all_out_attack = gtk_radio_menu_item_new_with_mnemonic (menu_all_out_defend_group, _("All Out Attack"));
  menu_all_out_defend_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_all_out_attack));
  gtk_widget_show (menu_all_out_attack);
  gtk_container_add (GTK_CONTAINER (menu_playing_style_menu), menu_all_out_attack);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_all_out_attack), TRUE);

  menu_scout = gtk_image_menu_item_new_with_mnemonic (_("Scout"));
  gtk_widget_show (menu_scout);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_scout);

  image2734 = create_pixmap (main_window, "menu_scout.png");
  gtk_widget_show (image2734);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_scout), image2734);

  menu_scout_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_scout), menu_scout_menu);

  menu_scout_best = gtk_radio_menu_item_new_with_mnemonic (menu_scout_best_group, _("Best"));
  menu_scout_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_scout_best));
  gtk_widget_show (menu_scout_best);
  gtk_container_add (GTK_CONTAINER (menu_scout_menu), menu_scout_best);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_scout_best), TRUE);

  menu_scout_good = gtk_radio_menu_item_new_with_mnemonic (menu_scout_best_group, _("Good"));
  menu_scout_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_scout_good));
  gtk_widget_show (menu_scout_good);
  gtk_container_add (GTK_CONTAINER (menu_scout_menu), menu_scout_good);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_scout_good), TRUE);

  menu_scout_average = gtk_radio_menu_item_new_with_mnemonic (menu_scout_best_group, _("Average"));
  menu_scout_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_scout_average));
  gtk_widget_show (menu_scout_average);
  gtk_container_add (GTK_CONTAINER (menu_scout_menu), menu_scout_average);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_scout_average), TRUE);

  menu_scout_bad = gtk_radio_menu_item_new_with_mnemonic (menu_scout_best_group, _("Bad"));
  menu_scout_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_scout_bad));
  gtk_widget_show (menu_scout_bad);
  gtk_container_add (GTK_CONTAINER (menu_scout_menu), menu_scout_bad);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_scout_bad), TRUE);

  menu_physio = gtk_image_menu_item_new_with_mnemonic (_("Physio"));
  gtk_widget_show (menu_physio);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_physio);

  image2735 = create_pixmap (main_window, "menu_physio.png");
  gtk_widget_show (image2735);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_physio), image2735);

  menu_physio_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_physio), menu_physio_menu);

  menu_physio_best = gtk_radio_menu_item_new_with_mnemonic (menu_physio_best_group, _("Best"));
  menu_physio_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_physio_best));
  gtk_widget_show (menu_physio_best);
  gtk_container_add (GTK_CONTAINER (menu_physio_menu), menu_physio_best);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_physio_best), TRUE);

  menu_physio_good = gtk_radio_menu_item_new_with_mnemonic (menu_physio_best_group, _("Good"));
  menu_physio_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_physio_good));
  gtk_widget_show (menu_physio_good);
  gtk_container_add (GTK_CONTAINER (menu_physio_menu), menu_physio_good);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_physio_good), TRUE);

  menu_physio_average = gtk_radio_menu_item_new_with_mnemonic (menu_physio_best_group, _("Average"));
  menu_physio_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_physio_average));
  gtk_widget_show (menu_physio_average);
  gtk_container_add (GTK_CONTAINER (menu_physio_menu), menu_physio_average);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_physio_average), TRUE);

  menu_physio_bad = gtk_radio_menu_item_new_with_mnemonic (menu_physio_best_group, _("Bad"));
  menu_physio_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_physio_bad));
  gtk_widget_show (menu_physio_bad);
  gtk_container_add (GTK_CONTAINER (menu_physio_menu), menu_physio_bad);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_physio_bad), TRUE);

  menu_youth_academy = gtk_image_menu_item_new_with_mnemonic (_("Youth academy"));
  gtk_widget_show (menu_youth_academy);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_youth_academy);

  image2736 = create_pixmap (main_window, "menu_youth_academy.png");
  gtk_widget_show (image2736);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_youth_academy), image2736);

  menu_youth_academy_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_youth_academy), menu_youth_academy_menu);

  menu_show_youth_academy = gtk_menu_item_new_with_mnemonic (_("Show youth academy"));
  gtk_widget_show (menu_show_youth_academy);
  gtk_container_add (GTK_CONTAINER (menu_youth_academy_menu), menu_show_youth_academy);
  gtk_widget_add_accelerator (menu_show_youth_academy, "activate", accel_group,
                              GDK_y, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  youth_coach1 = gtk_menu_item_new_with_mnemonic (_("Youth coach"));
  gtk_widget_show (youth_coach1);
  gtk_container_add (GTK_CONTAINER (menu_youth_academy_menu), youth_coach1);

  youth_coach1_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (youth_coach1), youth_coach1_menu);

  menu_yc_best = gtk_radio_menu_item_new_with_mnemonic (menu_yc_best_group, _("Best"));
  menu_yc_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_yc_best));
  gtk_widget_show (menu_yc_best);
  gtk_container_add (GTK_CONTAINER (youth_coach1_menu), menu_yc_best);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_yc_best), TRUE);

  menu_yc_good = gtk_radio_menu_item_new_with_mnemonic (menu_yc_best_group, _("Good"));
  menu_yc_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_yc_good));
  gtk_widget_show (menu_yc_good);
  gtk_container_add (GTK_CONTAINER (youth_coach1_menu), menu_yc_good);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_yc_good), TRUE);

  menu_yc_average = gtk_radio_menu_item_new_with_mnemonic (menu_yc_best_group, _("Average"));
  menu_yc_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_yc_average));
  gtk_widget_show (menu_yc_average);
  gtk_container_add (GTK_CONTAINER (youth_coach1_menu), menu_yc_average);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_yc_average), TRUE);

  menu_yc_bad = gtk_radio_menu_item_new_with_mnemonic (menu_yc_best_group, _("Bad"));
  menu_yc_best_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_yc_bad));
  gtk_widget_show (menu_yc_bad);
  gtk_container_add (GTK_CONTAINER (youth_coach1_menu), menu_yc_bad);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_yc_bad), TRUE);

  recruiting_preference1 = gtk_menu_item_new_with_mnemonic (_("Recruiting preference"));
  gtk_widget_show (recruiting_preference1);
  gtk_container_add (GTK_CONTAINER (menu_youth_academy_menu), recruiting_preference1);

  recruiting_preference1_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (recruiting_preference1), recruiting_preference1_menu);

  menu_recruit0 = gtk_radio_menu_item_new_with_mnemonic (menu_recruit0_group, _("Goalies"));
  menu_recruit0_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_recruit0));
  gtk_widget_show (menu_recruit0);
  gtk_container_add (GTK_CONTAINER (recruiting_preference1_menu), menu_recruit0);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_recruit0), TRUE);

  menu_recruit1 = gtk_radio_menu_item_new_with_mnemonic (menu_recruit0_group, _("Defenders"));
  menu_recruit0_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_recruit1));
  gtk_widget_show (menu_recruit1);
  gtk_container_add (GTK_CONTAINER (recruiting_preference1_menu), menu_recruit1);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_recruit1), TRUE);

  menu_recruit2 = gtk_radio_menu_item_new_with_mnemonic (menu_recruit0_group, _("Midfielders"));
  menu_recruit0_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_recruit2));
  gtk_widget_show (menu_recruit2);
  gtk_container_add (GTK_CONTAINER (recruiting_preference1_menu), menu_recruit2);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_recruit2), TRUE);

  menu_recruit3 = gtk_radio_menu_item_new_with_mnemonic (menu_recruit0_group, _("Forwards"));
  menu_recruit0_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_recruit3));
  gtk_widget_show (menu_recruit3);
  gtk_container_add (GTK_CONTAINER (recruiting_preference1_menu), menu_recruit3);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_recruit3), TRUE);

  menu_recruit4 = gtk_radio_menu_item_new_with_mnemonic (menu_recruit0_group, _("Any"));
  menu_recruit0_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_recruit4));
  gtk_widget_show (menu_recruit4);
  gtk_container_add (GTK_CONTAINER (recruiting_preference1_menu), menu_recruit4);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_recruit4), TRUE);

  menu_set_investment = gtk_menu_item_new_with_mnemonic (_("Set investment"));
  gtk_widget_show (menu_set_investment);
  gtk_container_add (GTK_CONTAINER (menu_youth_academy_menu), menu_set_investment);
  gtk_tooltips_set_tip (tooltips, menu_set_investment, _("Set the percentage of your income you want to devote to your youth academy."), NULL);

  menu_boost = gtk_image_menu_item_new_with_mnemonic (_("Boost"));
  gtk_widget_show (menu_boost);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_boost);

  image2737 = create_pixmap (main_window, "menu_boost.png");
  gtk_widget_show (image2737);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_boost), image2737);

  menu_boost_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_boost), menu_boost_menu);

  menu_boost_on = gtk_radio_menu_item_new_with_mnemonic (menu_boost_on_group, _("On"));
  menu_boost_on_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_boost_on));
  gtk_widget_show (menu_boost_on);
  gtk_container_add (GTK_CONTAINER (menu_boost_menu), menu_boost_on);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_boost_on), TRUE);

  menu_boost_off = gtk_radio_menu_item_new_with_mnemonic (menu_boost_on_group, _("Off"));
  menu_boost_on_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_boost_off));
  gtk_widget_show (menu_boost_off);
  gtk_container_add (GTK_CONTAINER (menu_boost_menu), menu_boost_off);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_boost_off), TRUE);

  menu_boost_anti = gtk_radio_menu_item_new_with_mnemonic (menu_boost_on_group, _("Anti"));
  menu_boost_on_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_boost_anti));
  gtk_widget_show (menu_boost_anti);
  gtk_container_add (GTK_CONTAINER (menu_boost_menu), menu_boost_anti);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_boost_anti), TRUE);

  trennlinie11 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie11);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), trennlinie11);
  gtk_widget_set_sensitive (trennlinie11, FALSE);

  menu_training_camp = gtk_menu_item_new_with_mnemonic (_("Training camp"));
  gtk_widget_show (menu_training_camp);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_training_camp);

  trennlinie18 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie18);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), trennlinie18);
  gtk_widget_set_sensitive (trennlinie18, FALSE);

  menu_reset_players = gtk_image_menu_item_new_with_mnemonic (_("Reset player list"));
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_reset_players);
  gtk_tooltips_set_tip (tooltips, menu_reset_players, _("Reset player list to the formation at the beginning of the live game pause (right click on player list)"), NULL);

  image2738 = gtk_image_new_from_stock ("gtk-undo", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2738);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_reset_players), image2738);

  menu_custom_structure = gtk_image_menu_item_new_with_mnemonic (_("Enter custom structure"));
  gtk_widget_show (menu_custom_structure);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_custom_structure);

  image2739 = create_pixmap (main_window, "menu_structure.png");
  gtk_widget_show (image2739);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_custom_structure), image2739);

  menu_rearrange_team = gtk_image_menu_item_new_with_mnemonic (_("Rearrange team"));
  gtk_widget_show (menu_rearrange_team);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_rearrange_team);
  gtk_tooltips_set_tip (tooltips, menu_rearrange_team, _("Try to put the startup players onto their favoured positions and sort the substitutes (Ctrl-R or middle click)"), NULL);
  gtk_widget_add_accelerator (menu_rearrange_team, "activate", accel_group,
                              GDK_r, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2740 = create_pixmap (main_window, "menu_rearrange.png");
  gtk_widget_show (image2740);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_rearrange_team), image2740);

  trennlinie8 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie8);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), trennlinie8);
  gtk_widget_set_sensitive (trennlinie8, FALSE);

  menu_browse_teams = gtk_image_menu_item_new_with_mnemonic (_("Browse teams"));
  gtk_widget_show (menu_browse_teams);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_browse_teams);

  image2741 = create_pixmap (main_window, "menu_browse_tms.png");
  gtk_widget_show (image2741);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_browse_teams), image2741);

  trennlinie16 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie16);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), trennlinie16);
  gtk_widget_set_sensitive (trennlinie16, FALSE);

  menu_show_job_exchange = gtk_menu_item_new_with_mnemonic (_("Show job exchange"));
  gtk_widget_show (menu_show_job_exchange);
  gtk_container_add (GTK_CONTAINER (menu_team_menu), menu_show_job_exchange);
  gtk_tooltips_set_tip (tooltips, menu_show_job_exchange, _("Show the list of available manager jobs"), NULL);
  gtk_widget_add_accelerator (menu_show_job_exchange, "activate", accel_group,
                              GDK_j, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  menu_player = gtk_menu_item_new_with_mnemonic (_("_Player"));
  gtk_widget_show (menu_player);
  gtk_container_add (GTK_CONTAINER (menubar1), menu_player);

  menu_player_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_player), menu_player_menu);

  menu_show_info = gtk_image_menu_item_new_with_mnemonic (_("Show info"));
  gtk_widget_show (menu_show_info);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_show_info);

  image2742 = create_pixmap (main_window, "menu_player_info.png");
  gtk_widget_show (image2742);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_show_info), image2742);

  menu_put_on_transfer_list = gtk_image_menu_item_new_with_mnemonic (_("Put on transfer list"));
  gtk_widget_show (menu_put_on_transfer_list);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_put_on_transfer_list);

  image2743 = create_pixmap (main_window, "menu_player_put_transfer.png");
  gtk_widget_show (image2743);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_put_on_transfer_list), image2743);

  menu_remove_from_transfer_list = gtk_image_menu_item_new_with_mnemonic (_("Remove from transfer list"));
  gtk_widget_show (menu_remove_from_transfer_list);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_remove_from_transfer_list);

  image2744 = create_pixmap (main_window, "menu_player_remove_transfer.png");
  gtk_widget_show (image2744);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_remove_from_transfer_list), image2744);

  menu_offer_new_contract = gtk_image_menu_item_new_with_mnemonic (_("Offer new contract"));
  gtk_widget_show (menu_offer_new_contract);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_offer_new_contract);

  image2745 = create_pixmap (main_window, "menu_player_contract.png");
  gtk_widget_show (image2745);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_offer_new_contract), image2745);

  menu_fire = gtk_image_menu_item_new_with_mnemonic (_("Fire"));
  gtk_widget_show (menu_fire);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_fire);

  image2746 = create_pixmap (main_window, "menu_player_fire.png");
  gtk_widget_show (image2746);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_fire), image2746);

  menu_shoots_penalties = gtk_image_menu_item_new_with_mnemonic (_("Shoots penalties"));
  gtk_widget_show (menu_shoots_penalties);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_shoots_penalties);

  image2747 = create_pixmap (main_window, "menu_player_shoots.png");
  gtk_widget_show (image2747);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_shoots_penalties), image2747);

  menu_move_to_youth_academy = gtk_image_menu_item_new_with_mnemonic (_("Move to youth academy"));
  gtk_widget_show (menu_move_to_youth_academy);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_move_to_youth_academy);

  image2748 = create_pixmap (main_window, "menu_player_move_to_ya.png");
  gtk_widget_show (image2748);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_move_to_youth_academy), image2748);

  menu_edit_name = gtk_image_menu_item_new_with_mnemonic (_("Edit name"));
  gtk_widget_show (menu_edit_name);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_edit_name);

  image2749 = gtk_image_new_from_stock ("gtk-edit", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2749);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_edit_name), image2749);

  trennlinie10 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie10);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), trennlinie10);
  gtk_widget_set_sensitive (trennlinie10, FALSE);

  menu_browse_players = gtk_image_menu_item_new_with_mnemonic (_("Browse players"));
  gtk_widget_show (menu_browse_players);
  gtk_container_add (GTK_CONTAINER (menu_player_menu), menu_browse_players);

  image2750 = create_pixmap (main_window, "menu_player_browse.png");
  gtk_widget_show (image2750);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_browse_players), image2750);

  menu_user = gtk_menu_item_new_with_mnemonic (_("_User"));
  gtk_widget_show (menu_user);
  gtk_container_add (GTK_CONTAINER (menubar1), menu_user);

  menu_user_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_user), menu_user_menu);

  menu_user_show_last_match = gtk_image_menu_item_new_with_mnemonic (_("Show last match"));
  gtk_widget_show (menu_user_show_last_match);
  gtk_container_add (GTK_CONTAINER (menu_user_menu), menu_user_show_last_match);
  gtk_widget_add_accelerator (menu_user_show_last_match, "activate", accel_group,
                              GDK_v, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2751 = create_pixmap (main_window, "menu_last_match.png");
  gtk_widget_show (image2751);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_user_show_last_match), image2751);

  menu_user_show_last_stats = gtk_image_menu_item_new_with_mnemonic (_("Show last match stats"));
  gtk_widget_show (menu_user_show_last_stats);
  gtk_container_add (GTK_CONTAINER (menu_user_menu), menu_user_show_last_stats);
  gtk_widget_add_accelerator (menu_user_show_last_stats, "activate", accel_group,
                              GDK_F2, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2752 = create_pixmap (main_window, "menu_match_stats.png");
  gtk_widget_show (image2752);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_user_show_last_stats), image2752);

  menu_user_show_coming_matches = gtk_image_menu_item_new_with_mnemonic (_("Show coming matches"));
  gtk_widget_show (menu_user_show_coming_matches);
  gtk_container_add (GTK_CONTAINER (menu_user_menu), menu_user_show_coming_matches);
  gtk_widget_add_accelerator (menu_user_show_coming_matches, "activate", accel_group,
                              GDK_F1, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2753 = gtk_image_new_from_stock ("gtk-jump-to", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2753);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_user_show_coming_matches), image2753);

  trennlinie9 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie9);
  gtk_container_add (GTK_CONTAINER (menu_user_menu), trennlinie9);
  gtk_widget_set_sensitive (trennlinie9, FALSE);

  menu_next_user = gtk_image_menu_item_new_with_mnemonic (_("Next user"));
  gtk_widget_show (menu_next_user);
  gtk_container_add (GTK_CONTAINER (menu_user_menu), menu_next_user);
  gtk_widget_add_accelerator (menu_next_user, "activate", accel_group,
                              GDK_F9, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2754 = gtk_image_new_from_stock ("gtk-media-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2754);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_next_user), image2754);

  menu_previous_user = gtk_image_menu_item_new_with_mnemonic (_("Previous user"));
  gtk_widget_show (menu_previous_user);
  gtk_container_add (GTK_CONTAINER (menu_user_menu), menu_previous_user);
  gtk_widget_add_accelerator (menu_previous_user, "activate", accel_group,
                              GDK_F8, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2755 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2755);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_previous_user), image2755);

  menu_manage_users = gtk_image_menu_item_new_with_mnemonic (_("Manage users"));
  gtk_widget_show (menu_manage_users);
  gtk_container_add (GTK_CONTAINER (menu_user_menu), menu_manage_users);
  gtk_widget_add_accelerator (menu_manage_users, "activate", accel_group,
                              GDK_F12, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2756 = gtk_image_new_from_stock ("gtk-justify-fill", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2756);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_manage_users), image2756);

  menu_finances_stadium = gtk_menu_item_new_with_mnemonic (_("Fin_Stad"));
  gtk_widget_show (menu_finances_stadium);
  gtk_container_add (GTK_CONTAINER (menubar1), menu_finances_stadium);

  menu_finances_stadium_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_finances_stadium), menu_finances_stadium_menu);

  menu_show_finances = gtk_image_menu_item_new_with_mnemonic (_("Show finances"));
  gtk_widget_show (menu_show_finances);
  gtk_container_add (GTK_CONTAINER (menu_finances_stadium_menu), menu_show_finances);
  gtk_widget_add_accelerator (menu_show_finances, "activate", accel_group,
                              GDK_f, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2757 = create_pixmap (main_window, "menu_finances.png");
  gtk_widget_show (image2757);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_show_finances), image2757);

  menu_show_stadium = gtk_image_menu_item_new_with_mnemonic (_("Show stadium"));
  gtk_widget_show (menu_show_stadium);
  gtk_container_add (GTK_CONTAINER (menu_finances_stadium_menu), menu_show_stadium);
  gtk_widget_add_accelerator (menu_show_stadium, "activate", accel_group,
                              GDK_f, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2758 = create_pixmap (main_window, "menu_stadium.png");
  gtk_widget_show (image2758);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_show_stadium), image2758);

  automatic_loan_repayment = gtk_menu_item_new_with_mnemonic (_("Automatic loan repayment"));
  gtk_widget_show (automatic_loan_repayment);
  gtk_container_add (GTK_CONTAINER (menu_finances_stadium_menu), automatic_loan_repayment);
  gtk_widget_add_accelerator (automatic_loan_repayment, "activate", accel_group,
                              GDK_d, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  trennlinie15 = gtk_separator_menu_item_new ();
  gtk_widget_show (trennlinie15);
  gtk_container_add (GTK_CONTAINER (menu_finances_stadium_menu), trennlinie15);
  gtk_widget_set_sensitive (trennlinie15, FALSE);

  menu_betting = gtk_menu_item_new_with_mnemonic (_("Betting"));
  gtk_widget_show (menu_betting);
  gtk_container_add (GTK_CONTAINER (menu_finances_stadium_menu), menu_betting);
  gtk_tooltips_set_tip (tooltips, menu_betting, _("Show the betting window"), NULL);
  gtk_widget_add_accelerator (menu_betting, "activate", accel_group,
                              GDK_b, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  stats1 = gtk_menu_item_new_with_mnemonic (_("St_ats"));
  gtk_widget_show (stats1);
  gtk_container_add (GTK_CONTAINER (menubar1), stats1);

  stats1_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (stats1), stats1_menu);

  menu_news = gtk_menu_item_new_with_mnemonic (_("News"));
  gtk_widget_show (menu_news);
  gtk_container_add (GTK_CONTAINER (stats1_menu), menu_news);
  gtk_widget_add_accelerator (menu_news, "activate", accel_group,
                              GDK_n, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  menu_league_stats = gtk_image_menu_item_new_with_mnemonic (_("League stats"));
  gtk_widget_show (menu_league_stats);
  gtk_container_add (GTK_CONTAINER (stats1_menu), menu_league_stats);
  gtk_widget_add_accelerator (menu_league_stats, "activate", accel_group,
                              GDK_s, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2759 = create_pixmap (main_window, "menu_league_stats.png");
  gtk_widget_show (image2759);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_league_stats), image2759);

  menu_season_history = gtk_image_menu_item_new_with_mnemonic (_("Season history"));
  gtk_widget_show (menu_season_history);
  gtk_container_add (GTK_CONTAINER (stats1_menu), menu_season_history);
  gtk_widget_add_accelerator (menu_season_history, "activate", accel_group,
                              GDK_h, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image2760 = create_pixmap (main_window, "menu_history.png");
  gtk_widget_show (image2760);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_season_history), image2760);

  menu_user_show_history = gtk_image_menu_item_new_with_mnemonic (_("User history"));
  gtk_widget_show (menu_user_show_history);
  gtk_container_add (GTK_CONTAINER (stats1_menu), menu_user_show_history);
  gtk_widget_add_accelerator (menu_user_show_history, "activate", accel_group,
                              GDK_h, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2761 = create_pixmap (main_window, "menu_history.png");
  gtk_widget_show (image2761);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_user_show_history), image2761);

  memorable_matches = gtk_image_menu_item_new_with_mnemonic (_("Memorable matches"));
  gtk_widget_show (memorable_matches);
  gtk_container_add (GTK_CONTAINER (stats1_menu), memorable_matches);

  image2762 = create_pixmap (main_window, "menu_mmatches.png");
  gtk_widget_show (image2762);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (memorable_matches), image2762);

  memorable_matches_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (memorable_matches), memorable_matches_menu);

  mm_add_last_match = gtk_image_menu_item_new_with_mnemonic (_("Add last match"));
  gtk_widget_show (mm_add_last_match);
  gtk_container_add (GTK_CONTAINER (memorable_matches_menu), mm_add_last_match);
  gtk_tooltips_set_tip (tooltips, mm_add_last_match, _("Add last recorded match to the current memorable matches file."), NULL);
  gtk_widget_add_accelerator (mm_add_last_match, "activate", accel_group,
                              GDK_a, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2763 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2763);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mm_add_last_match), image2763);

  mm_manage_matches = gtk_image_menu_item_new_with_mnemonic (_("Manage matches"));
  gtk_widget_show (mm_manage_matches);
  gtk_container_add (GTK_CONTAINER (memorable_matches_menu), mm_manage_matches);
  gtk_tooltips_set_tip (tooltips, mm_manage_matches, _("Replay, delete or add memorable matches."), NULL);
  gtk_widget_add_accelerator (mm_manage_matches, "activate", accel_group,
                              GDK_m, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2764 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2764);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mm_manage_matches), image2764);

  menu_help1 = gtk_menu_item_new_with_mnemonic (_("_Help"));
  gtk_widget_show (menu_help1);
  gtk_container_add (GTK_CONTAINER (menubar1), menu_help1);

  menu_help1_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_help1), menu_help1_menu);

  menu_about = gtk_image_menu_item_new_with_mnemonic (_("About"));
  gtk_widget_show (menu_about);
  gtk_container_add (GTK_CONTAINER (menu_help1_menu), menu_about);

  image2765 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2765);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_about), image2765);

  menu_contributors = gtk_image_menu_item_new_with_mnemonic (_("Contributors"));
  gtk_widget_show (menu_contributors);
  gtk_container_add (GTK_CONTAINER (menu_help1_menu), menu_contributors);

  image2766 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2766);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_contributors), image2766);

  menu_help = gtk_image_menu_item_new_with_mnemonic (_("Help"));
  gtk_widget_show (menu_help);
  gtk_container_add (GTK_CONTAINER (menu_help1_menu), menu_help);

  image2767 = gtk_image_new_from_stock ("gtk-help", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2767);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_help), image2767);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);

  button_load = gtk_button_new ();
  gtk_widget_show (button_load);
  gtk_box_pack_start (GTK_BOX (hbox1), button_load, FALSE, FALSE, 2);
  gtk_container_set_border_width (GTK_CONTAINER (button_load), 2);
  gtk_tooltips_set_tip (tooltips, button_load, _("Load game (Ctrl - O)"), NULL);

  image11 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image11);
  gtk_container_add (GTK_CONTAINER (button_load), image11);

  button_save = gtk_button_new ();
  gtk_widget_show (button_save);
  gtk_box_pack_start (GTK_BOX (hbox1), button_save, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_save), 2);
  gtk_tooltips_set_tip (tooltips, button_save, _("Save game (Ctrl - S)"), NULL);

  image12 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image12);
  gtk_container_add (GTK_CONTAINER (button_save), image12);

  button_quit = gtk_button_new ();
  gtk_widget_show (button_quit);
  gtk_box_pack_start (GTK_BOX (hbox1), button_quit, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_quit), 2);
  gtk_tooltips_set_tip (tooltips, button_quit, _("Quit (Ctrl - Q)"), NULL);

  image13 = gtk_image_new_from_stock ("gtk-quit", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image13);
  gtk_container_add (GTK_CONTAINER (button_quit), image13);

  vseparator1 = gtk_vseparator_new ();
  gtk_widget_show (vseparator1);
  gtk_box_pack_start (GTK_BOX (hbox1), vseparator1, FALSE, FALSE, 0);
  gtk_widget_set_size_request (vseparator1, 10, 1);

  vseparator11 = gtk_vseparator_new ();
  gtk_widget_show (vseparator11);
  gtk_box_pack_start (GTK_BOX (hbox1), vseparator11, FALSE, FALSE, 0);
  gtk_widget_set_size_request (vseparator11, 10, 1);

  button_back_to_main = gtk_button_new ();
  gtk_widget_show (button_back_to_main);
  gtk_box_pack_start (GTK_BOX (hbox1), button_back_to_main, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_back_to_main), 2);
  gtk_tooltips_set_tip (tooltips, button_back_to_main, _("Back to main menu (Esc)"), NULL);
  gtk_widget_add_accelerator (button_back_to_main, "clicked", accel_group,
                              GDK_Escape, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image20 = gtk_image_new_from_stock ("gtk-home", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image20);
  gtk_container_add (GTK_CONTAINER (button_back_to_main), image20);

  button_transfers = gtk_button_new ();
  gtk_widget_show (button_transfers);
  gtk_box_pack_start (GTK_BOX (hbox1), button_transfers, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_transfers), 2);
  gtk_tooltips_set_tip (tooltips, button_transfers, _("Show transferlist (T)"), NULL);
  gtk_widget_add_accelerator (button_transfers, "clicked", accel_group,
                              GDK_t, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image32 = create_pixmap (main_window, "transfers.png");
  gtk_widget_show (image32);
  gtk_container_add (GTK_CONTAINER (button_transfers), image32);

  vseparator16 = gtk_vseparator_new ();
  gtk_widget_show (vseparator16);
  gtk_box_pack_start (GTK_BOX (hbox1), vseparator16, FALSE, FALSE, 0);
  gtk_widget_set_size_request (vseparator16, 40, 1);

  button_new_week = gtk_button_new ();
  gtk_widget_show (button_new_week);
  gtk_box_pack_start (GTK_BOX (hbox1), button_new_week, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_new_week), 2);
  gtk_tooltips_set_tip (tooltips, button_new_week, _("Begin a new week (Space)"), NULL);
  gtk_widget_add_accelerator (button_new_week, "clicked", accel_group,
                              GDK_space, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image23 = create_pixmap (main_window, "new_week.png");
  gtk_widget_show (image23);
  gtk_container_add (GTK_CONTAINER (button_new_week), image23);

  entry_message = gtk_entry_new ();
  gtk_widget_show (entry_message);
  gtk_box_pack_start (GTK_BOX (hbox1), entry_message, TRUE, TRUE, 5);
  gtk_editable_set_editable (GTK_EDITABLE (entry_message), FALSE);

  hseparator1 = gtk_hseparator_new ();
  gtk_widget_show (hseparator1);
  gtk_box_pack_start (GTK_BOX (vbox1), hseparator1, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator1, 1, 10);

  eventbox_main_info = gtk_event_box_new ();
  gtk_widget_show (eventbox_main_info);
  gtk_box_pack_start (GTK_BOX (vbox1), eventbox_main_info, FALSE, FALSE, 0);

  hbox18 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox18);
  gtk_container_add (GTK_CONTAINER (eventbox_main_info), hbox18);

  label_user = gtk_label_new ("");
  gtk_widget_show (label_user);
  gtk_box_pack_start (GTK_BOX (hbox18), label_user, FALSE, FALSE, 0);

  label23 = gtk_label_new (_(" Season "));
  gtk_widget_show (label23);
  gtk_box_pack_start (GTK_BOX (hbox18), label23, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label23), TRUE);
  gtk_misc_set_padding (GTK_MISC (label23), 5, 0);

  label_season = gtk_label_new ("");
  gtk_widget_show (label_season);
  gtk_box_pack_start (GTK_BOX (hbox18), label_season, FALSE, FALSE, 0);

  label25 = gtk_label_new (_(" Week "));
  gtk_widget_show (label25);
  gtk_box_pack_start (GTK_BOX (hbox18), label25, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label25), TRUE);
  gtk_misc_set_padding (GTK_MISC (label25), 5, 0);

  label_week = gtk_label_new ("");
  gtk_widget_show (label_week);
  gtk_box_pack_start (GTK_BOX (hbox18), label_week, FALSE, FALSE, 0);

  label13114 = gtk_label_new (_(" Round "));
  gtk_widget_show (label13114);
  gtk_box_pack_start (GTK_BOX (hbox18), label13114, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label13114), TRUE);

  label_round = gtk_label_new ("");
  gtk_widget_show (label_round);
  gtk_box_pack_start (GTK_BOX (hbox18), label_round, FALSE, FALSE, 0);

  vseparator14 = gtk_vseparator_new ();
  gtk_widget_show (vseparator14);
  gtk_box_pack_start (GTK_BOX (hbox18), vseparator14, FALSE, FALSE, 0);
  gtk_widget_set_size_request (vseparator14, 15, 1);

  hbox48 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox48);
  gtk_box_pack_start (GTK_BOX (hbox18), hbox48, FALSE, FALSE, 0);

  eventbox_style = gtk_event_box_new ();
  gtk_widget_show (eventbox_style);
  gtk_box_pack_start (GTK_BOX (hbox48), eventbox_style, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_style, _("Right click and left click to change your playing style"), NULL);

  image_style = create_pixmap (main_window, NULL);
  gtk_widget_show (image_style);
  gtk_container_add (GTK_CONTAINER (eventbox_style), image_style);
  gtk_misc_set_padding (GTK_MISC (image_style), 2, 0);

  eventbox_boost = gtk_event_box_new ();
  gtk_widget_show (eventbox_boost);
  gtk_box_pack_start (GTK_BOX (hbox48), eventbox_boost, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_boost, _("Right click and left click to change boost state"), NULL);

  image_boost = create_pixmap (main_window, NULL);
  gtk_widget_show (image_boost);
  gtk_container_add (GTK_CONTAINER (eventbox_boost), image_boost);
  gtk_misc_set_padding (GTK_MISC (image_boost), 2, 0);

  eventbox_team_name = gtk_event_box_new ();
  gtk_widget_show (eventbox_team_name);
  gtk_box_pack_start (GTK_BOX (hbox48), eventbox_team_name, FALSE, FALSE, 0);

  label_team = gtk_label_new ("");
  gtk_widget_show (label_team);
  gtk_container_add (GTK_CONTAINER (eventbox_team_name), label_team);
  gtk_misc_set_padding (GTK_MISC (label_team), 5, 0);

  label_league = gtk_label_new ("");
  gtk_widget_show (label_league);
  gtk_box_pack_start (GTK_BOX (hbox18), label_league, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_league), TRUE);
  gtk_misc_set_padding (GTK_MISC (label_league), 5, 0);

  eventbox_rank = gtk_event_box_new ();
  gtk_widget_show (eventbox_rank);
  gtk_box_pack_start (GTK_BOX (hbox18), eventbox_rank, FALSE, FALSE, 0);

  hbox49 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox49);
  gtk_container_add (GTK_CONTAINER (eventbox_rank), hbox49);

  label29 = gtk_label_new (_("Rank "));
  gtk_widget_show (label29);
  gtk_box_pack_start (GTK_BOX (hbox49), label29, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label29), TRUE);
  gtk_misc_set_padding (GTK_MISC (label29), 5, 0);

  label_rank = gtk_label_new ("");
  gtk_widget_show (label_rank);
  gtk_box_pack_start (GTK_BOX (hbox49), label_rank, FALSE, FALSE, 0);

  vseparator15 = gtk_vseparator_new ();
  gtk_widget_show (vseparator15);
  gtk_box_pack_start (GTK_BOX (hbox18), vseparator15, FALSE, TRUE, 0);
  gtk_widget_set_size_request (vseparator15, 15, 1);

  label34 = gtk_label_new (_("Money "));
  gtk_widget_show (label34);
  gtk_box_pack_start (GTK_BOX (hbox18), label34, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label34), TRUE);
  gtk_misc_set_padding (GTK_MISC (label34), 5, 0);

  label_money = gtk_label_new ("");
  gtk_widget_show (label_money);
  gtk_box_pack_start (GTK_BOX (hbox18), label_money, FALSE, FALSE, 0);

  vseparator17 = gtk_vseparator_new ();
  gtk_widget_show (vseparator17);
  gtk_box_pack_start (GTK_BOX (hbox18), vseparator17, FALSE, FALSE, 0);
  gtk_widget_set_size_request (vseparator17, 15, 1);

  eventbox1 = gtk_event_box_new ();
  gtk_widget_show (eventbox1);
  gtk_box_pack_start (GTK_BOX (hbox18), eventbox1, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox1, _("First value: average current skill of the first 11 players. Second value: average skill of all players."), NULL);

  hbox50 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox50);
  gtk_container_add (GTK_CONTAINER (eventbox1), hbox50);

  label69 = gtk_label_new (_("Av. skills:  "));
  gtk_widget_show (label69);
  gtk_box_pack_start (GTK_BOX (hbox50), label69, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label69), TRUE);

  label_av_skills = gtk_label_new ("");
  gtk_widget_show (label_av_skills);
  gtk_box_pack_start (GTK_BOX (hbox50), label_av_skills, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label_av_skills), 5, 0);

  hbox7 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox7);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox7, TRUE, TRUE, 0);

  hpaned2 = gtk_hpaned_new ();
  gtk_widget_show (hpaned2);
  gtk_box_pack_start (GTK_BOX (hbox7), hpaned2, TRUE, TRUE, 3);
  gtk_paned_set_position (GTK_PANED (hpaned2), 470);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox3);
  gtk_paned_pack1 (GTK_PANED (hpaned2), vbox3, FALSE, TRUE);

  scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow2);
  gtk_box_pack_start (GTK_BOX (vbox3), scrolledwindow2, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow2), 2);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_SHADOW_IN);

  viewport1 = gtk_viewport_new (NULL, NULL);
  gtk_widget_show (viewport1);
  gtk_container_add (GTK_CONTAINER (scrolledwindow2), viewport1);

  notebook_player = gtk_notebook_new ();
  gtk_widget_show (notebook_player);
  gtk_container_add (GTK_CONTAINER (viewport1), notebook_player);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook_player), FALSE);

  player_list1 = gtk_tree_view_new ();
  gtk_widget_show (player_list1);
  gtk_container_add (GTK_CONTAINER (notebook_player), player_list1);

  label71 = gtk_label_new (_("Player list 1"));
  gtk_widget_show (label71);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_player), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_player), 0), label71);

  player_list2 = gtk_tree_view_new ();
  gtk_widget_show (player_list2);
  gtk_container_add (GTK_CONTAINER (notebook_player), player_list2);

  label72 = gtk_label_new (_("Player list 2"));
  gtk_widget_show (label72);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_player), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_player), 1), label72);

  button_reset_players = gtk_button_new ();
  gtk_box_pack_start (GTK_BOX (vbox3), button_reset_players, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_reset_players, _("Reset player list to the formation at the beginning of the live game pause (right click on player list)"), NULL);

  image298 = gtk_image_new_from_stock ("gtk-undo", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image298);
  gtk_container_add (GTK_CONTAINER (button_reset_players), image298);

  vbox8 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox8);
  gtk_paned_pack2 (GTK_PANED (hpaned2), vbox8, TRUE, TRUE);

  hbox_14 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox_14);
  gtk_box_pack_start (GTK_BOX (vbox8), hbox_14, FALSE, FALSE, 4);

  button_cl_back = gtk_button_new ();
  gtk_widget_show (button_cl_back);
  gtk_box_pack_start (GTK_BOX (hbox_14), button_cl_back, TRUE, TRUE, 0);
  gtk_widget_set_sensitive (button_cl_back, FALSE);
  gtk_tooltips_set_tip (tooltips, button_cl_back, _("Previous league/cup (1)"), NULL);
  gtk_widget_add_accelerator (button_cl_back, "clicked", accel_group,
                              GDK_1, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image215 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image215);
  gtk_container_add (GTK_CONTAINER (button_cl_back), image215);

  button_cl_forward = gtk_button_new ();
  gtk_widget_show (button_cl_forward);
  gtk_box_pack_start (GTK_BOX (hbox_14), button_cl_forward, TRUE, TRUE, 0);
  gtk_widget_set_sensitive (button_cl_forward, FALSE);
  gtk_tooltips_set_tip (tooltips, button_cl_forward, _("Next league/cup (2)"), NULL);
  gtk_widget_add_accelerator (button_cl_forward, "clicked", accel_group,
                              GDK_2, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image216 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image216);
  gtk_container_add (GTK_CONTAINER (button_cl_forward), image216);

  button_browse_back = gtk_button_new ();
  gtk_widget_show (button_browse_back);
  gtk_box_pack_start (GTK_BOX (hbox_14), button_browse_back, TRUE, TRUE, 0);
  gtk_widget_set_sensitive (button_browse_back, FALSE);
  gtk_tooltips_set_tip (tooltips, button_browse_back, _("Previous (Q)"), NULL);
  gtk_widget_add_accelerator (button_browse_back, "clicked", accel_group,
                              GDK_q, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image10 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image10);
  gtk_container_add (GTK_CONTAINER (button_browse_back), image10);

  button_browse_forward = gtk_button_new ();
  gtk_widget_show (button_browse_forward);
  gtk_box_pack_start (GTK_BOX (hbox_14), button_browse_forward, TRUE, TRUE, 0);
  gtk_widget_set_sensitive (button_browse_forward, FALSE);
  gtk_tooltips_set_tip (tooltips, button_browse_forward, _("Next (W)"), NULL);
  gtk_widget_add_accelerator (button_browse_forward, "clicked", accel_group,
                              GDK_w, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  image9 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image9);
  gtk_container_add (GTK_CONTAINER (button_browse_forward), image9);

  scrolledwindow3 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow3);
  gtk_box_pack_start (GTK_BOX (vbox8), scrolledwindow3, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow3), 2);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow3), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow3), GTK_SHADOW_IN);

  treeview_right = gtk_tree_view_new ();
  gtk_widget_show (treeview_right);
  gtk_container_add (GTK_CONTAINER (scrolledwindow3), treeview_right);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_right), FALSE);

  g_signal_connect ((gpointer) main_window, "delete_event",
                    G_CALLBACK (on_button_quit_clicked),
                    NULL);
  g_signal_connect ((gpointer) menu_new, "activate",
                    G_CALLBACK (on_menu_new_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_open, "activate",
                    G_CALLBACK (on_menu_open_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_load_last_save, "activate",
                    G_CALLBACK (on_menu_load_last_save_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_save, "activate",
                    G_CALLBACK (on_menu_save_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_save_as, "activate",
                    G_CALLBACK (on_menu_save_as_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_quit, "activate",
                    G_CALLBACK (on_menu_quit_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_preferences, "activate",
                    G_CALLBACK (on_menu_preferences_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_job_offers, "button_press_event",
                    G_CALLBACK (on_menu_check_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) menu_live_game, "button_press_event",
                    G_CALLBACK (on_menu_check_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) menu_overwrite, "button_press_event",
                    G_CALLBACK (on_menu_check_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) menu_save_window_geometry, "activate",
                    G_CALLBACK (on_menu_save_window_geometry_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_fixtures_week, "activate",
                    G_CALLBACK (on_menu_fixtures_week_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_fixtures, "activate",
                    G_CALLBACK (on_menu_fixtures_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_tables, "activate",
                    G_CALLBACK (on_menu_tables_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_my_league_results, "activate",
                    G_CALLBACK (on_menu_my_league_results_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_season_results, "activate",
                    G_CALLBACK (on_menu_season_results_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_all_out_defend, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_defend, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_balanced, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_attack, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_all_out_attack, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_scout_best, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_scout_good, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_scout_average, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_scout_bad, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_physio_best, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_physio_good, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_physio_average, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_physio_bad, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_show_youth_academy, "activate",
                    G_CALLBACK (on_menu_show_youth_academy_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_yc_best, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_yc_good, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_yc_average, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_yc_bad, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_recruit0, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_recruit1, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_recruit2, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_recruit3, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_recruit4, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_set_investment, "activate",
                    G_CALLBACK (on_menu_set_investment_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_boost_on, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_boost_off, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_boost_anti, "button_release_event",
                    G_CALLBACK (on_menu_team_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) menu_training_camp, "activate",
                    G_CALLBACK (on_training_camp_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_reset_players, "activate",
                    G_CALLBACK (on_menu_reset_players_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_custom_structure, "activate",
                    G_CALLBACK (on_menu_custom_structure_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_rearrange_team, "activate",
                    G_CALLBACK (on_menu_rearrange_team_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_browse_teams, "activate",
                    G_CALLBACK (on_menu_browse_teams_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_show_job_exchange, "activate",
                    G_CALLBACK (on_menu_show_job_exchange_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_show_info, "activate",
                    G_CALLBACK (on_menu_show_info_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_put_on_transfer_list, "activate",
                    G_CALLBACK (on_menu_put_on_transfer_list_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_remove_from_transfer_list, "activate",
                    G_CALLBACK (on_menu_remove_from_transfer_list_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_offer_new_contract, "activate",
                    G_CALLBACK (on_menu_offer_new_contract_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_fire, "activate",
                    G_CALLBACK (on_menu_fire_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_shoots_penalties, "activate",
                    G_CALLBACK (on_menu_shoots_penalties_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_move_to_youth_academy, "activate",
                    G_CALLBACK (on_menu_move_to_youth_academy_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_edit_name, "activate",
                    G_CALLBACK (on_menu_edit_name_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_browse_players, "activate",
                    G_CALLBACK (on_menu_browse_players_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_user_show_last_match, "activate",
                    G_CALLBACK (on_menu_user_show_last_match_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_user_show_last_stats, "activate",
                    G_CALLBACK (on_menu_user_show_last_stats_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_user_show_coming_matches, "activate",
                    G_CALLBACK (on_menu_user_show_coming_matches_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_next_user, "activate",
                    G_CALLBACK (on_menu_next_user_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_previous_user, "activate",
                    G_CALLBACK (on_menu_previous_user_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_manage_users, "activate",
                    G_CALLBACK (on_menu_manage_users_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_show_finances, "activate",
                    G_CALLBACK (on_menu_show_finances_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_show_stadium, "activate",
                    G_CALLBACK (on_menu_show_stadium_activate),
                    NULL);
  g_signal_connect ((gpointer) automatic_loan_repayment, "activate",
                    G_CALLBACK (on_automatic_loan_repayment_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_betting, "activate",
                    G_CALLBACK (on_menu_betting_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_news, "activate",
                    G_CALLBACK (on_menu_news_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_league_stats, "activate",
                    G_CALLBACK (on_menu_league_stats_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_season_history, "activate",
                    G_CALLBACK (on_menu_season_history_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_user_show_history, "activate",
                    G_CALLBACK (on_menu_user_show_history_activate),
                    NULL);
  g_signal_connect ((gpointer) mm_add_last_match, "activate",
                    G_CALLBACK (on_mm_add_last_match_activate),
                    NULL);
  g_signal_connect ((gpointer) mm_manage_matches, "activate",
                    G_CALLBACK (on_mm_manage_matches_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_about, "activate",
                    G_CALLBACK (on_menu_about_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_contributors, "activate",
                    G_CALLBACK (on_menu_contributors_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_help, "activate",
                    G_CALLBACK (on_menu_help_activate),
                    NULL);
  g_signal_connect ((gpointer) button_load, "clicked",
                    G_CALLBACK (on_button_load_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_save, "clicked",
                    G_CALLBACK (on_button_save_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_quit, "clicked",
                    G_CALLBACK (on_button_quit_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_quit, "button_press_event",
                    G_CALLBACK (on_button_quit_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) button_back_to_main, "clicked",
                    G_CALLBACK (on_button_back_to_main_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_transfers, "clicked",
                    G_CALLBACK (on_button_transfers_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_new_week, "clicked",
                    G_CALLBACK (on_button_new_week_clicked),
                    NULL);
  g_signal_connect ((gpointer) eventbox_style, "button_press_event",
                    G_CALLBACK (on_eventbox_style_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) eventbox_boost, "button_press_event",
                    G_CALLBACK (on_eventbox_boost_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) hpaned2, "button_release_event",
                    G_CALLBACK (on_hpaned2_button_release_event),
                    NULL);
  g_signal_connect ((gpointer) player_list1, "button_press_event",
                    G_CALLBACK (on_player_list1_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) player_list1, "key_press_event",
                    G_CALLBACK (on_player_list1_key_press_event),
                    NULL);
  g_signal_connect ((gpointer) player_list2, "button_press_event",
                    G_CALLBACK (on_player_list1_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) button_reset_players, "clicked",
                    G_CALLBACK (on_button_reset_players_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_cl_back, "clicked",
                    G_CALLBACK (on_button_cl_back_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_cl_forward, "clicked",
                    G_CALLBACK (on_button_cl_forward_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_browse_back, "clicked",
                    G_CALLBACK (on_button_browse_back_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_browse_forward, "clicked",
                    G_CALLBACK (on_button_browse_forward_clicked),
                    NULL);
  g_signal_connect ((gpointer) treeview_right, "button_press_event",
                    G_CALLBACK (on_treeview_right_button_press_event),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window, main_window, "main_window");
  GLADE_HOOKUP_OBJECT (main_window, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (main_window, menubar1, "menubar1");
  GLADE_HOOKUP_OBJECT (main_window, menu_file, "menu_file");
  GLADE_HOOKUP_OBJECT (main_window, menu_file_menu, "menu_file_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_new, "menu_new");
  GLADE_HOOKUP_OBJECT (main_window, menu_open, "menu_open");
  GLADE_HOOKUP_OBJECT (main_window, menu_load_last_save, "menu_load_last_save");
  GLADE_HOOKUP_OBJECT (main_window, image2725, "image2725");
  GLADE_HOOKUP_OBJECT (main_window, menu_save, "menu_save");
  GLADE_HOOKUP_OBJECT (main_window, menu_save_as, "menu_save_as");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie1, "trennlinie1");
  GLADE_HOOKUP_OBJECT (main_window, menu_quit, "menu_quit");
  GLADE_HOOKUP_OBJECT (main_window, menu_options, "menu_options");
  GLADE_HOOKUP_OBJECT (main_window, menu_options_menu, "menu_options_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_preferences, "menu_preferences");
  GLADE_HOOKUP_OBJECT (main_window, image2726, "image2726");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie7, "trennlinie7");
  GLADE_HOOKUP_OBJECT (main_window, menu_job_offers, "menu_job_offers");
  GLADE_HOOKUP_OBJECT (main_window, menu_live_game, "menu_live_game");
  GLADE_HOOKUP_OBJECT (main_window, menu_overwrite, "menu_overwrite");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie14, "trennlinie14");
  GLADE_HOOKUP_OBJECT (main_window, menu_save_window_geometry, "menu_save_window_geometry");
  GLADE_HOOKUP_OBJECT (main_window, image2727, "image2727");
  GLADE_HOOKUP_OBJECT (main_window, menu_figures, "menu_figures");
  GLADE_HOOKUP_OBJECT (main_window, menu_figures_menu, "menu_figures_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_fixtures_week, "menu_fixtures_week");
  GLADE_HOOKUP_OBJECT (main_window, image2728, "image2728");
  GLADE_HOOKUP_OBJECT (main_window, menu_fixtures, "menu_fixtures");
  GLADE_HOOKUP_OBJECT (main_window, image2729, "image2729");
  GLADE_HOOKUP_OBJECT (main_window, menu_tables, "menu_tables");
  GLADE_HOOKUP_OBJECT (main_window, image2730, "image2730");
  GLADE_HOOKUP_OBJECT (main_window, menu_my_league_results, "menu_my_league_results");
  GLADE_HOOKUP_OBJECT (main_window, image2731, "image2731");
  GLADE_HOOKUP_OBJECT (main_window, menu_season_results, "menu_season_results");
  GLADE_HOOKUP_OBJECT (main_window, image2732, "image2732");
  GLADE_HOOKUP_OBJECT (main_window, menu_team, "menu_team");
  GLADE_HOOKUP_OBJECT (main_window, menu_team_menu, "menu_team_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_playing_style, "menu_playing_style");
  GLADE_HOOKUP_OBJECT (main_window, image2733, "image2733");
  GLADE_HOOKUP_OBJECT (main_window, menu_playing_style_menu, "menu_playing_style_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_all_out_defend, "menu_all_out_defend");
  GLADE_HOOKUP_OBJECT (main_window, menu_defend, "menu_defend");
  GLADE_HOOKUP_OBJECT (main_window, menu_balanced, "menu_balanced");
  GLADE_HOOKUP_OBJECT (main_window, menu_attack, "menu_attack");
  GLADE_HOOKUP_OBJECT (main_window, menu_all_out_attack, "menu_all_out_attack");
  GLADE_HOOKUP_OBJECT (main_window, menu_scout, "menu_scout");
  GLADE_HOOKUP_OBJECT (main_window, image2734, "image2734");
  GLADE_HOOKUP_OBJECT (main_window, menu_scout_menu, "menu_scout_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_scout_best, "menu_scout_best");
  GLADE_HOOKUP_OBJECT (main_window, menu_scout_good, "menu_scout_good");
  GLADE_HOOKUP_OBJECT (main_window, menu_scout_average, "menu_scout_average");
  GLADE_HOOKUP_OBJECT (main_window, menu_scout_bad, "menu_scout_bad");
  GLADE_HOOKUP_OBJECT (main_window, menu_physio, "menu_physio");
  GLADE_HOOKUP_OBJECT (main_window, image2735, "image2735");
  GLADE_HOOKUP_OBJECT (main_window, menu_physio_menu, "menu_physio_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_physio_best, "menu_physio_best");
  GLADE_HOOKUP_OBJECT (main_window, menu_physio_good, "menu_physio_good");
  GLADE_HOOKUP_OBJECT (main_window, menu_physio_average, "menu_physio_average");
  GLADE_HOOKUP_OBJECT (main_window, menu_physio_bad, "menu_physio_bad");
  GLADE_HOOKUP_OBJECT (main_window, menu_youth_academy, "menu_youth_academy");
  GLADE_HOOKUP_OBJECT (main_window, image2736, "image2736");
  GLADE_HOOKUP_OBJECT (main_window, menu_youth_academy_menu, "menu_youth_academy_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_show_youth_academy, "menu_show_youth_academy");
  GLADE_HOOKUP_OBJECT (main_window, youth_coach1, "youth_coach1");
  GLADE_HOOKUP_OBJECT (main_window, youth_coach1_menu, "youth_coach1_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_yc_best, "menu_yc_best");
  GLADE_HOOKUP_OBJECT (main_window, menu_yc_good, "menu_yc_good");
  GLADE_HOOKUP_OBJECT (main_window, menu_yc_average, "menu_yc_average");
  GLADE_HOOKUP_OBJECT (main_window, menu_yc_bad, "menu_yc_bad");
  GLADE_HOOKUP_OBJECT (main_window, recruiting_preference1, "recruiting_preference1");
  GLADE_HOOKUP_OBJECT (main_window, recruiting_preference1_menu, "recruiting_preference1_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_recruit0, "menu_recruit0");
  GLADE_HOOKUP_OBJECT (main_window, menu_recruit1, "menu_recruit1");
  GLADE_HOOKUP_OBJECT (main_window, menu_recruit2, "menu_recruit2");
  GLADE_HOOKUP_OBJECT (main_window, menu_recruit3, "menu_recruit3");
  GLADE_HOOKUP_OBJECT (main_window, menu_recruit4, "menu_recruit4");
  GLADE_HOOKUP_OBJECT (main_window, menu_set_investment, "menu_set_investment");
  GLADE_HOOKUP_OBJECT (main_window, menu_boost, "menu_boost");
  GLADE_HOOKUP_OBJECT (main_window, image2737, "image2737");
  GLADE_HOOKUP_OBJECT (main_window, menu_boost_menu, "menu_boost_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_boost_on, "menu_boost_on");
  GLADE_HOOKUP_OBJECT (main_window, menu_boost_off, "menu_boost_off");
  GLADE_HOOKUP_OBJECT (main_window, menu_boost_anti, "menu_boost_anti");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie11, "trennlinie11");
  GLADE_HOOKUP_OBJECT (main_window, menu_training_camp, "menu_training_camp");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie18, "trennlinie18");
  GLADE_HOOKUP_OBJECT (main_window, menu_reset_players, "menu_reset_players");
  GLADE_HOOKUP_OBJECT (main_window, image2738, "image2738");
  GLADE_HOOKUP_OBJECT (main_window, menu_custom_structure, "menu_custom_structure");
  GLADE_HOOKUP_OBJECT (main_window, image2739, "image2739");
  GLADE_HOOKUP_OBJECT (main_window, menu_rearrange_team, "menu_rearrange_team");
  GLADE_HOOKUP_OBJECT (main_window, image2740, "image2740");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie8, "trennlinie8");
  GLADE_HOOKUP_OBJECT (main_window, menu_browse_teams, "menu_browse_teams");
  GLADE_HOOKUP_OBJECT (main_window, image2741, "image2741");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie16, "trennlinie16");
  GLADE_HOOKUP_OBJECT (main_window, menu_show_job_exchange, "menu_show_job_exchange");
  GLADE_HOOKUP_OBJECT (main_window, menu_player, "menu_player");
  GLADE_HOOKUP_OBJECT (main_window, menu_player_menu, "menu_player_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_show_info, "menu_show_info");
  GLADE_HOOKUP_OBJECT (main_window, image2742, "image2742");
  GLADE_HOOKUP_OBJECT (main_window, menu_put_on_transfer_list, "menu_put_on_transfer_list");
  GLADE_HOOKUP_OBJECT (main_window, image2743, "image2743");
  GLADE_HOOKUP_OBJECT (main_window, menu_remove_from_transfer_list, "menu_remove_from_transfer_list");
  GLADE_HOOKUP_OBJECT (main_window, image2744, "image2744");
  GLADE_HOOKUP_OBJECT (main_window, menu_offer_new_contract, "menu_offer_new_contract");
  GLADE_HOOKUP_OBJECT (main_window, image2745, "image2745");
  GLADE_HOOKUP_OBJECT (main_window, menu_fire, "menu_fire");
  GLADE_HOOKUP_OBJECT (main_window, image2746, "image2746");
  GLADE_HOOKUP_OBJECT (main_window, menu_shoots_penalties, "menu_shoots_penalties");
  GLADE_HOOKUP_OBJECT (main_window, image2747, "image2747");
  GLADE_HOOKUP_OBJECT (main_window, menu_move_to_youth_academy, "menu_move_to_youth_academy");
  GLADE_HOOKUP_OBJECT (main_window, image2748, "image2748");
  GLADE_HOOKUP_OBJECT (main_window, menu_edit_name, "menu_edit_name");
  GLADE_HOOKUP_OBJECT (main_window, image2749, "image2749");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie10, "trennlinie10");
  GLADE_HOOKUP_OBJECT (main_window, menu_browse_players, "menu_browse_players");
  GLADE_HOOKUP_OBJECT (main_window, image2750, "image2750");
  GLADE_HOOKUP_OBJECT (main_window, menu_user, "menu_user");
  GLADE_HOOKUP_OBJECT (main_window, menu_user_menu, "menu_user_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_user_show_last_match, "menu_user_show_last_match");
  GLADE_HOOKUP_OBJECT (main_window, image2751, "image2751");
  GLADE_HOOKUP_OBJECT (main_window, menu_user_show_last_stats, "menu_user_show_last_stats");
  GLADE_HOOKUP_OBJECT (main_window, image2752, "image2752");
  GLADE_HOOKUP_OBJECT (main_window, menu_user_show_coming_matches, "menu_user_show_coming_matches");
  GLADE_HOOKUP_OBJECT (main_window, image2753, "image2753");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie9, "trennlinie9");
  GLADE_HOOKUP_OBJECT (main_window, menu_next_user, "menu_next_user");
  GLADE_HOOKUP_OBJECT (main_window, image2754, "image2754");
  GLADE_HOOKUP_OBJECT (main_window, menu_previous_user, "menu_previous_user");
  GLADE_HOOKUP_OBJECT (main_window, image2755, "image2755");
  GLADE_HOOKUP_OBJECT (main_window, menu_manage_users, "menu_manage_users");
  GLADE_HOOKUP_OBJECT (main_window, image2756, "image2756");
  GLADE_HOOKUP_OBJECT (main_window, menu_finances_stadium, "menu_finances_stadium");
  GLADE_HOOKUP_OBJECT (main_window, menu_finances_stadium_menu, "menu_finances_stadium_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_show_finances, "menu_show_finances");
  GLADE_HOOKUP_OBJECT (main_window, image2757, "image2757");
  GLADE_HOOKUP_OBJECT (main_window, menu_show_stadium, "menu_show_stadium");
  GLADE_HOOKUP_OBJECT (main_window, image2758, "image2758");
  GLADE_HOOKUP_OBJECT (main_window, automatic_loan_repayment, "automatic_loan_repayment");
  GLADE_HOOKUP_OBJECT (main_window, trennlinie15, "trennlinie15");
  GLADE_HOOKUP_OBJECT (main_window, menu_betting, "menu_betting");
  GLADE_HOOKUP_OBJECT (main_window, stats1, "stats1");
  GLADE_HOOKUP_OBJECT (main_window, stats1_menu, "stats1_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_news, "menu_news");
  GLADE_HOOKUP_OBJECT (main_window, menu_league_stats, "menu_league_stats");
  GLADE_HOOKUP_OBJECT (main_window, image2759, "image2759");
  GLADE_HOOKUP_OBJECT (main_window, menu_season_history, "menu_season_history");
  GLADE_HOOKUP_OBJECT (main_window, image2760, "image2760");
  GLADE_HOOKUP_OBJECT (main_window, menu_user_show_history, "menu_user_show_history");
  GLADE_HOOKUP_OBJECT (main_window, image2761, "image2761");
  GLADE_HOOKUP_OBJECT (main_window, memorable_matches, "memorable_matches");
  GLADE_HOOKUP_OBJECT (main_window, image2762, "image2762");
  GLADE_HOOKUP_OBJECT (main_window, memorable_matches_menu, "memorable_matches_menu");
  GLADE_HOOKUP_OBJECT (main_window, mm_add_last_match, "mm_add_last_match");
  GLADE_HOOKUP_OBJECT (main_window, image2763, "image2763");
  GLADE_HOOKUP_OBJECT (main_window, mm_manage_matches, "mm_manage_matches");
  GLADE_HOOKUP_OBJECT (main_window, image2764, "image2764");
  GLADE_HOOKUP_OBJECT (main_window, menu_help1, "menu_help1");
  GLADE_HOOKUP_OBJECT (main_window, menu_help1_menu, "menu_help1_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_about, "menu_about");
  GLADE_HOOKUP_OBJECT (main_window, image2765, "image2765");
  GLADE_HOOKUP_OBJECT (main_window, menu_contributors, "menu_contributors");
  GLADE_HOOKUP_OBJECT (main_window, image2766, "image2766");
  GLADE_HOOKUP_OBJECT (main_window, menu_help, "menu_help");
  GLADE_HOOKUP_OBJECT (main_window, image2767, "image2767");
  GLADE_HOOKUP_OBJECT (main_window, hbox1, "hbox1");
  GLADE_HOOKUP_OBJECT (main_window, button_load, "button_load");
  GLADE_HOOKUP_OBJECT (main_window, image11, "image11");
  GLADE_HOOKUP_OBJECT (main_window, button_save, "button_save");
  GLADE_HOOKUP_OBJECT (main_window, image12, "image12");
  GLADE_HOOKUP_OBJECT (main_window, button_quit, "button_quit");
  GLADE_HOOKUP_OBJECT (main_window, image13, "image13");
  GLADE_HOOKUP_OBJECT (main_window, vseparator1, "vseparator1");
  GLADE_HOOKUP_OBJECT (main_window, vseparator11, "vseparator11");
  GLADE_HOOKUP_OBJECT (main_window, button_back_to_main, "button_back_to_main");
  GLADE_HOOKUP_OBJECT (main_window, image20, "image20");
  GLADE_HOOKUP_OBJECT (main_window, button_transfers, "button_transfers");
  GLADE_HOOKUP_OBJECT (main_window, image32, "image32");
  GLADE_HOOKUP_OBJECT (main_window, vseparator16, "vseparator16");
  GLADE_HOOKUP_OBJECT (main_window, button_new_week, "button_new_week");
  GLADE_HOOKUP_OBJECT (main_window, image23, "image23");
  GLADE_HOOKUP_OBJECT (main_window, entry_message, "entry_message");
  GLADE_HOOKUP_OBJECT (main_window, hseparator1, "hseparator1");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_main_info, "eventbox_main_info");
  GLADE_HOOKUP_OBJECT (main_window, hbox18, "hbox18");
  GLADE_HOOKUP_OBJECT (main_window, label_user, "label_user");
  GLADE_HOOKUP_OBJECT (main_window, label23, "label23");
  GLADE_HOOKUP_OBJECT (main_window, label_season, "label_season");
  GLADE_HOOKUP_OBJECT (main_window, label25, "label25");
  GLADE_HOOKUP_OBJECT (main_window, label_week, "label_week");
  GLADE_HOOKUP_OBJECT (main_window, label13114, "label13114");
  GLADE_HOOKUP_OBJECT (main_window, label_round, "label_round");
  GLADE_HOOKUP_OBJECT (main_window, vseparator14, "vseparator14");
  GLADE_HOOKUP_OBJECT (main_window, hbox48, "hbox48");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_style, "eventbox_style");
  GLADE_HOOKUP_OBJECT (main_window, image_style, "image_style");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_boost, "eventbox_boost");
  GLADE_HOOKUP_OBJECT (main_window, image_boost, "image_boost");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_team_name, "eventbox_team_name");
  GLADE_HOOKUP_OBJECT (main_window, label_team, "label_team");
  GLADE_HOOKUP_OBJECT (main_window, label_league, "label_league");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_rank, "eventbox_rank");
  GLADE_HOOKUP_OBJECT (main_window, hbox49, "hbox49");
  GLADE_HOOKUP_OBJECT (main_window, label29, "label29");
  GLADE_HOOKUP_OBJECT (main_window, label_rank, "label_rank");
  GLADE_HOOKUP_OBJECT (main_window, vseparator15, "vseparator15");
  GLADE_HOOKUP_OBJECT (main_window, label34, "label34");
  GLADE_HOOKUP_OBJECT (main_window, label_money, "label_money");
  GLADE_HOOKUP_OBJECT (main_window, vseparator17, "vseparator17");
  GLADE_HOOKUP_OBJECT (main_window, eventbox1, "eventbox1");
  GLADE_HOOKUP_OBJECT (main_window, hbox50, "hbox50");
  GLADE_HOOKUP_OBJECT (main_window, label69, "label69");
  GLADE_HOOKUP_OBJECT (main_window, label_av_skills, "label_av_skills");
  GLADE_HOOKUP_OBJECT (main_window, hbox7, "hbox7");
  GLADE_HOOKUP_OBJECT (main_window, hpaned2, "hpaned2");
  GLADE_HOOKUP_OBJECT (main_window, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (main_window, scrolledwindow2, "scrolledwindow2");
  GLADE_HOOKUP_OBJECT (main_window, viewport1, "viewport1");
  GLADE_HOOKUP_OBJECT (main_window, notebook_player, "notebook_player");
  GLADE_HOOKUP_OBJECT (main_window, player_list1, "player_list1");
  GLADE_HOOKUP_OBJECT (main_window, label71, "label71");
  GLADE_HOOKUP_OBJECT (main_window, player_list2, "player_list2");
  GLADE_HOOKUP_OBJECT (main_window, label72, "label72");
  GLADE_HOOKUP_OBJECT (main_window, button_reset_players, "button_reset_players");
  GLADE_HOOKUP_OBJECT (main_window, image298, "image298");
  GLADE_HOOKUP_OBJECT (main_window, vbox8, "vbox8");
  GLADE_HOOKUP_OBJECT (main_window, hbox_14, "hbox_14");
  GLADE_HOOKUP_OBJECT (main_window, button_cl_back, "button_cl_back");
  GLADE_HOOKUP_OBJECT (main_window, image215, "image215");
  GLADE_HOOKUP_OBJECT (main_window, button_cl_forward, "button_cl_forward");
  GLADE_HOOKUP_OBJECT (main_window, image216, "image216");
  GLADE_HOOKUP_OBJECT (main_window, button_browse_back, "button_browse_back");
  GLADE_HOOKUP_OBJECT (main_window, image10, "image10");
  GLADE_HOOKUP_OBJECT (main_window, button_browse_forward, "button_browse_forward");
  GLADE_HOOKUP_OBJECT (main_window, image9, "image9");
  GLADE_HOOKUP_OBJECT (main_window, scrolledwindow3, "scrolledwindow3");
  GLADE_HOOKUP_OBJECT (main_window, treeview_right, "treeview_right");
  GLADE_HOOKUP_OBJECT_NO_REF (main_window, tooltips, "tooltips");

  gtk_widget_grab_focus (hbox1);
  gtk_window_add_accel_group (GTK_WINDOW (main_window), accel_group);

  return main_window;
}

GtkWidget*
create_menu_player (void)
{
  GtkWidget *menu_player;
  GtkWidget *player_menu_show_info;
  GtkWidget *player_menu_put_on_transfer_list;
  GtkWidget *player_menu_remove_from_transfer_list;
  GtkWidget *player_menu_offer_new_contract;
  GtkWidget *player_menu_fire;
  GtkWidget *player_menu_shoots_penalties;
  GtkWidget *player_menu_move_to_youth_academy;
  GtkWidget *player_menu_edit_name;

  menu_player = gtk_menu_new ();

  player_menu_show_info = gtk_menu_item_new_with_mnemonic (_("Show info"));
  gtk_widget_show (player_menu_show_info);
  gtk_container_add (GTK_CONTAINER (menu_player), player_menu_show_info);

  player_menu_put_on_transfer_list = gtk_menu_item_new_with_mnemonic (_("Put on transfer list"));
  gtk_widget_show (player_menu_put_on_transfer_list);
  gtk_container_add (GTK_CONTAINER (menu_player), player_menu_put_on_transfer_list);

  player_menu_remove_from_transfer_list = gtk_menu_item_new_with_mnemonic (_("Remove from transfer list"));
  gtk_widget_show (player_menu_remove_from_transfer_list);
  gtk_container_add (GTK_CONTAINER (menu_player), player_menu_remove_from_transfer_list);

  player_menu_offer_new_contract = gtk_menu_item_new_with_mnemonic (_("Offer new contract"));
  gtk_widget_show (player_menu_offer_new_contract);
  gtk_container_add (GTK_CONTAINER (menu_player), player_menu_offer_new_contract);

  player_menu_fire = gtk_menu_item_new_with_mnemonic (_("Fire"));
  gtk_widget_show (player_menu_fire);
  gtk_container_add (GTK_CONTAINER (menu_player), player_menu_fire);

  player_menu_shoots_penalties = gtk_menu_item_new_with_mnemonic (_("Shoots penalties"));
  gtk_widget_show (player_menu_shoots_penalties);
  gtk_container_add (GTK_CONTAINER (menu_player), player_menu_shoots_penalties);

  player_menu_move_to_youth_academy = gtk_menu_item_new_with_mnemonic (_("Move to youth academy"));
  gtk_widget_show (player_menu_move_to_youth_academy);
  gtk_container_add (GTK_CONTAINER (menu_player), player_menu_move_to_youth_academy);

  player_menu_edit_name = gtk_menu_item_new_with_mnemonic (_("Edit name"));
  gtk_widget_show (player_menu_edit_name);
  gtk_container_add (GTK_CONTAINER (menu_player), player_menu_edit_name);

  g_signal_connect ((gpointer) player_menu_show_info, "activate",
                    G_CALLBACK (on_player_menu_show_info_activate),
                    NULL);
  g_signal_connect ((gpointer) player_menu_put_on_transfer_list, "activate",
                    G_CALLBACK (on_player_menu_put_on_transfer_list_activate),
                    NULL);
  g_signal_connect ((gpointer) player_menu_remove_from_transfer_list, "activate",
                    G_CALLBACK (on_player_menu_remove_from_transfer_list_activate),
                    NULL);
  g_signal_connect ((gpointer) player_menu_offer_new_contract, "activate",
                    G_CALLBACK (on_player_menu_offer_new_contract_activate),
                    NULL);
  g_signal_connect ((gpointer) player_menu_fire, "activate",
                    G_CALLBACK (on_player_menu_fire_activate),
                    NULL);
  g_signal_connect ((gpointer) player_menu_shoots_penalties, "activate",
                    G_CALLBACK (on_player_menu_shoots_penalties_activate),
                    NULL);
  g_signal_connect ((gpointer) player_menu_move_to_youth_academy, "activate",
                    G_CALLBACK (on_player_menu_move_to_youth_academy_activate),
                    NULL);
  g_signal_connect ((gpointer) player_menu_edit_name, "activate",
                    G_CALLBACK (on_player_menu_edit_name_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (menu_player, menu_player, "menu_player");
  GLADE_HOOKUP_OBJECT (menu_player, player_menu_show_info, "player_menu_show_info");
  GLADE_HOOKUP_OBJECT (menu_player, player_menu_put_on_transfer_list, "player_menu_put_on_transfer_list");
  GLADE_HOOKUP_OBJECT (menu_player, player_menu_remove_from_transfer_list, "player_menu_remove_from_transfer_list");
  GLADE_HOOKUP_OBJECT (menu_player, player_menu_offer_new_contract, "player_menu_offer_new_contract");
  GLADE_HOOKUP_OBJECT (menu_player, player_menu_fire, "player_menu_fire");
  GLADE_HOOKUP_OBJECT (menu_player, player_menu_shoots_penalties, "player_menu_shoots_penalties");
  GLADE_HOOKUP_OBJECT (menu_player, player_menu_move_to_youth_academy, "player_menu_move_to_youth_academy");
  GLADE_HOOKUP_OBJECT (menu_player, player_menu_edit_name, "player_menu_edit_name");

  return menu_player;
}

GtkWidget*
create_menu_youth (void)
{
  GtkWidget *menu_youth;
  GtkWidget *menu_youth_move_to_team;
  GtkWidget *image2149;
  GtkWidget *menu_youth_kick_out_of_academy;
  GtkWidget *image2150;

  menu_youth = gtk_menu_new ();

  menu_youth_move_to_team = gtk_image_menu_item_new_with_mnemonic (_("Move to team"));
  gtk_widget_show (menu_youth_move_to_team);
  gtk_container_add (GTK_CONTAINER (menu_youth), menu_youth_move_to_team);

  image2149 = create_pixmap (menu_youth, "menu_player_move_to_team.png");
  gtk_widget_show (image2149);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_youth_move_to_team), image2149);

  menu_youth_kick_out_of_academy = gtk_image_menu_item_new_with_mnemonic (_("Kick out of academy"));
  gtk_widget_show (menu_youth_kick_out_of_academy);
  gtk_container_add (GTK_CONTAINER (menu_youth), menu_youth_kick_out_of_academy);

  image2150 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image2150);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_youth_kick_out_of_academy), image2150);

  g_signal_connect ((gpointer) menu_youth_move_to_team, "activate",
                    G_CALLBACK (on_menu_youth_move_to_team_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_youth_kick_out_of_academy, "activate",
                    G_CALLBACK (on_menu_youth_kick_out_of_academy_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (menu_youth, menu_youth, "menu_youth");
  GLADE_HOOKUP_OBJECT (menu_youth, menu_youth_move_to_team, "menu_youth_move_to_team");
  GLADE_HOOKUP_OBJECT (menu_youth, image2149, "image2149");
  GLADE_HOOKUP_OBJECT (menu_youth, menu_youth_kick_out_of_academy, "menu_youth_kick_out_of_academy");
  GLADE_HOOKUP_OBJECT (menu_youth, image2150, "image2150");

  return menu_youth;
}

