/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

GtkWidget* create_window_startup (void);
GtkWidget* create_window_font_sel (void);
GtkWidget* create_window_live (void);
GtkWidget* create_window_stadium (void);
GtkWidget* create_window_file_chooser (void);
GtkWidget* create_window_sponsors (void);
