/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "options_callbacks.h"
#include "options_interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

GtkWidget*
create_window_options (void)
{
  GtkWidget *window_options;
  GtkWidget *vbox1;
  GtkWidget *notebook1;
  GtkWidget *hbox2;
  GtkWidget *vbox3;
  GtkWidget *checkbutton_conf_quit;
  GtkWidget *checkbutton_conf_unfit;
  GtkWidget *checkbutton_save_overwrite;
  GtkWidget *hseparator5;
  GtkWidget *checkbutton_maximize;
  GtkWidget *checkbutton_pref_mess;
  GtkWidget *checkbutton_show_progress_pics;
  GtkWidget *hseparator6;
  GtkWidget *checkbutton_skip;
  GtkWidget *vseparator1;
  GtkWidget *table1;
  GtkWidget *hbox3;
  GtkWidget *label6;
  GtkObject *spinbutton_autosave_adj;
  GtkWidget *spinbutton_autosave;
  GtkWidget *label36;
  GtkObject *spinbutton_autosave_files_adj;
  GtkWidget *spinbutton_autosave_files;
  GtkWidget *label7;
  GtkWidget *label8;
  GtkWidget *label10;
  GtkWidget *button_font_name;
  GtkWidget *alignment1;
  GtkWidget *hbox7;
  GtkWidget *image1;
  GtkWidget *label34;
  GtkWidget *hbox8;
  GtkWidget *entry_constants_file;
  GtkWidget *button_reload_constants;
  GtkWidget *alignment2;
  GtkWidget *hbox9;
  GtkWidget *image2;
  GtkWidget *label35;
  GtkWidget *button_edit_constants;
  GtkWidget *alignment3;
  GtkWidget *hbox19;
  GtkWidget *image3;
  GtkWidget *label49;
  GtkWidget *label40;
  GtkWidget *checkbutton_autosave;
  GtkObject *spinbutton_precision_adj;
  GtkWidget *spinbutton_precision;
  GtkObject *spinbutton_refresh_adj;
  GtkWidget *spinbutton_refresh;
  GtkWidget *entry_font_name;
  GtkWidget *eventbox2;
  GtkWidget *combobox_languages;
  GtkWidget *label1;
  GtkWidget *hbox6;
  GtkWidget *vbox6;
  GtkWidget *checkbutton_conf_youth;
  GtkWidget *checkbutton_show_job;
  GtkWidget *eventbox1;
  GtkWidget *hbox10;
  GtkWidget *label37;
  GtkObject *spinbutton_contract_adj;
  GtkWidget *spinbutton_contract;
  GtkWidget *label38;
  GtkWidget *checkbutton_show_all_leagues;
  GtkWidget *vseparator3;
  GtkWidget *alignment7;
  GtkWidget *vbox7;
  GtkWidget *checkbutton_swap_adapts;
  GtkWidget *checkbutton_show_overall;
  GtkWidget *checkbutton_store_restore_default_team;
  GtkWidget *label3;
  GtkWidget *hbox4;
  GtkWidget *vbox4;
  GtkWidget *checkbutton_show_live;
  GtkWidget *checkbutton_show_tendency;
  GtkWidget *table3;
  GtkWidget *label12;
  GtkWidget *label39;
  GtkObject *spinbutton_live_speed_adj;
  GtkWidget *spinbutton_live_speed;
  GtkObject *spinbutton_live_verbosity_adj;
  GtkWidget *spinbutton_live_verbosity;
  GtkWidget *checkbutton_auto_sub;
  GtkWidget *vseparator2;
  GtkWidget *vbox5;
  GtkWidget *checkbutton_pause_injury;
  GtkWidget *checkbutton_pause_red;
  GtkWidget *checkbutton_pause_break;
  GtkWidget *label2;
  GtkWidget *table2;
  GtkWidget *label13;
  GtkWidget *label14;
  GtkWidget *label15;
  GtkWidget *label16;
  GtkWidget *label17;
  GtkWidget *label18;
  GtkWidget *label19;
  GtkWidget *label20;
  GtkWidget *label21;
  GtkWidget *label22;
  GtkWidget *label23;
  GtkWidget *label24;
  GtkWidget *label25;
  GtkWidget *label26;
  GtkWidget *label27;
  GtkWidget *label28;
  GtkWidget *label29;
  GtkWidget *label30;
  GtkWidget *checkbutton1;
  GtkWidget *checkbutton20;
  GtkWidget *checkbutton2;
  GtkWidget *checkbutton3;
  GtkWidget *checkbutton4;
  GtkWidget *checkbutton5;
  GtkWidget *checkbutton6;
  GtkWidget *checkbutton7;
  GtkWidget *checkbutton8;
  GtkWidget *checkbutton9;
  GtkWidget *checkbutton10;
  GtkWidget *checkbutton11;
  GtkWidget *checkbutton12;
  GtkWidget *checkbutton13;
  GtkWidget *checkbutton14;
  GtkWidget *checkbutton15;
  GtkWidget *checkbutton16;
  GtkWidget *checkbutton17;
  GtkWidget *checkbutton18;
  GtkWidget *checkbutton19;
  GtkWidget *checkbutton21;
  GtkWidget *checkbutton22;
  GtkWidget *checkbutton23;
  GtkWidget *checkbutton24;
  GtkWidget *checkbutton25;
  GtkWidget *checkbutton26;
  GtkWidget *checkbutton27;
  GtkWidget *checkbutton28;
  GtkWidget *checkbutton29;
  GtkWidget *checkbutton30;
  GtkWidget *checkbutton31;
  GtkWidget *checkbutton32;
  GtkWidget *checkbutton33;
  GtkWidget *checkbutton34;
  GtkWidget *checkbutton35;
  GtkWidget *checkbutton36;
  GtkWidget *hseparator3;
  GtkWidget *hseparator4;
  GtkWidget *label31;
  GtkWidget *label32;
  GtkWidget *label33;
  GtkWidget *hseparator2;
  GtkWidget *label4;
  GtkWidget *hbox11;
  GtkWidget *vbox8;
  GtkWidget *checkbutton_bet_show_all_leagues;
  GtkWidget *checkbutton_bet_show_cups;
  GtkWidget *checkbutton_bet_show_only_recent;
  GtkWidget *hbox12;
  GtkWidget *label42;
  GtkObject *spinbutton_bet_wager_adj;
  GtkWidget *spinbutton_bet_wager;
  GtkWidget *label41;
  GtkWidget *vbox9;
  GtkWidget *hbox13;
  GtkWidget *label44;
  GtkWidget *combobox_hotel;
  GtkWidget *vbox10;
  GtkWidget *hseparator7;
  GtkWidget *hbox15;
  GtkWidget *label45;
  GtkObject *spinbutton_recreation_adj;
  GtkWidget *spinbutton_recreation;
  GtkWidget *hseparator8;
  GtkWidget *hbox16;
  GtkWidget *label47;
  GtkWidget *label_training;
  GtkWidget *label43;
  GtkWidget *vbox11;
  GtkWidget *hbox17;
  GtkWidget *checkbutton_news_user;
  GtkWidget *checkbutton_news_cup;
  GtkWidget *checkbutton_news_league;
  GtkWidget *checkbutton_news_recent;
  GtkWidget *hbox18;
  GtkWidget *radiobutton_news_popup_no;
  GSList *radiobutton_news_popup_no_group = NULL;
  GtkWidget *radiobutton_news_popup_user;
  GtkWidget *radiobutton_news_popup_always;
  GtkWidget *label48;
  GtkWidget *hseparator1;
  GtkWidget *hbox1;
  GtkWidget *vbox2;
  GtkWidget *checkbutton_save_global;
  GtkWidget *checkbutton_save_user;
  GtkWidget *button_ok;
  GtkWidget *button_cancel;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  window_options = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_options), 5);
  gtk_window_set_position (GTK_WINDOW (window_options), GTK_WIN_POS_CENTER);

  vbox1 = gtk_vbox_new (FALSE, 2);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (window_options), vbox1);

  notebook1 = gtk_notebook_new ();
  gtk_widget_show (notebook1);
  gtk_box_pack_start (GTK_BOX (vbox1), notebook1, TRUE, TRUE, 0);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (notebook1), hbox2);
  gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook1), hbox2,
                                      FALSE, FALSE, GTK_PACK_START);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox3);
  gtk_box_pack_start (GTK_BOX (hbox2), vbox3, TRUE, TRUE, 0);

  checkbutton_conf_quit = gtk_check_button_new_with_mnemonic (_("Confirm quit when not saved"));
  gtk_widget_show (checkbutton_conf_quit);
  gtk_box_pack_start (GTK_BOX (vbox3), checkbutton_conf_quit, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_conf_quit, _("Whether to show a confirmation popup when you press quit and the game state is not saved"), NULL);

  checkbutton_conf_unfit = gtk_check_button_new_with_mnemonic (_("Confirm when unfit"));
  gtk_widget_show (checkbutton_conf_unfit);
  gtk_box_pack_start (GTK_BOX (vbox3), checkbutton_conf_unfit, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_conf_unfit, _("Whether to show a confirmation popup if a user team has an injured or banned player in the startup formation"), NULL);

  checkbutton_save_overwrite = gtk_check_button_new_with_mnemonic (_("Save overwrites"));
  gtk_widget_show (checkbutton_save_overwrite);
  gtk_box_pack_start (GTK_BOX (vbox3), checkbutton_save_overwrite, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_save_overwrite, _("Whether 'Save' overwrites the current save file or pops up a 'Save as' window"), NULL);

  hseparator5 = gtk_hseparator_new ();
  gtk_widget_show (hseparator5);
  gtk_box_pack_start (GTK_BOX (vbox3), hseparator5, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator5, 1, 10);

  checkbutton_maximize = gtk_check_button_new_with_mnemonic (_("Maximize main window"));
  gtk_widget_show (checkbutton_maximize);
  gtk_box_pack_start (GTK_BOX (vbox3), checkbutton_maximize, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_maximize, _("Whether game starts with a maximized main window (doesn't work with all window managers)"), NULL);

  checkbutton_pref_mess = gtk_check_button_new_with_mnemonic (_("Prefer messages"));
  gtk_widget_show (checkbutton_pref_mess);
  gtk_box_pack_start (GTK_BOX (vbox3), checkbutton_pref_mess, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_pref_mess, _("Whether to show warnings and such in the message area in the main window when possible"), NULL);

  checkbutton_show_progress_pics = gtk_check_button_new_with_mnemonic (_("Show progressbar pictures"));
  gtk_widget_show (checkbutton_show_progress_pics);
  gtk_box_pack_start (GTK_BOX (vbox3), checkbutton_show_progress_pics, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_show_progress_pics, _("Whether to show pictures on top of the progressbar when loading/saving or calculating results"), NULL);

  hseparator6 = gtk_hseparator_new ();
  gtk_widget_show (hseparator6);
  gtk_box_pack_start (GTK_BOX (vbox3), hseparator6, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator6, 1, 10);

  checkbutton_skip = gtk_check_button_new_with_mnemonic (_("Skip weeks without user matches"));
  gtk_widget_show (checkbutton_skip);
  gtk_box_pack_start (GTK_BOX (vbox3), checkbutton_skip, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_skip, _("If checked, weeks without user teams playing are calculated automatically (without the user having to press 'New week')"), NULL);

  vseparator1 = gtk_vseparator_new ();
  gtk_widget_show (vseparator1);
  gtk_box_pack_start (GTK_BOX (hbox2), vseparator1, FALSE, FALSE, 0);
  gtk_widget_set_size_request (vseparator1, 10, 1);

  table1 = gtk_table_new (6, 2, FALSE);
  gtk_widget_show (table1);
  gtk_box_pack_start (GTK_BOX (hbox2), table1, FALSE, FALSE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table1), 1);
  gtk_table_set_col_spacings (GTK_TABLE (table1), 5);

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox3);
  gtk_table_attach (GTK_TABLE (table1), hbox3, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label6 = gtk_label_new (_("Autosave interval "));
  gtk_widget_show (label6);
  gtk_box_pack_start (GTK_BOX (hbox3), label6, FALSE, FALSE, 0);

  spinbutton_autosave_adj = gtk_adjustment_new (1, 1, 20, 1, 10, 0);
  spinbutton_autosave = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_autosave_adj), 1, 0);
  gtk_widget_show (spinbutton_autosave);
  gtk_box_pack_start (GTK_BOX (hbox3), spinbutton_autosave, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_autosave, _("How often the game is saved automatically"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_autosave), TRUE);

  label36 = gtk_label_new (_(" Autosave files "));
  gtk_widget_show (label36);
  gtk_box_pack_start (GTK_BOX (hbox3), label36, FALSE, FALSE, 0);

  spinbutton_autosave_files_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_autosave_files = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_autosave_files_adj), 1, 0);
  gtk_widget_show (spinbutton_autosave_files);
  gtk_box_pack_start (GTK_BOX (hbox3), spinbutton_autosave_files, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_autosave_files, _("How many files the autosave uses"), NULL);

  label7 = gtk_label_new (_("Player attribute precision"));
  gtk_widget_show (label7);
  gtk_table_attach (GTK_TABLE (table1), label7, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label7), 1, 0.5);

  label8 = gtk_label_new (_("Player list refresh rate"));
  gtk_widget_show (label8);
  gtk_table_attach (GTK_TABLE (table1), label8, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8), 1, 0.5);

  label10 = gtk_label_new (_("Constants file"));
  gtk_widget_show (label10);
  gtk_table_attach (GTK_TABLE (table1), label10, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label10), 1, 0.5);

  button_font_name = gtk_button_new ();
  gtk_widget_show (button_font_name);
  gtk_table_attach (GTK_TABLE (table1), button_font_name, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, button_font_name, _("Font used in treeviews"), NULL);

  alignment1 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment1);
  gtk_container_add (GTK_CONTAINER (button_font_name), alignment1);

  hbox7 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox7);
  gtk_container_add (GTK_CONTAINER (alignment1), hbox7);

  image1 = gtk_image_new_from_stock ("gtk-select-font", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image1);
  gtk_box_pack_start (GTK_BOX (hbox7), image1, FALSE, FALSE, 0);

  label34 = gtk_label_new_with_mnemonic (_("Font name"));
  gtk_widget_show (label34);
  gtk_box_pack_start (GTK_BOX (hbox7), label34, FALSE, FALSE, 0);

  hbox8 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox8);
  gtk_table_attach (GTK_TABLE (table1), hbox8, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  entry_constants_file = gtk_entry_new ();
  gtk_widget_show (entry_constants_file);
  gtk_box_pack_start (GTK_BOX (hbox8), entry_constants_file, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, entry_constants_file, _("File containing settings which determine a lot of aspects of the game behaviour. DON'T CHANGE THIS UNLESS YOU REALLY KNOW WHAT YOU ARE DOING."), NULL);

  button_reload_constants = gtk_button_new ();
  gtk_widget_show (button_reload_constants);
  gtk_box_pack_start (GTK_BOX (hbox8), button_reload_constants, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_reload_constants, _("Reload the constants file"), NULL);

  alignment2 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment2);
  gtk_container_add (GTK_CONTAINER (button_reload_constants), alignment2);

  hbox9 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox9);
  gtk_container_add (GTK_CONTAINER (alignment2), hbox9);

  image2 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image2);
  gtk_box_pack_start (GTK_BOX (hbox9), image2, FALSE, FALSE, 0);

  label35 = gtk_label_new_with_mnemonic (_("Reload"));
  gtk_widget_show (label35);
  gtk_box_pack_start (GTK_BOX (hbox9), label35, FALSE, FALSE, 0);

  button_edit_constants = gtk_button_new ();
  gtk_widget_show (button_edit_constants);
  gtk_box_pack_start (GTK_BOX (hbox8), button_edit_constants, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_edit_constants, _("Edit the constants used in the game"), NULL);

  alignment3 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment3);
  gtk_container_add (GTK_CONTAINER (button_edit_constants), alignment3);

  hbox19 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox19);
  gtk_container_add (GTK_CONTAINER (alignment3), hbox19);

  image3 = gtk_image_new_from_stock ("gtk-edit", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image3);
  gtk_box_pack_start (GTK_BOX (hbox19), image3, FALSE, FALSE, 0);

  label49 = gtk_label_new_with_mnemonic (_("Edit"));
  gtk_widget_show (label49);
  gtk_box_pack_start (GTK_BOX (hbox19), label49, FALSE, FALSE, 0);

  label40 = gtk_label_new (_("Language"));
  gtk_widget_show (label40);
  gtk_table_attach (GTK_TABLE (table1), label40, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label40), 1, 0.5);

  checkbutton_autosave = gtk_check_button_new_with_mnemonic (_("Autosave"));
  gtk_widget_show (checkbutton_autosave);
  gtk_table_attach (GTK_TABLE (table1), checkbutton_autosave, 0, 1, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_autosave, _("Whether to automatically save the game regularly"), NULL);

  spinbutton_precision_adj = gtk_adjustment_new (1, 0, 3, 1, 10, 0);
  spinbutton_precision = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_precision_adj), 1, 0);
  gtk_widget_show (spinbutton_precision);
  gtk_table_attach (GTK_TABLE (table1), spinbutton_precision, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_precision, _("How many digits after the comma there are for skill etc."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_precision), TRUE);

  spinbutton_refresh_adj = gtk_adjustment_new (1, 1, 100, 1, 10, 0);
  spinbutton_refresh = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_refresh_adj), 1, 0);
  gtk_widget_show (spinbutton_refresh);
  gtk_table_attach (GTK_TABLE (table1), spinbutton_refresh, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_refresh, _("How often the player list gets refreshed during a live game (in live game minutes)"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_refresh), TRUE);

  entry_font_name = gtk_entry_new ();
  gtk_widget_show (entry_font_name);
  gtk_table_attach (GTK_TABLE (table1), entry_font_name, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, entry_font_name, _("Font used in treeviews"), NULL);

  eventbox2 = gtk_event_box_new ();
  gtk_widget_show (eventbox2);
  gtk_table_attach (GTK_TABLE (table1), eventbox2, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_tooltips_set_tip (tooltips, eventbox2, _("Choose game language (might not work in Windows versions)"), NULL);

  combobox_languages = gtk_combo_box_new_text ();
  gtk_widget_show (combobox_languages);
  gtk_container_add (GTK_CONTAINER (eventbox2), combobox_languages);

  label1 = gtk_label_new (_("Global"));
  gtk_widget_show (label1);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), label1);

  hbox6 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox6);
  gtk_container_add (GTK_CONTAINER (notebook1), hbox6);

  vbox6 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox6);
  gtk_box_pack_start (GTK_BOX (hbox6), vbox6, TRUE, TRUE, 0);

  checkbutton_conf_youth = gtk_check_button_new_with_mnemonic (_("Confirm removing youths"));
  gtk_widget_show (checkbutton_conf_youth);
  gtk_box_pack_start (GTK_BOX (vbox6), checkbutton_conf_youth, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_conf_youth, _("Whether a confirmation popup is shown when you kick out a youth from your academy"), NULL);

  checkbutton_show_job = gtk_check_button_new_with_mnemonic (_("Show job offers"));
  gtk_widget_show (checkbutton_show_job);
  gtk_box_pack_start (GTK_BOX (vbox6), checkbutton_show_job, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_show_job, _("Whether to show job offers when a user is successful"), NULL);

  eventbox1 = gtk_event_box_new ();
  gtk_widget_show (eventbox1);
  gtk_box_pack_start (GTK_BOX (vbox6), eventbox1, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox1, _("Set to 0 to switch off warning"), NULL);

  hbox10 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox10);
  gtk_container_add (GTK_CONTAINER (eventbox1), hbox10);

  label37 = gtk_label_new (_("Show warning if a player contract gets below "));
  gtk_widget_show (label37);
  gtk_box_pack_start (GTK_BOX (hbox10), label37, FALSE, FALSE, 0);

  spinbutton_contract_adj = gtk_adjustment_new (1, 0, 24, 1, 10, 0);
  spinbutton_contract = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_contract_adj), 1, 0);
  gtk_widget_show (spinbutton_contract);
  gtk_box_pack_start (GTK_BOX (hbox10), spinbutton_contract, FALSE, FALSE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_contract), TRUE);

  label38 = gtk_label_new (_(" months"));
  gtk_widget_show (label38);
  gtk_box_pack_start (GTK_BOX (hbox10), label38, FALSE, FALSE, 0);

  checkbutton_show_all_leagues = gtk_check_button_new_with_mnemonic (_("Show all leagues in the fixture view"));
  gtk_widget_show (checkbutton_show_all_leagues);
  gtk_box_pack_start (GTK_BOX (vbox6), checkbutton_show_all_leagues, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_show_all_leagues, _("Whether in the weekly fixture view all leagues or only the user league is shown"), NULL);

  vseparator3 = gtk_vseparator_new ();
  gtk_widget_show (vseparator3);
  gtk_box_pack_start (GTK_BOX (hbox6), vseparator3, FALSE, FALSE, 0);
  gtk_widget_set_size_request (vseparator3, 10, 1);

  alignment7 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment7);
  gtk_box_pack_start (GTK_BOX (hbox6), alignment7, TRUE, TRUE, 0);

  vbox7 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox7);
  gtk_container_add (GTK_CONTAINER (alignment7), vbox7);

  checkbutton_swap_adapts = gtk_check_button_new_with_mnemonic (_("Swap adapts structure"));
  gtk_widget_show (checkbutton_swap_adapts);
  gtk_box_pack_start (GTK_BOX (vbox7), checkbutton_swap_adapts, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_swap_adapts, _("Whether swapping two players automatically adapts the team structure to the player positions"), NULL);

  checkbutton_show_overall = gtk_check_button_new_with_mnemonic (_("Show overall games/goals"));
  gtk_widget_show (checkbutton_show_overall);
  gtk_box_pack_start (GTK_BOX (vbox7), checkbutton_show_overall, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_show_overall, _("Whether to show the player games/goals value in all competitions"), NULL);

  checkbutton_store_restore_default_team = gtk_check_button_new_with_mnemonic (_("Always store/restore your default team"));
  gtk_widget_show (checkbutton_store_restore_default_team);
  gtk_box_pack_start (GTK_BOX (vbox7), checkbutton_store_restore_default_team, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_store_restore_default_team, _("Always store/restore your default team before/after a match"), NULL);

  label3 = gtk_label_new (_("Gameplay"));
  gtk_widget_show (label3);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 1), label3);

  hbox4 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox4);
  gtk_container_add (GTK_CONTAINER (notebook1), hbox4);

  vbox4 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox4);
  gtk_box_pack_start (GTK_BOX (hbox4), vbox4, TRUE, TRUE, 0);

  checkbutton_show_live = gtk_check_button_new_with_mnemonic (_("Show live game"));
  gtk_widget_show (checkbutton_show_live);
  gtk_box_pack_start (GTK_BOX (vbox4), checkbutton_show_live, FALSE, FALSE, 0);

  checkbutton_show_tendency = gtk_check_button_new_with_mnemonic (_("Show tendency bar"));
  gtk_widget_show (checkbutton_show_tendency);
  gtk_box_pack_start (GTK_BOX (vbox4), checkbutton_show_tendency, FALSE, FALSE, 0);

  table3 = gtk_table_new (2, 2, FALSE);
  gtk_widget_show (table3);
  gtk_box_pack_start (GTK_BOX (vbox4), table3, FALSE, FALSE, 0);
  gtk_table_set_col_spacings (GTK_TABLE (table3), 2);

  label12 = gtk_label_new (_("Live game speed factor"));
  gtk_widget_show (label12);
  gtk_table_attach (GTK_TABLE (table3), label12, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label12), 1, 0.5);

  label39 = gtk_label_new (_("Live game verbosity"));
  gtk_widget_show (label39);
  gtk_table_attach (GTK_TABLE (table3), label39, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label39), 1, 0.5);

  spinbutton_live_speed_adj = gtk_adjustment_new (0, 0, 40, 1, 10, 0);
  spinbutton_live_speed = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_live_speed_adj), 1, 0);
  gtk_widget_show (spinbutton_live_speed);
  gtk_table_attach (GTK_TABLE (table3), spinbutton_live_speed, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_live_speed, _("The lower this value the faster the live game commentary will scroll."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_live_speed), TRUE);

  spinbutton_live_verbosity_adj = gtk_adjustment_new (1, 1, 7, 1, 10, 0);
  spinbutton_live_verbosity = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_live_verbosity_adj), 1, 0);
  gtk_widget_show (spinbutton_live_verbosity);
  gtk_table_attach (GTK_TABLE (table3), spinbutton_live_verbosity, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_live_verbosity, _("The higher this value, the more commentary you'll see."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_live_verbosity), TRUE);

  checkbutton_auto_sub = gtk_check_button_new_with_mnemonic (_("Automatic substitutions"));
  gtk_widget_show (checkbutton_auto_sub);
  gtk_box_pack_start (GTK_BOX (vbox4), checkbutton_auto_sub, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_auto_sub, _("Whether the subs (e.g. for injured players) are made by the CPU. This is automatically done if the live game is off."), NULL);

  vseparator2 = gtk_vseparator_new ();
  gtk_widget_show (vseparator2);
  gtk_box_pack_start (GTK_BOX (hbox4), vseparator2, FALSE, TRUE, 0);
  gtk_widget_set_size_request (vseparator2, 10, 1);

  vbox5 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox5);
  gtk_box_pack_start (GTK_BOX (hbox4), vbox5, TRUE, TRUE, 0);

  checkbutton_pause_injury = gtk_check_button_new_with_mnemonic (_("Pause when injury"));
  gtk_widget_show (checkbutton_pause_injury);
  gtk_box_pack_start (GTK_BOX (vbox5), checkbutton_pause_injury, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_pause_injury, _("Whether the live game pauses when a user player is injured"), NULL);

  checkbutton_pause_red = gtk_check_button_new_with_mnemonic (_("Pause when red card"));
  gtk_widget_show (checkbutton_pause_red);
  gtk_box_pack_start (GTK_BOX (vbox5), checkbutton_pause_red, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_pause_red, _("Whether the live game pauses when a user player is sent off"), NULL);

  checkbutton_pause_break = gtk_check_button_new_with_mnemonic (_("Pause when break"));
  gtk_widget_show (checkbutton_pause_break);
  gtk_box_pack_start (GTK_BOX (vbox5), checkbutton_pause_break, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_pause_break, _("Whether the live game pauses at half time and extra time"), NULL);

  label2 = gtk_label_new (_("Live game"));
  gtk_widget_show (label2);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 2), label2);

  table2 = gtk_table_new (20, 3, FALSE);
  gtk_widget_show (table2);
  gtk_container_add (GTK_CONTAINER (notebook1), table2);

  label13 = gtk_label_new (_("Name "));
  gtk_widget_show (label13);
  gtk_table_attach (GTK_TABLE (table2), label13, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label13), 0, 0.5);

  label14 = gtk_label_new (_("CPos "));
  gtk_widget_show (label14);
  gtk_table_attach (GTK_TABLE (table2), label14, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label14), 0, 0.5);

  label15 = gtk_label_new (_("Pos "));
  gtk_widget_show (label15);
  gtk_table_attach (GTK_TABLE (table2), label15, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label15), 0, 0.5);

  label16 = gtk_label_new (_("CSkill "));
  gtk_widget_show (label16);
  gtk_table_attach (GTK_TABLE (table2), label16, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label16), 0, 0.5);

  label17 = gtk_label_new (_("Skill "));
  gtk_widget_show (label17);
  gtk_table_attach (GTK_TABLE (table2), label17, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label17), 0, 0.5);

  label18 = gtk_label_new (_("Fitness "));
  gtk_widget_show (label18);
  gtk_table_attach (GTK_TABLE (table2), label18, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label18), 0, 0.5);

  label19 = gtk_label_new (_("Games "));
  gtk_widget_show (label19);
  gtk_table_attach (GTK_TABLE (table2), label19, 0, 1, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label19), 0, 0.5);

  label20 = gtk_label_new (_("Shots "));
  gtk_widget_show (label20);
  gtk_table_attach (GTK_TABLE (table2), label20, 0, 1, 9, 10,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label20), 0, 0.5);

  label21 = gtk_label_new (_("Goals "));
  gtk_widget_show (label21);
  gtk_table_attach (GTK_TABLE (table2), label21, 0, 1, 10, 11,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label21), 0, 0.5);

  label22 = gtk_label_new (_("Status "));
  gtk_widget_show (label22);
  gtk_table_attach (GTK_TABLE (table2), label22, 0, 1, 11, 12,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label22), 0, 0.5);

  label23 = gtk_label_new (_("Cards "));
  gtk_widget_show (label23);
  gtk_table_attach (GTK_TABLE (table2), label23, 0, 1, 12, 13,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label23), 0, 0.5);

  label24 = gtk_label_new (_("Age "));
  gtk_widget_show (label24);
  gtk_table_attach (GTK_TABLE (table2), label24, 0, 1, 13, 14,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label24), 0, 0.5);

  label25 = gtk_label_new (_("ETal "));
  gtk_widget_show (label25);
  gtk_table_attach (GTK_TABLE (table2), label25, 0, 1, 14, 15,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label25), 0, 0.5);

  label26 = gtk_label_new (_("Value "));
  gtk_widget_show (label26);
  gtk_table_attach (GTK_TABLE (table2), label26, 0, 1, 15, 16,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label26), 0, 0.5);

  label27 = gtk_label_new (_("Wage "));
  gtk_widget_show (label27);
  gtk_table_attach (GTK_TABLE (table2), label27, 0, 1, 16, 17,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label27), 0, 0.5);

  label28 = gtk_label_new (_("Contract "));
  gtk_widget_show (label28);
  gtk_table_attach (GTK_TABLE (table2), label28, 0, 1, 17, 18,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label28), 0, 0.5);

  label29 = gtk_label_new (_("League "));
  gtk_widget_show (label29);
  gtk_table_attach (GTK_TABLE (table2), label29, 0, 1, 19, 20,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label29), 0, 0.5);

  label30 = gtk_label_new (_("Team "));
  gtk_widget_show (label30);
  gtk_table_attach (GTK_TABLE (table2), label30, 0, 1, 18, 19,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label30), 0, 0.5);

  checkbutton1 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton1);
  gtk_table_attach (GTK_TABLE (table2), checkbutton1, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton20 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton20);
  gtk_table_attach (GTK_TABLE (table2), checkbutton20, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton2 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton2);
  gtk_table_attach (GTK_TABLE (table2), checkbutton2, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton3 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton3);
  gtk_table_attach (GTK_TABLE (table2), checkbutton3, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton4 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton4);
  gtk_table_attach (GTK_TABLE (table2), checkbutton4, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton5 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton5);
  gtk_table_attach (GTK_TABLE (table2), checkbutton5, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton6 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton6);
  gtk_table_attach (GTK_TABLE (table2), checkbutton6, 1, 2, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton7 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton7);
  gtk_table_attach (GTK_TABLE (table2), checkbutton7, 1, 2, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton8 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton8);
  gtk_table_attach (GTK_TABLE (table2), checkbutton8, 1, 2, 9, 10,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton9 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton9);
  gtk_table_attach (GTK_TABLE (table2), checkbutton9, 1, 2, 10, 11,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton10 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton10);
  gtk_table_attach (GTK_TABLE (table2), checkbutton10, 1, 2, 11, 12,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton11 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton11);
  gtk_table_attach (GTK_TABLE (table2), checkbutton11, 1, 2, 12, 13,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton12 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton12);
  gtk_table_attach (GTK_TABLE (table2), checkbutton12, 1, 2, 13, 14,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton13 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton13);
  gtk_table_attach (GTK_TABLE (table2), checkbutton13, 1, 2, 14, 15,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton14 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton14);
  gtk_table_attach (GTK_TABLE (table2), checkbutton14, 1, 2, 15, 16,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton15 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton15);
  gtk_table_attach (GTK_TABLE (table2), checkbutton15, 1, 2, 16, 17,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton16 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton16);
  gtk_table_attach (GTK_TABLE (table2), checkbutton16, 1, 2, 17, 18,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton17 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton17);
  gtk_table_attach (GTK_TABLE (table2), checkbutton17, 1, 2, 18, 19,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton18 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton18);
  gtk_table_attach (GTK_TABLE (table2), checkbutton18, 1, 2, 19, 20,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton19 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton19);
  gtk_table_attach (GTK_TABLE (table2), checkbutton19, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton21 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton21);
  gtk_table_attach (GTK_TABLE (table2), checkbutton21, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton22 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton22);
  gtk_table_attach (GTK_TABLE (table2), checkbutton22, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton23 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton23);
  gtk_table_attach (GTK_TABLE (table2), checkbutton23, 2, 3, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton24 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton24);
  gtk_table_attach (GTK_TABLE (table2), checkbutton24, 2, 3, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton25 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton25);
  gtk_table_attach (GTK_TABLE (table2), checkbutton25, 2, 3, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton26 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton26);
  gtk_table_attach (GTK_TABLE (table2), checkbutton26, 2, 3, 9, 10,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton27 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton27);
  gtk_table_attach (GTK_TABLE (table2), checkbutton27, 2, 3, 10, 11,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton28 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton28);
  gtk_table_attach (GTK_TABLE (table2), checkbutton28, 2, 3, 11, 12,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton29 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton29);
  gtk_table_attach (GTK_TABLE (table2), checkbutton29, 2, 3, 12, 13,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton30 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton30);
  gtk_table_attach (GTK_TABLE (table2), checkbutton30, 2, 3, 13, 14,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton31 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton31);
  gtk_table_attach (GTK_TABLE (table2), checkbutton31, 2, 3, 14, 15,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton32 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton32);
  gtk_table_attach (GTK_TABLE (table2), checkbutton32, 2, 3, 15, 16,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton33 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton33);
  gtk_table_attach (GTK_TABLE (table2), checkbutton33, 2, 3, 16, 17,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton34 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton34);
  gtk_table_attach (GTK_TABLE (table2), checkbutton34, 2, 3, 17, 18,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton35 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton35);
  gtk_table_attach (GTK_TABLE (table2), checkbutton35, 2, 3, 18, 19,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton36 = gtk_check_button_new_with_mnemonic ("");
  gtk_widget_show (checkbutton36);
  gtk_table_attach (GTK_TABLE (table2), checkbutton36, 2, 3, 19, 20,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  hseparator3 = gtk_hseparator_new ();
  gtk_widget_show (hseparator3);
  gtk_table_attach (GTK_TABLE (table2), hseparator3, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_widget_set_size_request (hseparator3, 1, 10);

  hseparator4 = gtk_hseparator_new ();
  gtk_widget_show (hseparator4);
  gtk_table_attach (GTK_TABLE (table2), hseparator4, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_widget_set_size_request (hseparator4, 1, 10);

  label31 = gtk_label_new (_("Attribute "));
  gtk_widget_show (label31);
  gtk_table_attach (GTK_TABLE (table2), label31, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label31), 0, 0.5);

  label32 = gtk_label_new (_("List 1 "));
  gtk_widget_show (label32);
  gtk_table_attach (GTK_TABLE (table2), label32, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label32), 0, 0.5);

  label33 = gtk_label_new (_("List 2"));
  gtk_widget_show (label33);
  gtk_table_attach (GTK_TABLE (table2), label33, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label33), 0, 0.5);

  hseparator2 = gtk_hseparator_new ();
  gtk_widget_show (hseparator2);
  gtk_table_attach (GTK_TABLE (table2), hseparator2, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_widget_set_size_request (hseparator2, 1, 10);

  label4 = gtk_label_new (_("Player attributes shown"));
  gtk_widget_show (label4);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 3), label4);

  hbox11 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox11);
  gtk_container_add (GTK_CONTAINER (notebook1), hbox11);

  vbox8 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox8);
  gtk_box_pack_start (GTK_BOX (hbox11), vbox8, TRUE, TRUE, 0);

  checkbutton_bet_show_all_leagues = gtk_check_button_new_with_mnemonic (_("Show matches from all leagues"));
  gtk_widget_show (checkbutton_bet_show_all_leagues);
  gtk_box_pack_start (GTK_BOX (vbox8), checkbutton_bet_show_all_leagues, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_bet_show_all_leagues, _("Whether to show matches of all leagues in the betting window"), NULL);

  checkbutton_bet_show_cups = gtk_check_button_new_with_mnemonic (_("Show matches from cups"));
  gtk_widget_show (checkbutton_bet_show_cups);
  gtk_box_pack_start (GTK_BOX (vbox8), checkbutton_bet_show_cups, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_bet_show_cups, _("Whether to show cup matches in the betting window"), NULL);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton_bet_show_cups), TRUE);

  checkbutton_bet_show_only_recent = gtk_check_button_new_with_mnemonic (_("Show only my recent bets"));
  gtk_widget_show (checkbutton_bet_show_only_recent);
  gtk_box_pack_start (GTK_BOX (vbox8), checkbutton_bet_show_only_recent, FALSE, FALSE, 0);

  hbox12 = gtk_hbox_new (FALSE, 5);
  gtk_widget_show (hbox12);
  gtk_box_pack_start (GTK_BOX (vbox8), hbox12, FALSE, FALSE, 0);

  label42 = gtk_label_new (_("Default wager"));
  gtk_widget_show (label42);
  gtk_box_pack_start (GTK_BOX (hbox12), label42, FALSE, FALSE, 0);

  spinbutton_bet_wager_adj = gtk_adjustment_new (1, 1, 100, 100, 1000, 0);
  spinbutton_bet_wager = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_bet_wager_adj), 1, 0);
  gtk_widget_show (spinbutton_bet_wager);
  gtk_box_pack_start (GTK_BOX (hbox12), spinbutton_bet_wager, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_bet_wager, _("How much you wager by default"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_bet_wager), TRUE);

  label41 = gtk_label_new (_("Betting"));
  gtk_widget_show (label41);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 4), label41);

  vbox9 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox9);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox9);
  gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook1), vbox9,
                                      FALSE, FALSE, GTK_PACK_START);

  hbox13 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox13);
  gtk_box_pack_start (GTK_BOX (vbox9), hbox13, FALSE, FALSE, 0);

  label44 = gtk_label_new (_("Default hotel"));
  gtk_widget_show (label44);
  gtk_box_pack_start (GTK_BOX (hbox13), label44, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label44), 0.1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label44), 4, 3);

  combobox_hotel = gtk_combo_box_new_text ();
  gtk_widget_show (combobox_hotel);
  gtk_box_pack_start (GTK_BOX (hbox13), combobox_hotel, FALSE, FALSE, 0);

  vbox10 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox10);
  gtk_box_pack_start (GTK_BOX (vbox9), vbox10, FALSE, FALSE, 0);

  hseparator7 = gtk_hseparator_new ();
  gtk_widget_show (hseparator7);
  gtk_box_pack_start (GTK_BOX (vbox10), hseparator7, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator7, -1, 10);

  hbox15 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox15);
  gtk_box_pack_start (GTK_BOX (vbox10), hbox15, FALSE, FALSE, 0);

  label45 = gtk_label_new (_("Default recreation:"));
  gtk_widget_show (label45);
  gtk_box_pack_start (GTK_BOX (hbox15), label45, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label45), 0.1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label45), 3, 3);

  spinbutton_recreation_adj = gtk_adjustment_new (1, 0, 10, 1, 10, 0);
  spinbutton_recreation = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_recreation_adj), 1, 0);
  gtk_widget_show (spinbutton_recreation);
  gtk_box_pack_start (GTK_BOX (hbox15), spinbutton_recreation, FALSE, FALSE, 0);

  hseparator8 = gtk_hseparator_new ();
  gtk_widget_show (hseparator8);
  gtk_box_pack_start (GTK_BOX (vbox9), hseparator8, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator8, -1, 10);

  hbox16 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox16);
  gtk_box_pack_start (GTK_BOX (vbox9), hbox16, FALSE, FALSE, 0);

  label47 = gtk_label_new (_("Default training:"));
  gtk_widget_show (label47);
  gtk_box_pack_start (GTK_BOX (hbox16), label47, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label47), 0.1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label47), 3, 3);

  label_training = gtk_label_new ("");
  gtk_widget_show (label_training);
  gtk_box_pack_start (GTK_BOX (hbox16), label_training, FALSE, FALSE, 0);

  label43 = gtk_label_new (_("Training camp"));
  gtk_widget_show (label43);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 5), label43);

  vbox11 = gtk_vbox_new (FALSE, 4);
  gtk_widget_show (vbox11);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox11);

  hbox17 = gtk_hbox_new (FALSE, 5);
  gtk_widget_show (hbox17);
  gtk_box_pack_start (GTK_BOX (vbox11), hbox17, FALSE, FALSE, 0);

  checkbutton_news_user = gtk_check_button_new_with_mnemonic (_("Create user news"));
  gtk_widget_show (checkbutton_news_user);
  gtk_box_pack_start (GTK_BOX (hbox17), checkbutton_news_user, FALSE, FALSE, 0);

  checkbutton_news_cup = gtk_check_button_new_with_mnemonic (_("Create cup news"));
  gtk_widget_show (checkbutton_news_cup);
  gtk_box_pack_start (GTK_BOX (hbox17), checkbutton_news_cup, FALSE, FALSE, 0);

  checkbutton_news_league = gtk_check_button_new_with_mnemonic (_("Create league news"));
  gtk_widget_show (checkbutton_news_league);
  gtk_box_pack_start (GTK_BOX (hbox17), checkbutton_news_league, FALSE, FALSE, 0);

  checkbutton_news_recent = gtk_check_button_new_with_mnemonic (_("Show only recent news"));
  gtk_widget_show (checkbutton_news_recent);
  gtk_box_pack_start (GTK_BOX (vbox11), checkbutton_news_recent, FALSE, FALSE, 0);

  hbox18 = gtk_hbox_new (FALSE, 5);
  gtk_widget_show (hbox18);
  gtk_box_pack_start (GTK_BOX (vbox11), hbox18, FALSE, FALSE, 0);

  radiobutton_news_popup_no = gtk_radio_button_new_with_mnemonic (NULL, _("No automatic popup"));
  gtk_widget_show (radiobutton_news_popup_no);
  gtk_box_pack_start (GTK_BOX (hbox18), radiobutton_news_popup_no, FALSE, FALSE, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_news_popup_no), radiobutton_news_popup_no_group);
  radiobutton_news_popup_no_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_news_popup_no));

  radiobutton_news_popup_user = gtk_radio_button_new_with_mnemonic (NULL, _("Popup for user news"));
  gtk_widget_show (radiobutton_news_popup_user);
  gtk_box_pack_start (GTK_BOX (hbox18), radiobutton_news_popup_user, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, radiobutton_news_popup_user, _("Show news window after a matchday when new user news was created"), NULL);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_news_popup_user), radiobutton_news_popup_no_group);
  radiobutton_news_popup_no_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_news_popup_user));

  radiobutton_news_popup_always = gtk_radio_button_new_with_mnemonic (NULL, _("Automatic popup"));
  gtk_widget_show (radiobutton_news_popup_always);
  gtk_box_pack_start (GTK_BOX (hbox18), radiobutton_news_popup_always, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, radiobutton_news_popup_always, _("Always show news window after a matchday"), NULL);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_news_popup_always), radiobutton_news_popup_no_group);
  radiobutton_news_popup_no_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_news_popup_always));

  label48 = gtk_label_new (_("News"));
  gtk_widget_show (label48);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 6), label48);

  hseparator1 = gtk_hseparator_new ();
  gtk_widget_show (hseparator1);
  gtk_box_pack_start (GTK_BOX (vbox1), hseparator1, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator1, 1, 10);

  hbox1 = gtk_hbox_new (FALSE, 3);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox2);
  gtk_box_pack_start (GTK_BOX (hbox1), vbox2, FALSE, FALSE, 0);

  checkbutton_save_global = gtk_check_button_new_with_mnemonic (_("Save global settings to file"));
  gtk_widget_show (checkbutton_save_global);
  gtk_box_pack_start (GTK_BOX (vbox2), checkbutton_save_global, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_save_global, _("Whether to save the global settings to file (so that they get loaded next time you start a new game)"), NULL);

  checkbutton_save_user = gtk_check_button_new_with_mnemonic (_("Save user settings to file"));
  gtk_widget_show (checkbutton_save_user);
  gtk_box_pack_start (GTK_BOX (vbox2), checkbutton_save_user, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_save_user, _("Whether to save the user settings to file (so that they get loaded next time this user starts a new game)"), NULL);

  button_ok = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (button_ok);
  gtk_box_pack_start (GTK_BOX (hbox1), button_ok, TRUE, TRUE, 0);

  button_cancel = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (button_cancel);
  gtk_box_pack_start (GTK_BOX (hbox1), button_cancel, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, button_cancel, _("Esc"), NULL);
  gtk_widget_add_accelerator (button_cancel, "clicked", accel_group,
                              GDK_Escape, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  g_signal_connect ((gpointer) window_options, "delete_event",
                    G_CALLBACK (on_window_options_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_font_name, "clicked",
                    G_CALLBACK (on_button_font_name_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_reload_constants, "clicked",
                    G_CALLBACK (on_button_reload_constants_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_edit_constants, "clicked",
                    G_CALLBACK (on_button_edit_constants_clicked),
                    NULL);
  g_signal_connect ((gpointer) spinbutton_recreation, "value_changed",
                    G_CALLBACK (on_spinbutton_recreation_value_changed),
                    NULL);
  g_signal_connect ((gpointer) checkbutton_save_global, "button_press_event",
                    G_CALLBACK (on_checkbutton_save_global_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) checkbutton_save_user, "button_press_event",
                    G_CALLBACK (on_checkbutton_save_user_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) button_ok, "clicked",
                    G_CALLBACK (on_button_options_ok_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_cancel, "clicked",
                    G_CALLBACK (on_button_options_cancel_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_options, window_options, "window_options");
  GLADE_HOOKUP_OBJECT (window_options, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (window_options, notebook1, "notebook1");
  GLADE_HOOKUP_OBJECT (window_options, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (window_options, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_conf_quit, "checkbutton_conf_quit");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_conf_unfit, "checkbutton_conf_unfit");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_save_overwrite, "checkbutton_save_overwrite");
  GLADE_HOOKUP_OBJECT (window_options, hseparator5, "hseparator5");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_maximize, "checkbutton_maximize");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_pref_mess, "checkbutton_pref_mess");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_show_progress_pics, "checkbutton_show_progress_pics");
  GLADE_HOOKUP_OBJECT (window_options, hseparator6, "hseparator6");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_skip, "checkbutton_skip");
  GLADE_HOOKUP_OBJECT (window_options, vseparator1, "vseparator1");
  GLADE_HOOKUP_OBJECT (window_options, table1, "table1");
  GLADE_HOOKUP_OBJECT (window_options, hbox3, "hbox3");
  GLADE_HOOKUP_OBJECT (window_options, label6, "label6");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_autosave, "spinbutton_autosave");
  GLADE_HOOKUP_OBJECT (window_options, label36, "label36");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_autosave_files, "spinbutton_autosave_files");
  GLADE_HOOKUP_OBJECT (window_options, label7, "label7");
  GLADE_HOOKUP_OBJECT (window_options, label8, "label8");
  GLADE_HOOKUP_OBJECT (window_options, label10, "label10");
  GLADE_HOOKUP_OBJECT (window_options, button_font_name, "button_font_name");
  GLADE_HOOKUP_OBJECT (window_options, alignment1, "alignment1");
  GLADE_HOOKUP_OBJECT (window_options, hbox7, "hbox7");
  GLADE_HOOKUP_OBJECT (window_options, image1, "image1");
  GLADE_HOOKUP_OBJECT (window_options, label34, "label34");
  GLADE_HOOKUP_OBJECT (window_options, hbox8, "hbox8");
  GLADE_HOOKUP_OBJECT (window_options, entry_constants_file, "entry_constants_file");
  GLADE_HOOKUP_OBJECT (window_options, button_reload_constants, "button_reload_constants");
  GLADE_HOOKUP_OBJECT (window_options, alignment2, "alignment2");
  GLADE_HOOKUP_OBJECT (window_options, hbox9, "hbox9");
  GLADE_HOOKUP_OBJECT (window_options, image2, "image2");
  GLADE_HOOKUP_OBJECT (window_options, label35, "label35");
  GLADE_HOOKUP_OBJECT (window_options, button_edit_constants, "button_edit_constants");
  GLADE_HOOKUP_OBJECT (window_options, alignment3, "alignment3");
  GLADE_HOOKUP_OBJECT (window_options, hbox19, "hbox19");
  GLADE_HOOKUP_OBJECT (window_options, image3, "image3");
  GLADE_HOOKUP_OBJECT (window_options, label49, "label49");
  GLADE_HOOKUP_OBJECT (window_options, label40, "label40");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_autosave, "checkbutton_autosave");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_precision, "spinbutton_precision");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_refresh, "spinbutton_refresh");
  GLADE_HOOKUP_OBJECT (window_options, entry_font_name, "entry_font_name");
  GLADE_HOOKUP_OBJECT (window_options, eventbox2, "eventbox2");
  GLADE_HOOKUP_OBJECT (window_options, combobox_languages, "combobox_languages");
  GLADE_HOOKUP_OBJECT (window_options, label1, "label1");
  GLADE_HOOKUP_OBJECT (window_options, hbox6, "hbox6");
  GLADE_HOOKUP_OBJECT (window_options, vbox6, "vbox6");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_conf_youth, "checkbutton_conf_youth");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_show_job, "checkbutton_show_job");
  GLADE_HOOKUP_OBJECT (window_options, eventbox1, "eventbox1");
  GLADE_HOOKUP_OBJECT (window_options, hbox10, "hbox10");
  GLADE_HOOKUP_OBJECT (window_options, label37, "label37");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_contract, "spinbutton_contract");
  GLADE_HOOKUP_OBJECT (window_options, label38, "label38");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_show_all_leagues, "checkbutton_show_all_leagues");
  GLADE_HOOKUP_OBJECT (window_options, vseparator3, "vseparator3");
  GLADE_HOOKUP_OBJECT (window_options, alignment7, "alignment7");
  GLADE_HOOKUP_OBJECT (window_options, vbox7, "vbox7");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_swap_adapts, "checkbutton_swap_adapts");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_show_overall, "checkbutton_show_overall");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_store_restore_default_team, "checkbutton_store_restore_default_team");
  GLADE_HOOKUP_OBJECT (window_options, label3, "label3");
  GLADE_HOOKUP_OBJECT (window_options, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (window_options, vbox4, "vbox4");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_show_live, "checkbutton_show_live");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_show_tendency, "checkbutton_show_tendency");
  GLADE_HOOKUP_OBJECT (window_options, table3, "table3");
  GLADE_HOOKUP_OBJECT (window_options, label12, "label12");
  GLADE_HOOKUP_OBJECT (window_options, label39, "label39");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_live_speed, "spinbutton_live_speed");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_live_verbosity, "spinbutton_live_verbosity");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_auto_sub, "checkbutton_auto_sub");
  GLADE_HOOKUP_OBJECT (window_options, vseparator2, "vseparator2");
  GLADE_HOOKUP_OBJECT (window_options, vbox5, "vbox5");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_pause_injury, "checkbutton_pause_injury");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_pause_red, "checkbutton_pause_red");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_pause_break, "checkbutton_pause_break");
  GLADE_HOOKUP_OBJECT (window_options, label2, "label2");
  GLADE_HOOKUP_OBJECT (window_options, table2, "table2");
  GLADE_HOOKUP_OBJECT (window_options, label13, "label13");
  GLADE_HOOKUP_OBJECT (window_options, label14, "label14");
  GLADE_HOOKUP_OBJECT (window_options, label15, "label15");
  GLADE_HOOKUP_OBJECT (window_options, label16, "label16");
  GLADE_HOOKUP_OBJECT (window_options, label17, "label17");
  GLADE_HOOKUP_OBJECT (window_options, label18, "label18");
  GLADE_HOOKUP_OBJECT (window_options, label19, "label19");
  GLADE_HOOKUP_OBJECT (window_options, label20, "label20");
  GLADE_HOOKUP_OBJECT (window_options, label21, "label21");
  GLADE_HOOKUP_OBJECT (window_options, label22, "label22");
  GLADE_HOOKUP_OBJECT (window_options, label23, "label23");
  GLADE_HOOKUP_OBJECT (window_options, label24, "label24");
  GLADE_HOOKUP_OBJECT (window_options, label25, "label25");
  GLADE_HOOKUP_OBJECT (window_options, label26, "label26");
  GLADE_HOOKUP_OBJECT (window_options, label27, "label27");
  GLADE_HOOKUP_OBJECT (window_options, label28, "label28");
  GLADE_HOOKUP_OBJECT (window_options, label29, "label29");
  GLADE_HOOKUP_OBJECT (window_options, label30, "label30");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton1, "checkbutton1");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton20, "checkbutton20");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton2, "checkbutton2");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton3, "checkbutton3");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton4, "checkbutton4");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton5, "checkbutton5");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton6, "checkbutton6");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton7, "checkbutton7");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton8, "checkbutton8");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton9, "checkbutton9");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton10, "checkbutton10");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton11, "checkbutton11");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton12, "checkbutton12");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton13, "checkbutton13");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton14, "checkbutton14");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton15, "checkbutton15");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton16, "checkbutton16");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton17, "checkbutton17");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton18, "checkbutton18");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton19, "checkbutton19");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton21, "checkbutton21");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton22, "checkbutton22");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton23, "checkbutton23");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton24, "checkbutton24");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton25, "checkbutton25");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton26, "checkbutton26");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton27, "checkbutton27");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton28, "checkbutton28");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton29, "checkbutton29");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton30, "checkbutton30");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton31, "checkbutton31");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton32, "checkbutton32");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton33, "checkbutton33");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton34, "checkbutton34");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton35, "checkbutton35");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton36, "checkbutton36");
  GLADE_HOOKUP_OBJECT (window_options, hseparator3, "hseparator3");
  GLADE_HOOKUP_OBJECT (window_options, hseparator4, "hseparator4");
  GLADE_HOOKUP_OBJECT (window_options, label31, "label31");
  GLADE_HOOKUP_OBJECT (window_options, label32, "label32");
  GLADE_HOOKUP_OBJECT (window_options, label33, "label33");
  GLADE_HOOKUP_OBJECT (window_options, hseparator2, "hseparator2");
  GLADE_HOOKUP_OBJECT (window_options, label4, "label4");
  GLADE_HOOKUP_OBJECT (window_options, hbox11, "hbox11");
  GLADE_HOOKUP_OBJECT (window_options, vbox8, "vbox8");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_bet_show_all_leagues, "checkbutton_bet_show_all_leagues");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_bet_show_cups, "checkbutton_bet_show_cups");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_bet_show_only_recent, "checkbutton_bet_show_only_recent");
  GLADE_HOOKUP_OBJECT (window_options, hbox12, "hbox12");
  GLADE_HOOKUP_OBJECT (window_options, label42, "label42");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_bet_wager, "spinbutton_bet_wager");
  GLADE_HOOKUP_OBJECT (window_options, label41, "label41");
  GLADE_HOOKUP_OBJECT (window_options, vbox9, "vbox9");
  GLADE_HOOKUP_OBJECT (window_options, hbox13, "hbox13");
  GLADE_HOOKUP_OBJECT (window_options, label44, "label44");
  GLADE_HOOKUP_OBJECT (window_options, combobox_hotel, "combobox_hotel");
  GLADE_HOOKUP_OBJECT (window_options, vbox10, "vbox10");
  GLADE_HOOKUP_OBJECT (window_options, hseparator7, "hseparator7");
  GLADE_HOOKUP_OBJECT (window_options, hbox15, "hbox15");
  GLADE_HOOKUP_OBJECT (window_options, label45, "label45");
  GLADE_HOOKUP_OBJECT (window_options, spinbutton_recreation, "spinbutton_recreation");
  GLADE_HOOKUP_OBJECT (window_options, hseparator8, "hseparator8");
  GLADE_HOOKUP_OBJECT (window_options, hbox16, "hbox16");
  GLADE_HOOKUP_OBJECT (window_options, label47, "label47");
  GLADE_HOOKUP_OBJECT (window_options, label_training, "label_training");
  GLADE_HOOKUP_OBJECT (window_options, label43, "label43");
  GLADE_HOOKUP_OBJECT (window_options, vbox11, "vbox11");
  GLADE_HOOKUP_OBJECT (window_options, hbox17, "hbox17");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_news_user, "checkbutton_news_user");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_news_cup, "checkbutton_news_cup");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_news_league, "checkbutton_news_league");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_news_recent, "checkbutton_news_recent");
  GLADE_HOOKUP_OBJECT (window_options, hbox18, "hbox18");
  GLADE_HOOKUP_OBJECT (window_options, radiobutton_news_popup_no, "radiobutton_news_popup_no");
  GLADE_HOOKUP_OBJECT (window_options, radiobutton_news_popup_user, "radiobutton_news_popup_user");
  GLADE_HOOKUP_OBJECT (window_options, radiobutton_news_popup_always, "radiobutton_news_popup_always");
  GLADE_HOOKUP_OBJECT (window_options, label48, "label48");
  GLADE_HOOKUP_OBJECT (window_options, hseparator1, "hseparator1");
  GLADE_HOOKUP_OBJECT (window_options, hbox1, "hbox1");
  GLADE_HOOKUP_OBJECT (window_options, vbox2, "vbox2");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_save_global, "checkbutton_save_global");
  GLADE_HOOKUP_OBJECT (window_options, checkbutton_save_user, "checkbutton_save_user");
  GLADE_HOOKUP_OBJECT (window_options, button_ok, "button_ok");
  GLADE_HOOKUP_OBJECT (window_options, button_cancel, "button_cancel");
  GLADE_HOOKUP_OBJECT_NO_REF (window_options, tooltips, "tooltips");

  gtk_window_add_accel_group (GTK_WINDOW (window_options), accel_group);

  return window_options;
}

GtkWidget*
create_window_constants (void)
{
  GtkWidget *window_constants;
  GtkWidget *vbox12;
  GtkWidget *notebook_constants;
  GtkWidget *scrolledwindow1;
  GtkWidget *treeview_constants_integer;
  GtkWidget *label50;
  GtkWidget *scrolledwindow2;
  GtkWidget *treeview_constants_float;
  GtkWidget *label51;
  GtkWidget *scrolledwindow3;
  GtkWidget *treeview_constants_string;
  GtkWidget *label52;
  GtkWidget *scrolledwindow4;
  GtkWidget *treeview_constants_app;
  GtkWidget *label53;
  GtkWidget *hseparator9;
  GtkWidget *button_constants_save;
  GtkWidget *alignment6;
  GtkWidget *hbox22;
  GtkWidget *image6;
  GtkWidget *label56;
  GtkWidget *button_constants_reload;
  GtkWidget *alignment4;
  GtkWidget *hbox20;
  GtkWidget *image4;
  GtkWidget *label54;
  GtkWidget *button_constants_close;
  GtkWidget *alignment5;
  GtkWidget *hbox21;
  GtkWidget *image5;
  GtkWidget *label55;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  window_constants = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_constants), 5);
  gtk_window_set_position (GTK_WINDOW (window_constants), GTK_WIN_POS_CENTER);
  gtk_window_set_default_size (GTK_WINDOW (window_constants), 650, 600);

  vbox12 = gtk_vbox_new (FALSE, 5);
  gtk_widget_show (vbox12);
  gtk_container_add (GTK_CONTAINER (window_constants), vbox12);

  notebook_constants = gtk_notebook_new ();
  gtk_widget_show (notebook_constants);
  gtk_box_pack_start (GTK_BOX (vbox12), notebook_constants, TRUE, TRUE, 0);

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow1);
  gtk_container_add (GTK_CONTAINER (notebook_constants), scrolledwindow1);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_SHADOW_IN);

  treeview_constants_integer = gtk_tree_view_new ();
  gtk_widget_show (treeview_constants_integer);
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), treeview_constants_integer);

  label50 = gtk_label_new (_("Integer"));
  gtk_widget_show (label50);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_constants), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_constants), 0), label50);

  scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow2);
  gtk_container_add (GTK_CONTAINER (notebook_constants), scrolledwindow2);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_SHADOW_IN);

  treeview_constants_float = gtk_tree_view_new ();
  gtk_widget_show (treeview_constants_float);
  gtk_container_add (GTK_CONTAINER (scrolledwindow2), treeview_constants_float);

  label51 = gtk_label_new (_("Float"));
  gtk_widget_show (label51);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_constants), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_constants), 1), label51);

  scrolledwindow3 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow3);
  gtk_container_add (GTK_CONTAINER (notebook_constants), scrolledwindow3);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow3), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow3), GTK_SHADOW_IN);

  treeview_constants_string = gtk_tree_view_new ();
  gtk_widget_show (treeview_constants_string);
  gtk_container_add (GTK_CONTAINER (scrolledwindow3), treeview_constants_string);

  label52 = gtk_label_new (_("String"));
  gtk_widget_show (label52);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_constants), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_constants), 2), label52);

  scrolledwindow4 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow4);
  gtk_container_add (GTK_CONTAINER (notebook_constants), scrolledwindow4);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow4), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow4), GTK_SHADOW_IN);

  treeview_constants_app = gtk_tree_view_new ();
  gtk_widget_show (treeview_constants_app);
  gtk_container_add (GTK_CONTAINER (scrolledwindow4), treeview_constants_app);

  label53 = gtk_label_new (_("Appearance"));
  gtk_widget_show (label53);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_constants), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_constants), 3), label53);

  hseparator9 = gtk_hseparator_new ();
  gtk_widget_show (hseparator9);
  gtk_box_pack_start (GTK_BOX (vbox12), hseparator9, FALSE, TRUE, 0);
  gtk_widget_set_size_request (hseparator9, -1, 10);

  button_constants_save = gtk_button_new ();
  gtk_widget_show (button_constants_save);
  gtk_box_pack_start (GTK_BOX (vbox12), button_constants_save, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_constants_save, _("Save changes to the constants file. DON'T DO THIS UNLESS YOU REALLY KNOW WHAT YOU ARE DOING."), NULL);

  alignment6 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment6);
  gtk_container_add (GTK_CONTAINER (button_constants_save), alignment6);

  hbox22 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox22);
  gtk_container_add (GTK_CONTAINER (alignment6), hbox22);

  image6 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image6);
  gtk_box_pack_start (GTK_BOX (hbox22), image6, FALSE, FALSE, 0);

  label56 = gtk_label_new_with_mnemonic (_("Save to file"));
  gtk_widget_show (label56);
  gtk_box_pack_start (GTK_BOX (hbox22), label56, FALSE, FALSE, 0);

  button_constants_reload = gtk_button_new ();
  gtk_widget_show (button_constants_reload);
  gtk_box_pack_start (GTK_BOX (vbox12), button_constants_reload, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_constants_reload, _("Reload constants files. This will overwrite any changes you made in the current game session."), NULL);

  alignment4 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment4);
  gtk_container_add (GTK_CONTAINER (button_constants_reload), alignment4);

  hbox20 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox20);
  gtk_container_add (GTK_CONTAINER (alignment4), hbox20);

  image4 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image4);
  gtk_box_pack_start (GTK_BOX (hbox20), image4, FALSE, FALSE, 0);

  label54 = gtk_label_new_with_mnemonic (_("Reload from file"));
  gtk_widget_show (label54);
  gtk_box_pack_start (GTK_BOX (hbox20), label54, FALSE, FALSE, 0);

  button_constants_close = gtk_button_new ();
  gtk_widget_show (button_constants_close);
  gtk_box_pack_start (GTK_BOX (vbox12), button_constants_close, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_constants_close, _("Close window. Changes will only be saved for the current session, unless you also save to file."), NULL);
  gtk_widget_add_accelerator (button_constants_close, "clicked", accel_group,
                              GDK_Escape, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  alignment5 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment5);
  gtk_container_add (GTK_CONTAINER (button_constants_close), alignment5);

  hbox21 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox21);
  gtk_container_add (GTK_CONTAINER (alignment5), hbox21);

  image5 = gtk_image_new_from_stock ("gtk-close", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image5);
  gtk_box_pack_start (GTK_BOX (hbox21), image5, FALSE, FALSE, 0);

  label55 = gtk_label_new_with_mnemonic (_("Close"));
  gtk_widget_show (label55);
  gtk_box_pack_start (GTK_BOX (hbox21), label55, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) window_constants, "destroy_event",
                    G_CALLBACK (on_window_constants_destroy_event),
                    NULL);
  g_signal_connect ((gpointer) window_constants, "delete_event",
                    G_CALLBACK (on_window_constants_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_constants_save, "clicked",
                    G_CALLBACK (on_button_constants_save_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_constants_reload, "clicked",
                    G_CALLBACK (on_button_constants_reload_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_constants_close, "clicked",
                    G_CALLBACK (on_button_constants_close_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_constants, window_constants, "window_constants");
  GLADE_HOOKUP_OBJECT (window_constants, vbox12, "vbox12");
  GLADE_HOOKUP_OBJECT (window_constants, notebook_constants, "notebook_constants");
  GLADE_HOOKUP_OBJECT (window_constants, scrolledwindow1, "scrolledwindow1");
  GLADE_HOOKUP_OBJECT (window_constants, treeview_constants_integer, "treeview_constants_integer");
  GLADE_HOOKUP_OBJECT (window_constants, label50, "label50");
  GLADE_HOOKUP_OBJECT (window_constants, scrolledwindow2, "scrolledwindow2");
  GLADE_HOOKUP_OBJECT (window_constants, treeview_constants_float, "treeview_constants_float");
  GLADE_HOOKUP_OBJECT (window_constants, label51, "label51");
  GLADE_HOOKUP_OBJECT (window_constants, scrolledwindow3, "scrolledwindow3");
  GLADE_HOOKUP_OBJECT (window_constants, treeview_constants_string, "treeview_constants_string");
  GLADE_HOOKUP_OBJECT (window_constants, label52, "label52");
  GLADE_HOOKUP_OBJECT (window_constants, scrolledwindow4, "scrolledwindow4");
  GLADE_HOOKUP_OBJECT (window_constants, treeview_constants_app, "treeview_constants_app");
  GLADE_HOOKUP_OBJECT (window_constants, label53, "label53");
  GLADE_HOOKUP_OBJECT (window_constants, hseparator9, "hseparator9");
  GLADE_HOOKUP_OBJECT (window_constants, button_constants_save, "button_constants_save");
  GLADE_HOOKUP_OBJECT (window_constants, alignment6, "alignment6");
  GLADE_HOOKUP_OBJECT (window_constants, hbox22, "hbox22");
  GLADE_HOOKUP_OBJECT (window_constants, image6, "image6");
  GLADE_HOOKUP_OBJECT (window_constants, label56, "label56");
  GLADE_HOOKUP_OBJECT (window_constants, button_constants_reload, "button_constants_reload");
  GLADE_HOOKUP_OBJECT (window_constants, alignment4, "alignment4");
  GLADE_HOOKUP_OBJECT (window_constants, hbox20, "hbox20");
  GLADE_HOOKUP_OBJECT (window_constants, image4, "image4");
  GLADE_HOOKUP_OBJECT (window_constants, label54, "label54");
  GLADE_HOOKUP_OBJECT (window_constants, button_constants_close, "button_constants_close");
  GLADE_HOOKUP_OBJECT (window_constants, alignment5, "alignment5");
  GLADE_HOOKUP_OBJECT (window_constants, hbox21, "hbox21");
  GLADE_HOOKUP_OBJECT (window_constants, image5, "image5");
  GLADE_HOOKUP_OBJECT (window_constants, label55, "label55");
  GLADE_HOOKUP_OBJECT_NO_REF (window_constants, tooltips, "tooltips");

  gtk_window_add_accel_group (GTK_WINDOW (window_constants), accel_group);

  return window_constants;
}

