/* THIS FILE WILL BE OVERWRITTEN BY DEV-C++ */
/* DO NOT EDIT! */

#include <windows.h> // include for version info constants


A ICON MOVEABLE PURE LOADONCALL DISCARDABLE "bygfoot.ico"

//
// TO CHANGE VERSION INFORMATION, EDIT PROJECT OPTIONS...
//
1 VERSIONINFO
FILEVERSION 0,1,1,1
PRODUCTVERSION 0,1,1,1
FILETYPE VFT_APP
{
  BLOCK "StringFileInfo"
	 {
		 BLOCK "041C04E4"
		 {
			 VALUE "CompanyName", ""
			 VALUE "FileVersion", ""
			 VALUE "FileDescription", "Developed using the Dev-C++ IDE"
			 VALUE "InternalName", ""
			 VALUE "LegalCopyright", ""
			 VALUE "LegalTrademarks", ""
			 VALUE "OriginalFilename", ""
			 VALUE "ProductName", ""
			 VALUE "ProductVersion", ""
		 }
	 }
  BLOCK "VarFileInfo"
	 {
		 VALUE "Translation", 0x041C, 1252
	 }
}

