/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "misc2_callbacks.h"
#include "misc2_interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

GtkWidget*
create_window_job_offer (void)
{
  GtkWidget *window_job_offer;
  GtkWidget *vbox5;
  GtkWidget *label_text;
  GtkWidget *hseparator5;
  GtkWidget *hbox5;
  GtkWidget *vbox6;
  GtkWidget *label15;
  GtkWidget *label16;
  GtkWidget *label17;
  GtkWidget *label18;
  GtkWidget *label19;
  GtkWidget *label14;
  GtkWidget *vseparator3;
  GtkWidget *vbox7;
  GtkWidget *label_name;
  GtkWidget *label_league;
  GtkWidget *label_rank;
  GtkWidget *label_money;
  GtkWidget *label_cap;
  GtkWidget *label_saf;
  GtkWidget *hseparator6;
  GtkWidget *label28;
  GtkWidget *hbox17;
  GtkWidget *label42;
  GtkWidget *label_average_skill;
  GtkWidget *scrolledwindow1;
  GtkWidget *treeview_players;
  GtkWidget *hseparator7;
  GtkWidget *label_text2;
  GtkWidget *hbox6;
  GtkWidget *button_ok;
  GtkWidget *alignment5;
  GtkWidget *hbox9;
  GtkWidget *image5;
  GtkWidget *label31;
  GtkWidget *button_cancel;

  window_job_offer = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_job_offer), 6);
  gtk_window_set_title (GTK_WINDOW (window_job_offer), _("Job offer"));
  gtk_window_set_position (GTK_WINDOW (window_job_offer), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (window_job_offer), TRUE);
  gtk_window_set_default_size (GTK_WINDOW (window_job_offer), 500, 600);

  vbox5 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox5);
  gtk_container_add (GTK_CONTAINER (window_job_offer), vbox5);

  label_text = gtk_label_new ("");
  gtk_widget_show (label_text);
  gtk_box_pack_start (GTK_BOX (vbox5), label_text, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_text), TRUE);

  hseparator5 = gtk_hseparator_new ();
  gtk_widget_show (hseparator5);
  gtk_box_pack_start (GTK_BOX (vbox5), hseparator5, FALSE, TRUE, 0);
  gtk_widget_set_size_request (hseparator5, 1, 10);

  hbox5 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox5);
  gtk_box_pack_start (GTK_BOX (vbox5), hbox5, FALSE, TRUE, 0);

  vbox6 = gtk_vbox_new (FALSE, 3);
  gtk_widget_show (vbox6);
  gtk_box_pack_start (GTK_BOX (hbox5), vbox6, FALSE, TRUE, 0);

  label15 = gtk_label_new (_("Name"));
  gtk_widget_show (label15);
  gtk_box_pack_start (GTK_BOX (vbox6), label15, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label15), 2.23517e-10, 0.5);

  label16 = gtk_label_new (_("League"));
  gtk_widget_show (label16);
  gtk_box_pack_start (GTK_BOX (vbox6), label16, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label16), 2.23517e-10, 0.5);

  label17 = gtk_label_new (_("Rank"));
  gtk_widget_show (label17);
  gtk_box_pack_start (GTK_BOX (vbox6), label17, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label17), 2.23517e-10, 0.5);

  label18 = gtk_label_new (_("Money (approx.)"));
  gtk_widget_show (label18);
  gtk_box_pack_start (GTK_BOX (vbox6), label18, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label18), 2.23517e-10, 0.5);

  label19 = gtk_label_new (_("Stadium capacity"));
  gtk_widget_show (label19);
  gtk_box_pack_start (GTK_BOX (vbox6), label19, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label19), 2.23517e-10, 0.5);

  label14 = gtk_label_new (_("Stadium safety"));
  gtk_widget_show (label14);
  gtk_box_pack_start (GTK_BOX (vbox6), label14, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label14), 0, 0.5);

  vseparator3 = gtk_vseparator_new ();
  gtk_widget_show (vseparator3);
  gtk_box_pack_start (GTK_BOX (hbox5), vseparator3, FALSE, TRUE, 0);
  gtk_widget_set_size_request (vseparator3, 10, 1);

  vbox7 = gtk_vbox_new (FALSE, 3);
  gtk_widget_show (vbox7);
  gtk_box_pack_start (GTK_BOX (hbox5), vbox7, TRUE, TRUE, 0);

  label_name = gtk_label_new ("");
  gtk_widget_show (label_name);
  gtk_box_pack_start (GTK_BOX (vbox7), label_name, FALSE, FALSE, 0);

  label_league = gtk_label_new ("");
  gtk_widget_show (label_league);
  gtk_box_pack_start (GTK_BOX (vbox7), label_league, FALSE, FALSE, 0);

  label_rank = gtk_label_new ("");
  gtk_widget_show (label_rank);
  gtk_box_pack_start (GTK_BOX (vbox7), label_rank, FALSE, FALSE, 0);

  label_money = gtk_label_new ("");
  gtk_widget_show (label_money);
  gtk_box_pack_start (GTK_BOX (vbox7), label_money, FALSE, FALSE, 0);

  label_cap = gtk_label_new ("");
  gtk_widget_show (label_cap);
  gtk_box_pack_start (GTK_BOX (vbox7), label_cap, FALSE, FALSE, 0);

  label_saf = gtk_label_new ("");
  gtk_widget_show (label_saf);
  gtk_box_pack_start (GTK_BOX (vbox7), label_saf, FALSE, FALSE, 0);

  hseparator6 = gtk_hseparator_new ();
  gtk_widget_show (hseparator6);
  gtk_box_pack_start (GTK_BOX (vbox5), hseparator6, FALSE, TRUE, 0);
  gtk_widget_set_size_request (hseparator6, 1, 10);

  label28 = gtk_label_new (_("Player list"));
  gtk_widget_show (label28);
  gtk_box_pack_start (GTK_BOX (vbox5), label28, FALSE, FALSE, 0);

  hbox17 = gtk_hbox_new (FALSE, 5);
  gtk_widget_show (hbox17);
  gtk_box_pack_start (GTK_BOX (vbox5), hbox17, FALSE, FALSE, 0);

  label42 = gtk_label_new (_("Average skill:"));
  gtk_widget_show (label42);
  gtk_box_pack_start (GTK_BOX (hbox17), label42, FALSE, FALSE, 0);

  label_average_skill = gtk_label_new ("");
  gtk_widget_show (label_average_skill);
  gtk_box_pack_start (GTK_BOX (hbox17), label_average_skill, FALSE, FALSE, 0);

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow1);
  gtk_box_pack_start (GTK_BOX (vbox5), scrolledwindow1, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow1), 4);

  treeview_players = gtk_tree_view_new ();
  gtk_widget_show (treeview_players);
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), treeview_players);

  hseparator7 = gtk_hseparator_new ();
  gtk_widget_show (hseparator7);
  gtk_box_pack_start (GTK_BOX (vbox5), hseparator7, FALSE, TRUE, 0);
  gtk_widget_set_size_request (hseparator7, 1, 10);

  label_text2 = gtk_label_new ("");
  gtk_widget_show (label_text2);
  gtk_box_pack_start (GTK_BOX (vbox5), label_text2, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label_text2), 0, 5);

  hbox6 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox6);
  gtk_box_pack_start (GTK_BOX (vbox5), hbox6, FALSE, TRUE, 0);

  button_ok = gtk_button_new ();
  gtk_widget_show (button_ok);
  gtk_box_pack_start (GTK_BOX (hbox6), button_ok, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_ok), 2);

  alignment5 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment5);
  gtk_container_add (GTK_CONTAINER (button_ok), alignment5);

  hbox9 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox9);
  gtk_container_add (GTK_CONTAINER (alignment5), hbox9);

  image5 = gtk_image_new_from_stock ("gtk-apply", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image5);
  gtk_box_pack_start (GTK_BOX (hbox9), image5, FALSE, FALSE, 0);

  label31 = gtk_label_new_with_mnemonic (_("OK"));
  gtk_widget_show (label31);
  gtk_box_pack_start (GTK_BOX (hbox9), label31, FALSE, FALSE, 0);

  button_cancel = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (button_cancel);
  gtk_box_pack_start (GTK_BOX (hbox6), button_cancel, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_cancel), 2);

  g_signal_connect ((gpointer) window_job_offer, "delete_event",
                    G_CALLBACK (on_window_job_offer_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_ok, "clicked",
                    G_CALLBACK (on_button_offer_ok_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_cancel, "clicked",
                    G_CALLBACK (on_button_offer_cancel_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_job_offer, window_job_offer, "window_job_offer");
  GLADE_HOOKUP_OBJECT (window_job_offer, vbox5, "vbox5");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_text, "label_text");
  GLADE_HOOKUP_OBJECT (window_job_offer, hseparator5, "hseparator5");
  GLADE_HOOKUP_OBJECT (window_job_offer, hbox5, "hbox5");
  GLADE_HOOKUP_OBJECT (window_job_offer, vbox6, "vbox6");
  GLADE_HOOKUP_OBJECT (window_job_offer, label15, "label15");
  GLADE_HOOKUP_OBJECT (window_job_offer, label16, "label16");
  GLADE_HOOKUP_OBJECT (window_job_offer, label17, "label17");
  GLADE_HOOKUP_OBJECT (window_job_offer, label18, "label18");
  GLADE_HOOKUP_OBJECT (window_job_offer, label19, "label19");
  GLADE_HOOKUP_OBJECT (window_job_offer, label14, "label14");
  GLADE_HOOKUP_OBJECT (window_job_offer, vseparator3, "vseparator3");
  GLADE_HOOKUP_OBJECT (window_job_offer, vbox7, "vbox7");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_name, "label_name");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_league, "label_league");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_rank, "label_rank");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_money, "label_money");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_cap, "label_cap");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_saf, "label_saf");
  GLADE_HOOKUP_OBJECT (window_job_offer, hseparator6, "hseparator6");
  GLADE_HOOKUP_OBJECT (window_job_offer, label28, "label28");
  GLADE_HOOKUP_OBJECT (window_job_offer, hbox17, "hbox17");
  GLADE_HOOKUP_OBJECT (window_job_offer, label42, "label42");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_average_skill, "label_average_skill");
  GLADE_HOOKUP_OBJECT (window_job_offer, scrolledwindow1, "scrolledwindow1");
  GLADE_HOOKUP_OBJECT (window_job_offer, treeview_players, "treeview_players");
  GLADE_HOOKUP_OBJECT (window_job_offer, hseparator7, "hseparator7");
  GLADE_HOOKUP_OBJECT (window_job_offer, label_text2, "label_text2");
  GLADE_HOOKUP_OBJECT (window_job_offer, hbox6, "hbox6");
  GLADE_HOOKUP_OBJECT (window_job_offer, button_ok, "button_ok");
  GLADE_HOOKUP_OBJECT (window_job_offer, alignment5, "alignment5");
  GLADE_HOOKUP_OBJECT (window_job_offer, hbox9, "hbox9");
  GLADE_HOOKUP_OBJECT (window_job_offer, image5, "image5");
  GLADE_HOOKUP_OBJECT (window_job_offer, label31, "label31");
  GLADE_HOOKUP_OBJECT (window_job_offer, button_cancel, "button_cancel");

  return window_job_offer;
}

GtkWidget*
create_window_progress (void)
{
  GtkWidget *window_progress;
  GtkWidget *vbox28;
  GtkWidget *image_match;
  GtkWidget *progressbar;

  window_progress = gtk_window_new (GTK_WINDOW_POPUP);
  gtk_window_set_position (GTK_WINDOW (window_progress), GTK_WIN_POS_CENTER_ALWAYS);
  gtk_window_set_modal (GTK_WINDOW (window_progress), TRUE);
  gtk_window_set_default_size (GTK_WINDOW (window_progress), 300, -1);
  gtk_window_set_type_hint (GTK_WINDOW (window_progress), GDK_WINDOW_TYPE_HINT_SPLASHSCREEN);

  vbox28 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox28);
  gtk_container_add (GTK_CONTAINER (window_progress), vbox28);

  image_match = create_pixmap (window_progress, NULL);
  gtk_widget_show (image_match);
  gtk_box_pack_start (GTK_BOX (vbox28), image_match, FALSE, FALSE, 0);

  progressbar = gtk_progress_bar_new ();
  gtk_widget_show (progressbar);
  gtk_box_pack_start (GTK_BOX (vbox28), progressbar, FALSE, FALSE, 0);
  gtk_widget_set_size_request (progressbar, 200, 20);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_progress, window_progress, "window_progress");
  GLADE_HOOKUP_OBJECT (window_progress, vbox28, "vbox28");
  GLADE_HOOKUP_OBJECT (window_progress, image_match, "image_match");
  GLADE_HOOKUP_OBJECT (window_progress, progressbar, "progressbar");

  return window_progress;
}

GtkWidget*
create_window_warning (void)
{
  GtkWidget *window_warning;
  GtkWidget *vbox13;
  GtkWidget *image7;
  GtkWidget *label_warning;
  GtkWidget *button_warning;

  window_warning = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_warning), 10);
  gtk_window_set_position (GTK_WINDOW (window_warning), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (window_warning), TRUE);

  vbox13 = gtk_vbox_new (FALSE, 10);
  gtk_widget_show (vbox13);
  gtk_container_add (GTK_CONTAINER (window_warning), vbox13);

  image7 = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image7);
  gtk_box_pack_start (GTK_BOX (vbox13), image7, FALSE, TRUE, 0);

  label_warning = gtk_label_new ("");
  gtk_widget_show (label_warning);
  gtk_box_pack_start (GTK_BOX (vbox13), label_warning, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_warning), TRUE);

  button_warning = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (button_warning);
  gtk_box_pack_start (GTK_BOX (vbox13), button_warning, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) window_warning, "delete_event",
                    G_CALLBACK (on_button_warning_clicked),
                    NULL);
  g_signal_connect ((gpointer) window_warning, "destroy_event",
                    G_CALLBACK (on_button_warning_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_warning, "clicked",
                    G_CALLBACK (on_button_warning_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_warning, window_warning, "window_warning");
  GLADE_HOOKUP_OBJECT (window_warning, vbox13, "vbox13");
  GLADE_HOOKUP_OBJECT (window_warning, image7, "image7");
  GLADE_HOOKUP_OBJECT (window_warning, label_warning, "label_warning");
  GLADE_HOOKUP_OBJECT (window_warning, button_warning, "button_warning");

  return window_warning;
}

GtkWidget*
create_window_digits (void)
{
  GtkWidget *window_digits;
  GtkWidget *vbox14;
  GtkWidget *label_main;
  GtkWidget *hbox15;
  GtkWidget *vbox15;
  GtkWidget *label_1;
  GtkObject *spinbutton1_adj;
  GtkWidget *spinbutton1;
  GtkWidget *vbox16;
  GtkWidget *label_2;
  GtkObject *spinbutton2_adj;
  GtkWidget *spinbutton2;
  GtkWidget *hseparator10;
  GtkWidget *vbox29;
  GtkWidget *button_digits_ok;
  GtkWidget *button_digits_alr;
  GtkWidget *alignment16;
  GtkWidget *hbox38;
  GtkWidget *image23;
  GtkWidget *label63;
  GtkWidget *button_digits_cancel;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  window_digits = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_digits), 5);
  gtk_window_set_position (GTK_WINDOW (window_digits), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (window_digits), TRUE);

  vbox14 = gtk_vbox_new (FALSE, 10);
  gtk_widget_show (vbox14);
  gtk_container_add (GTK_CONTAINER (window_digits), vbox14);

  label_main = gtk_label_new ("");
  gtk_widget_show (label_main);
  gtk_box_pack_start (GTK_BOX (vbox14), label_main, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_main), TRUE);

  hbox15 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox15);
  gtk_box_pack_start (GTK_BOX (vbox14), hbox15, FALSE, TRUE, 0);

  vbox15 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox15);
  gtk_box_pack_start (GTK_BOX (hbox15), vbox15, TRUE, TRUE, 0);

  label_1 = gtk_label_new ("");
  gtk_widget_show (label_1);
  gtk_box_pack_start (GTK_BOX (vbox15), label_1, FALSE, FALSE, 0);

  spinbutton1_adj = gtk_adjustment_new (1, 0, 100000000, 100, 1000, 0);
  spinbutton1 = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton1_adj), 1, 0);
  gtk_widget_show (spinbutton1);
  gtk_box_pack_start (GTK_BOX (vbox15), spinbutton1, FALSE, FALSE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton1), TRUE);

  vbox16 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox16);
  gtk_box_pack_start (GTK_BOX (hbox15), vbox16, TRUE, TRUE, 0);

  label_2 = gtk_label_new ("");
  gtk_widget_show (label_2);
  gtk_box_pack_start (GTK_BOX (vbox16), label_2, FALSE, FALSE, 0);

  spinbutton2_adj = gtk_adjustment_new (1, 0, 100000000, 10, 100, 0);
  spinbutton2 = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton2_adj), 1, 0);
  gtk_widget_show (spinbutton2);
  gtk_box_pack_start (GTK_BOX (vbox16), spinbutton2, FALSE, FALSE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton2), TRUE);

  hseparator10 = gtk_hseparator_new ();
  gtk_widget_show (hseparator10);
  gtk_box_pack_start (GTK_BOX (vbox14), hseparator10, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator10, -1, 10);

  vbox29 = gtk_vbox_new (FALSE, 3);
  gtk_widget_show (vbox29);
  gtk_box_pack_start (GTK_BOX (vbox14), vbox29, TRUE, FALSE, 0);

  button_digits_ok = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (button_digits_ok);
  gtk_box_pack_start (GTK_BOX (vbox29), button_digits_ok, FALSE, FALSE, 0);

  button_digits_alr = gtk_button_new ();
  gtk_box_pack_start (GTK_BOX (vbox29), button_digits_alr, FALSE, FALSE, 0);

  alignment16 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment16);
  gtk_container_add (GTK_CONTAINER (button_digits_alr), alignment16);

  hbox38 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox38);
  gtk_container_add (GTK_CONTAINER (alignment16), hbox38);

  image23 = gtk_image_new_from_stock ("gtk-jump-to", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image23);
  gtk_box_pack_start (GTK_BOX (hbox38), image23, FALSE, FALSE, 0);

  label63 = gtk_label_new_with_mnemonic (_("Confirm & schedule repayment"));
  gtk_widget_show (label63);
  gtk_box_pack_start (GTK_BOX (hbox38), label63, FALSE, FALSE, 0);

  button_digits_cancel = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (button_digits_cancel);
  gtk_box_pack_start (GTK_BOX (vbox29), button_digits_cancel, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_digits_cancel, _("Esc"), NULL);
  gtk_widget_add_accelerator (button_digits_cancel, "clicked", accel_group,
                              GDK_Escape, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  g_signal_connect ((gpointer) window_digits, "delete_event",
                    G_CALLBACK (on_window_digits_delete_event),
                    NULL);
  g_signal_connect ((gpointer) spinbutton1, "activate",
                    G_CALLBACK (on_spinbutton1_activate),
                    NULL);
  g_signal_connect ((gpointer) spinbutton2, "activate",
                    G_CALLBACK (on_spinbutton2_activate),
                    NULL);
  g_signal_connect ((gpointer) button_digits_ok, "clicked",
                    G_CALLBACK (on_button_digits_ok_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_digits_alr, "clicked",
                    G_CALLBACK (on_button_digits_alr_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_digits_cancel, "clicked",
                    G_CALLBACK (on_button_digits_cancel_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_digits, window_digits, "window_digits");
  GLADE_HOOKUP_OBJECT (window_digits, vbox14, "vbox14");
  GLADE_HOOKUP_OBJECT (window_digits, label_main, "label_main");
  GLADE_HOOKUP_OBJECT (window_digits, hbox15, "hbox15");
  GLADE_HOOKUP_OBJECT (window_digits, vbox15, "vbox15");
  GLADE_HOOKUP_OBJECT (window_digits, label_1, "label_1");
  GLADE_HOOKUP_OBJECT (window_digits, spinbutton1, "spinbutton1");
  GLADE_HOOKUP_OBJECT (window_digits, vbox16, "vbox16");
  GLADE_HOOKUP_OBJECT (window_digits, label_2, "label_2");
  GLADE_HOOKUP_OBJECT (window_digits, spinbutton2, "spinbutton2");
  GLADE_HOOKUP_OBJECT (window_digits, hseparator10, "hseparator10");
  GLADE_HOOKUP_OBJECT (window_digits, vbox29, "vbox29");
  GLADE_HOOKUP_OBJECT (window_digits, button_digits_ok, "button_digits_ok");
  GLADE_HOOKUP_OBJECT (window_digits, button_digits_alr, "button_digits_alr");
  GLADE_HOOKUP_OBJECT (window_digits, alignment16, "alignment16");
  GLADE_HOOKUP_OBJECT (window_digits, hbox38, "hbox38");
  GLADE_HOOKUP_OBJECT (window_digits, image23, "image23");
  GLADE_HOOKUP_OBJECT (window_digits, label63, "label63");
  GLADE_HOOKUP_OBJECT (window_digits, button_digits_cancel, "button_digits_cancel");
  GLADE_HOOKUP_OBJECT_NO_REF (window_digits, tooltips, "tooltips");

  gtk_window_add_accel_group (GTK_WINDOW (window_digits), accel_group);

  return window_digits;
}

GtkWidget*
create_window_yesno (void)
{
  GtkWidget *window_yesno;
  GtkWidget *vbox17;
  GtkWidget *image8;
  GtkWidget *label_yesno;
  GtkWidget *hbox18;
  GtkWidget *button_yesno_yes;
  GtkWidget *button_yesno_no;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  window_yesno = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_yesno), 5);
  gtk_window_set_position (GTK_WINDOW (window_yesno), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (window_yesno), TRUE);

  vbox17 = gtk_vbox_new (FALSE, 5);
  gtk_widget_show (vbox17);
  gtk_container_add (GTK_CONTAINER (window_yesno), vbox17);

  image8 = gtk_image_new_from_stock ("gtk-dialog-question", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image8);
  gtk_box_pack_start (GTK_BOX (vbox17), image8, FALSE, FALSE, 0);

  label_yesno = gtk_label_new ("");
  gtk_widget_show (label_yesno);
  gtk_box_pack_start (GTK_BOX (vbox17), label_yesno, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_yesno), TRUE);

  hbox18 = gtk_hbox_new (FALSE, 3);
  gtk_widget_show (hbox18);
  gtk_box_pack_start (GTK_BOX (vbox17), hbox18, FALSE, FALSE, 0);

  button_yesno_yes = gtk_button_new_from_stock ("gtk-yes");
  gtk_widget_show (button_yesno_yes);
  gtk_box_pack_start (GTK_BOX (hbox18), button_yesno_yes, TRUE, TRUE, 0);

  button_yesno_no = gtk_button_new_from_stock ("gtk-no");
  gtk_widget_show (button_yesno_no);
  gtk_box_pack_start (GTK_BOX (hbox18), button_yesno_no, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, button_yesno_no, _("Esc"), NULL);
  gtk_widget_add_accelerator (button_yesno_no, "clicked", accel_group,
                              GDK_Escape, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  g_signal_connect ((gpointer) window_yesno, "delete_event",
                    G_CALLBACK (on_window_yesno_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_yesno_yes, "clicked",
                    G_CALLBACK (on_button_yesno_yes_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_yesno_no, "clicked",
                    G_CALLBACK (on_button_yesno_no_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_yesno, window_yesno, "window_yesno");
  GLADE_HOOKUP_OBJECT (window_yesno, vbox17, "vbox17");
  GLADE_HOOKUP_OBJECT (window_yesno, image8, "image8");
  GLADE_HOOKUP_OBJECT (window_yesno, label_yesno, "label_yesno");
  GLADE_HOOKUP_OBJECT (window_yesno, hbox18, "hbox18");
  GLADE_HOOKUP_OBJECT (window_yesno, button_yesno_yes, "button_yesno_yes");
  GLADE_HOOKUP_OBJECT (window_yesno, button_yesno_no, "button_yesno_no");
  GLADE_HOOKUP_OBJECT_NO_REF (window_yesno, tooltips, "tooltips");

  gtk_window_add_accel_group (GTK_WINDOW (window_yesno), accel_group);

  return window_yesno;
}

GtkWidget*
create_window_contract (void)
{
  GtkWidget *window_contract;
  GtkWidget *vbox18;
  GtkWidget *image9;
  GtkWidget *label_contract;
  GtkWidget *table1;
  GtkWidget *radiobutton_contract1;
  GSList *radiobutton_contract1_group = NULL;
  GtkWidget *radiobutton_contract3;
  GtkWidget *radiobutton_contract4;
  GtkWidget *radiobutton_contract2;
  GtkObject *spinbutton_contract1_adj;
  GtkWidget *spinbutton_contract1;
  GtkObject *spinbutton_contract2_adj;
  GtkWidget *spinbutton_contract2;
  GtkObject *spinbutton_contract3_adj;
  GtkWidget *spinbutton_contract3;
  GtkObject *spinbutton_contract4_adj;
  GtkWidget *spinbutton_contract4;
  GtkWidget *hseparator8;
  GtkWidget *hbox19;
  GtkWidget *button_contract_offer;
  GtkWidget *alignment6;
  GtkWidget *hbox20;
  GtkWidget *image10;
  GtkWidget *label44;
  GtkWidget *button_contract_cancel;

  window_contract = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_contract), 5);
  gtk_window_set_position (GTK_WINDOW (window_contract), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (window_contract), TRUE);

  vbox18 = gtk_vbox_new (FALSE, 3);
  gtk_widget_show (vbox18);
  gtk_container_add (GTK_CONTAINER (window_contract), vbox18);

  image9 = gtk_image_new_from_stock ("gtk-new", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image9);
  gtk_box_pack_start (GTK_BOX (vbox18), image9, FALSE, FALSE, 0);

  label_contract = gtk_label_new ("");
  gtk_widget_show (label_contract);
  gtk_box_pack_start (GTK_BOX (vbox18), label_contract, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_contract), TRUE);

  table1 = gtk_table_new (4, 2, FALSE);
  gtk_widget_show (table1);
  gtk_box_pack_start (GTK_BOX (vbox18), table1, FALSE, FALSE, 0);
  gtk_table_set_col_spacings (GTK_TABLE (table1), 3);

  radiobutton_contract1 = gtk_radio_button_new_with_mnemonic (NULL, _("1 year"));
  gtk_widget_show (radiobutton_contract1);
  gtk_table_attach (GTK_TABLE (table1), radiobutton_contract1, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_contract1), radiobutton_contract1_group);
  radiobutton_contract1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_contract1));

  radiobutton_contract3 = gtk_radio_button_new_with_mnemonic (NULL, _("3 years"));
  gtk_widget_show (radiobutton_contract3);
  gtk_table_attach (GTK_TABLE (table1), radiobutton_contract3, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_contract3), radiobutton_contract1_group);
  radiobutton_contract1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_contract3));

  radiobutton_contract4 = gtk_radio_button_new_with_mnemonic (NULL, _("4 years"));
  gtk_widget_show (radiobutton_contract4);
  gtk_table_attach (GTK_TABLE (table1), radiobutton_contract4, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_contract4), radiobutton_contract1_group);
  radiobutton_contract1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_contract4));

  radiobutton_contract2 = gtk_radio_button_new_with_mnemonic (NULL, _("2 years"));
  gtk_widget_show (radiobutton_contract2);
  gtk_table_attach (GTK_TABLE (table1), radiobutton_contract2, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_contract2), radiobutton_contract1_group);
  radiobutton_contract1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_contract2));
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_contract2), TRUE);

  spinbutton_contract1_adj = gtk_adjustment_new (1, 1, 1000000, 1, 100, 0);
  spinbutton_contract1 = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_contract1_adj), 1, 0);
  gtk_widget_show (spinbutton_contract1);
  gtk_table_attach (GTK_TABLE (table1), spinbutton_contract1, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_contract1), TRUE);

  spinbutton_contract2_adj = gtk_adjustment_new (1, 1, 1000000, 1, 100, 0);
  spinbutton_contract2 = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_contract2_adj), 1, 0);
  gtk_widget_show (spinbutton_contract2);
  gtk_table_attach (GTK_TABLE (table1), spinbutton_contract2, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_contract3_adj = gtk_adjustment_new (1, 1, 1000000, 1, 100, 0);
  spinbutton_contract3 = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_contract3_adj), 1, 0);
  gtk_widget_show (spinbutton_contract3);
  gtk_table_attach (GTK_TABLE (table1), spinbutton_contract3, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_contract4_adj = gtk_adjustment_new (1, 1, 1000000, 1, 100, 0);
  spinbutton_contract4 = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_contract4_adj), 1, 0);
  gtk_widget_show (spinbutton_contract4);
  gtk_table_attach (GTK_TABLE (table1), spinbutton_contract4, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  hseparator8 = gtk_hseparator_new ();
  gtk_widget_show (hseparator8);
  gtk_box_pack_start (GTK_BOX (vbox18), hseparator8, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator8, 1, 10);

  hbox19 = gtk_hbox_new (FALSE, 3);
  gtk_widget_show (hbox19);
  gtk_box_pack_start (GTK_BOX (vbox18), hbox19, FALSE, FALSE, 0);

  button_contract_offer = gtk_button_new ();
  gtk_widget_show (button_contract_offer);
  gtk_box_pack_start (GTK_BOX (hbox19), button_contract_offer, TRUE, TRUE, 0);

  alignment6 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment6);
  gtk_container_add (GTK_CONTAINER (button_contract_offer), alignment6);

  hbox20 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox20);
  gtk_container_add (GTK_CONTAINER (alignment6), hbox20);

  image10 = gtk_image_new_from_stock ("gtk-apply", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image10);
  gtk_box_pack_start (GTK_BOX (hbox20), image10, FALSE, FALSE, 0);

  label44 = gtk_label_new_with_mnemonic (_("Make offer"));
  gtk_widget_show (label44);
  gtk_box_pack_start (GTK_BOX (hbox20), label44, FALSE, FALSE, 0);

  button_contract_cancel = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (button_contract_cancel);
  gtk_box_pack_start (GTK_BOX (hbox19), button_contract_cancel, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) window_contract, "delete_event",
                    G_CALLBACK (on_window_contract_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_contract_offer, "clicked",
                    G_CALLBACK (on_button_contract_offer_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_contract_cancel, "clicked",
                    G_CALLBACK (on_button_contract_cancel_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_contract, window_contract, "window_contract");
  GLADE_HOOKUP_OBJECT (window_contract, vbox18, "vbox18");
  GLADE_HOOKUP_OBJECT (window_contract, image9, "image9");
  GLADE_HOOKUP_OBJECT (window_contract, label_contract, "label_contract");
  GLADE_HOOKUP_OBJECT (window_contract, table1, "table1");
  GLADE_HOOKUP_OBJECT (window_contract, radiobutton_contract1, "radiobutton_contract1");
  GLADE_HOOKUP_OBJECT (window_contract, radiobutton_contract3, "radiobutton_contract3");
  GLADE_HOOKUP_OBJECT (window_contract, radiobutton_contract4, "radiobutton_contract4");
  GLADE_HOOKUP_OBJECT (window_contract, radiobutton_contract2, "radiobutton_contract2");
  GLADE_HOOKUP_OBJECT (window_contract, spinbutton_contract1, "spinbutton_contract1");
  GLADE_HOOKUP_OBJECT (window_contract, spinbutton_contract2, "spinbutton_contract2");
  GLADE_HOOKUP_OBJECT (window_contract, spinbutton_contract3, "spinbutton_contract3");
  GLADE_HOOKUP_OBJECT (window_contract, spinbutton_contract4, "spinbutton_contract4");
  GLADE_HOOKUP_OBJECT (window_contract, hseparator8, "hseparator8");
  GLADE_HOOKUP_OBJECT (window_contract, hbox19, "hbox19");
  GLADE_HOOKUP_OBJECT (window_contract, button_contract_offer, "button_contract_offer");
  GLADE_HOOKUP_OBJECT (window_contract, alignment6, "alignment6");
  GLADE_HOOKUP_OBJECT (window_contract, hbox20, "hbox20");
  GLADE_HOOKUP_OBJECT (window_contract, image10, "image10");
  GLADE_HOOKUP_OBJECT (window_contract, label44, "label44");
  GLADE_HOOKUP_OBJECT (window_contract, button_contract_cancel, "button_contract_cancel");

  return window_contract;
}

GtkWidget*
create_window_user_management (void)
{
  GtkWidget *window_user_management;
  GtkWidget *vbox19;
  GtkWidget *hbox23;
  GtkWidget *hpaned1;
  GtkWidget *vbox20;
  GtkWidget *label47;
  GtkWidget *scrolledwindow2;
  GtkWidget *viewport1;
  GtkWidget *treeview_user_management_users;
  GtkWidget *vbox21;
  GtkWidget *label46;
  GtkWidget *scrolledwindow3;
  GtkWidget *treeview_user_management_teams;
  GtkWidget *hbox21;
  GtkWidget *entry_user_management;
  GtkWidget *button_user_management_add;
  GtkWidget *alignment7;
  GtkWidget *hbox22;
  GtkWidget *image11;
  GtkWidget *label45;
  GtkWidget *hseparator9;
  GtkWidget *button_user_management_close;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  window_user_management = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_user_management), 5);
  gtk_window_set_position (GTK_WINDOW (window_user_management), GTK_WIN_POS_CENTER);
  gtk_window_set_default_size (GTK_WINDOW (window_user_management), 600, 550);

  vbox19 = gtk_vbox_new (FALSE, 5);
  gtk_widget_show (vbox19);
  gtk_container_add (GTK_CONTAINER (window_user_management), vbox19);

  hbox23 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox23);
  gtk_box_pack_start (GTK_BOX (vbox19), hbox23, TRUE, TRUE, 0);

  hpaned1 = gtk_hpaned_new ();
  gtk_widget_show (hpaned1);
  gtk_box_pack_start (GTK_BOX (hbox23), hpaned1, TRUE, TRUE, 0);
  gtk_paned_set_position (GTK_PANED (hpaned1), 200);

  vbox20 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox20);
  gtk_paned_pack1 (GTK_PANED (hpaned1), vbox20, FALSE, TRUE);

  label47 = gtk_label_new (_("Users -- click to remove"));
  gtk_widget_show (label47);
  gtk_box_pack_start (GTK_BOX (vbox20), label47, FALSE, FALSE, 0);

  scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow2);
  gtk_box_pack_start (GTK_BOX (vbox20), scrolledwindow2, TRUE, TRUE, 0);

  viewport1 = gtk_viewport_new (NULL, NULL);
  gtk_widget_show (viewport1);
  gtk_container_add (GTK_CONTAINER (scrolledwindow2), viewport1);

  treeview_user_management_users = gtk_tree_view_new ();
  gtk_widget_show (treeview_user_management_users);
  gtk_container_add (GTK_CONTAINER (viewport1), treeview_user_management_users);
  gtk_tooltips_set_tip (tooltips, treeview_user_management_users, _("Click on a user to remove him from the game."), NULL);

  vbox21 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox21);
  gtk_paned_pack2 (GTK_PANED (hpaned1), vbox21, TRUE, TRUE);

  label46 = gtk_label_new (_("Available teams"));
  gtk_widget_show (label46);
  gtk_box_pack_start (GTK_BOX (vbox21), label46, FALSE, FALSE, 0);

  scrolledwindow3 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow3);
  gtk_box_pack_start (GTK_BOX (vbox21), scrolledwindow3, TRUE, TRUE, 0);

  treeview_user_management_teams = gtk_tree_view_new ();
  gtk_widget_show (treeview_user_management_teams);
  gtk_container_add (GTK_CONTAINER (scrolledwindow3), treeview_user_management_teams);

  hbox21 = gtk_hbox_new (FALSE, 5);
  gtk_widget_show (hbox21);
  gtk_box_pack_start (GTK_BOX (vbox19), hbox21, FALSE, FALSE, 0);

  entry_user_management = gtk_entry_new ();
  gtk_widget_show (entry_user_management);
  gtk_box_pack_start (GTK_BOX (hbox21), entry_user_management, TRUE, TRUE, 0);

  button_user_management_add = gtk_button_new ();
  gtk_widget_show (button_user_management_add);
  gtk_box_pack_start (GTK_BOX (hbox21), button_user_management_add, FALSE, FALSE, 0);

  alignment7 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment7);
  gtk_container_add (GTK_CONTAINER (button_user_management_add), alignment7);

  hbox22 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox22);
  gtk_container_add (GTK_CONTAINER (alignment7), hbox22);

  image11 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image11);
  gtk_box_pack_start (GTK_BOX (hbox22), image11, FALSE, FALSE, 0);

  label45 = gtk_label_new_with_mnemonic (_("Add user"));
  gtk_widget_show (label45);
  gtk_box_pack_start (GTK_BOX (hbox22), label45, FALSE, FALSE, 0);

  hseparator9 = gtk_hseparator_new ();
  gtk_widget_show (hseparator9);
  gtk_box_pack_start (GTK_BOX (vbox19), hseparator9, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator9, 1, 10);

  button_user_management_close = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (button_user_management_close);
  gtk_box_pack_start (GTK_BOX (vbox19), button_user_management_close, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) window_user_management, "delete_event",
                    G_CALLBACK (on_window_user_management_delete_event),
                    NULL);
  g_signal_connect ((gpointer) treeview_user_management_users, "button_press_event",
                    G_CALLBACK (on_treeview_user_management_users_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) treeview_user_management_teams, "row_activated",
                    G_CALLBACK (on_treeview_user_management_teams_row_activated),
                    NULL);
  g_signal_connect ((gpointer) entry_user_management, "activate",
                    G_CALLBACK (on_entry_user_management_activate),
                    NULL);
  g_signal_connect ((gpointer) button_user_management_add, "clicked",
                    G_CALLBACK (on_button_user_management_add_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_user_management_close, "clicked",
                    G_CALLBACK (on_button_user_management_close_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_user_management, window_user_management, "window_user_management");
  GLADE_HOOKUP_OBJECT (window_user_management, vbox19, "vbox19");
  GLADE_HOOKUP_OBJECT (window_user_management, hbox23, "hbox23");
  GLADE_HOOKUP_OBJECT (window_user_management, hpaned1, "hpaned1");
  GLADE_HOOKUP_OBJECT (window_user_management, vbox20, "vbox20");
  GLADE_HOOKUP_OBJECT (window_user_management, label47, "label47");
  GLADE_HOOKUP_OBJECT (window_user_management, scrolledwindow2, "scrolledwindow2");
  GLADE_HOOKUP_OBJECT (window_user_management, viewport1, "viewport1");
  GLADE_HOOKUP_OBJECT (window_user_management, treeview_user_management_users, "treeview_user_management_users");
  GLADE_HOOKUP_OBJECT (window_user_management, vbox21, "vbox21");
  GLADE_HOOKUP_OBJECT (window_user_management, label46, "label46");
  GLADE_HOOKUP_OBJECT (window_user_management, scrolledwindow3, "scrolledwindow3");
  GLADE_HOOKUP_OBJECT (window_user_management, treeview_user_management_teams, "treeview_user_management_teams");
  GLADE_HOOKUP_OBJECT (window_user_management, hbox21, "hbox21");
  GLADE_HOOKUP_OBJECT (window_user_management, entry_user_management, "entry_user_management");
  GLADE_HOOKUP_OBJECT (window_user_management, button_user_management_add, "button_user_management_add");
  GLADE_HOOKUP_OBJECT (window_user_management, alignment7, "alignment7");
  GLADE_HOOKUP_OBJECT (window_user_management, hbox22, "hbox22");
  GLADE_HOOKUP_OBJECT (window_user_management, image11, "image11");
  GLADE_HOOKUP_OBJECT (window_user_management, label45, "label45");
  GLADE_HOOKUP_OBJECT (window_user_management, hseparator9, "hseparator9");
  GLADE_HOOKUP_OBJECT (window_user_management, button_user_management_close, "button_user_management_close");
  GLADE_HOOKUP_OBJECT_NO_REF (window_user_management, tooltips, "tooltips");

  return window_user_management;
}

GtkWidget*
create_window_debug (void)
{
  GtkWidget *window_debug;
  GtkWidget *vbox22;
  GtkWidget *label48;
  GtkWidget *hbox24;
  GtkWidget *entry_debug;
  GtkWidget *button_debug_apply;
  GtkWidget *button_debug_close;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  window_debug = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_debug), 5);
  gtk_window_set_title (GTK_WINDOW (window_debug), _("Debug"));
  gtk_window_set_position (GTK_WINDOW (window_debug), GTK_WIN_POS_CENTER);

  vbox22 = gtk_vbox_new (FALSE, 5);
  gtk_widget_show (vbox22);
  gtk_container_add (GTK_CONTAINER (window_debug), vbox22);

  label48 = gtk_label_new (_("Bygfoot debug window. If you got here by accident, CLOSE IMMEDIATELY (otherwise your CPU will be destroyed by overheating)."));
  gtk_widget_show (label48);
  gtk_box_pack_start (GTK_BOX (vbox22), label48, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label48), TRUE);

  hbox24 = gtk_hbox_new (FALSE, 3);
  gtk_widget_show (hbox24);
  gtk_box_pack_start (GTK_BOX (vbox22), hbox24, FALSE, FALSE, 0);

  entry_debug = gtk_entry_new ();
  gtk_widget_show (entry_debug);
  gtk_box_pack_start (GTK_BOX (hbox24), entry_debug, TRUE, TRUE, 0);

  button_debug_apply = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (button_debug_apply);
  gtk_box_pack_start (GTK_BOX (hbox24), button_debug_apply, FALSE, FALSE, 0);

  button_debug_close = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (button_debug_close);
  gtk_box_pack_start (GTK_BOX (vbox22), button_debug_close, FALSE, FALSE, 0);
  gtk_widget_add_accelerator (button_debug_close, "clicked", accel_group,
                              GDK_Escape, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  g_signal_connect ((gpointer) window_debug, "delete_event",
                    G_CALLBACK (on_window_debug_delete_event),
                    NULL);
  g_signal_connect ((gpointer) entry_debug, "activate",
                    G_CALLBACK (on_entry_debug_activate),
                    NULL);
  g_signal_connect ((gpointer) button_debug_apply, "clicked",
                    G_CALLBACK (on_button_debug_apply_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_debug_close, "clicked",
                    G_CALLBACK (on_button_debug_close_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_debug, window_debug, "window_debug");
  GLADE_HOOKUP_OBJECT (window_debug, vbox22, "vbox22");
  GLADE_HOOKUP_OBJECT (window_debug, label48, "label48");
  GLADE_HOOKUP_OBJECT (window_debug, hbox24, "hbox24");
  GLADE_HOOKUP_OBJECT (window_debug, entry_debug, "entry_debug");
  GLADE_HOOKUP_OBJECT (window_debug, button_debug_apply, "button_debug_apply");
  GLADE_HOOKUP_OBJECT (window_debug, button_debug_close, "button_debug_close");

  gtk_window_add_accel_group (GTK_WINDOW (window_debug), accel_group);

  return window_debug;
}

GtkWidget*
create_window_help (void)
{
  GtkWidget *window_help;
  GtkWidget *vbox23;
  GtkWidget *notebook1;
  GtkWidget *vbox24;
  GtkWidget *image12;
  GtkWidget *label_about;
  GtkWidget *label49;
  GtkWidget *scrolledwindow4;
  GtkWidget *treeview_contributors;
  GtkWidget *label_contributors;
  GtkWidget *vbox25;
  GtkWidget *image13;
  GtkWidget *label_help_text1;
  GtkWidget *label_help_text2;
  GtkWidget *label51;
  GtkWidget *button_help_close;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  window_help = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_help), 5);
  gtk_window_set_position (GTK_WINDOW (window_help), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (window_help), TRUE);
  gtk_window_set_default_size (GTK_WINDOW (window_help), 400, 400);

  vbox23 = gtk_vbox_new (FALSE, 3);
  gtk_widget_show (vbox23);
  gtk_container_add (GTK_CONTAINER (window_help), vbox23);

  notebook1 = gtk_notebook_new ();
  gtk_widget_show (notebook1);
  gtk_box_pack_start (GTK_BOX (vbox23), notebook1, TRUE, TRUE, 0);

  vbox24 = gtk_vbox_new (FALSE, 5);
  gtk_widget_show (vbox24);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox24);
  gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook1), vbox24,
                                      FALSE, FALSE, GTK_PACK_START);

  image12 = create_pixmap (window_help, "bygfoot_splash2.png");
  gtk_widget_show (image12);
  gtk_box_pack_start (GTK_BOX (vbox24), image12, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (image12), 0, 5);

  label_about = gtk_label_new ("");
  gtk_widget_show (label_about);
  gtk_box_pack_start (GTK_BOX (vbox24), label_about, FALSE, FALSE, 0);
  GTK_WIDGET_SET_FLAGS (label_about, GTK_CAN_FOCUS);
  gtk_label_set_use_markup (GTK_LABEL (label_about), TRUE);
  gtk_label_set_justify (GTK_LABEL (label_about), GTK_JUSTIFY_CENTER);
  gtk_label_set_selectable (GTK_LABEL (label_about), TRUE);

  label49 = gtk_label_new (_("About"));
  gtk_widget_show (label49);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), label49);

  scrolledwindow4 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow4);
  gtk_container_add (GTK_CONTAINER (notebook1), scrolledwindow4);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow4), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow4), GTK_SHADOW_IN);

  treeview_contributors = gtk_tree_view_new ();
  gtk_widget_show (treeview_contributors);
  gtk_container_add (GTK_CONTAINER (scrolledwindow4), treeview_contributors);

  label_contributors = gtk_label_new (_("Contributors"));
  gtk_widget_show (label_contributors);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 1), label_contributors);

  vbox25 = gtk_vbox_new (FALSE, 3);
  gtk_widget_show (vbox25);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox25);
  gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (notebook1), vbox25,
                                      FALSE, FALSE, GTK_PACK_START);

  image13 = gtk_image_new_from_stock ("gtk-help", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image13);
  gtk_box_pack_start (GTK_BOX (vbox25), image13, FALSE, FALSE, 0);

  label_help_text1 = gtk_label_new ("");
  gtk_widget_show (label_help_text1);
  gtk_box_pack_start (GTK_BOX (vbox25), label_help_text1, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_help_text1), TRUE);

  label_help_text2 = gtk_label_new ("");
  gtk_widget_show (label_help_text2);
  gtk_box_pack_start (GTK_BOX (vbox25), label_help_text2, FALSE, FALSE, 0);
  GTK_WIDGET_SET_FLAGS (label_help_text2, GTK_CAN_FOCUS);
  gtk_label_set_line_wrap (GTK_LABEL (label_help_text2), TRUE);
  gtk_label_set_selectable (GTK_LABEL (label_help_text2), TRUE);

  label51 = gtk_label_new (_("Help"));
  gtk_widget_show (label51);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 2), label51);

  button_help_close = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (button_help_close);
  gtk_box_pack_start (GTK_BOX (vbox23), button_help_close, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_help_close, _("Esc"), NULL);
  gtk_widget_add_accelerator (button_help_close, "clicked", accel_group,
                              GDK_Escape, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  g_signal_connect ((gpointer) window_help, "delete_event",
                    G_CALLBACK (on_window_help_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_help_close, "clicked",
                    G_CALLBACK (on_button_help_close_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_help, window_help, "window_help");
  GLADE_HOOKUP_OBJECT (window_help, vbox23, "vbox23");
  GLADE_HOOKUP_OBJECT (window_help, notebook1, "notebook1");
  GLADE_HOOKUP_OBJECT (window_help, vbox24, "vbox24");
  GLADE_HOOKUP_OBJECT (window_help, image12, "image12");
  GLADE_HOOKUP_OBJECT (window_help, label_about, "label_about");
  GLADE_HOOKUP_OBJECT (window_help, label49, "label49");
  GLADE_HOOKUP_OBJECT (window_help, scrolledwindow4, "scrolledwindow4");
  GLADE_HOOKUP_OBJECT (window_help, treeview_contributors, "treeview_contributors");
  GLADE_HOOKUP_OBJECT (window_help, label_contributors, "label_contributors");
  GLADE_HOOKUP_OBJECT (window_help, vbox25, "vbox25");
  GLADE_HOOKUP_OBJECT (window_help, image13, "image13");
  GLADE_HOOKUP_OBJECT (window_help, label_help_text1, "label_help_text1");
  GLADE_HOOKUP_OBJECT (window_help, label_help_text2, "label_help_text2");
  GLADE_HOOKUP_OBJECT (window_help, label51, "label51");
  GLADE_HOOKUP_OBJECT (window_help, button_help_close, "button_help_close");
  GLADE_HOOKUP_OBJECT_NO_REF (window_help, tooltips, "tooltips");

  gtk_window_add_accel_group (GTK_WINDOW (window_help), accel_group);

  return window_help;
}

GtkWidget*
create_window_transfer_dialog (void)
{
  GtkWidget *window_transfer_dialog;
  GtkWidget *vbox26;
  GtkWidget *image14;
  GtkWidget *label_transfer_dialog;
  GtkWidget *hbox25;
  GtkWidget *button_transfer_yes;
  GtkWidget *button_transfer_no;
  GtkWidget *button_transfer_later;
  GtkWidget *alignment8;
  GtkWidget *hbox26;
  GtkWidget *image15;
  GtkWidget *label53;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  window_transfer_dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_transfer_dialog), 5);
  gtk_window_set_position (GTK_WINDOW (window_transfer_dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (window_transfer_dialog), TRUE);

  vbox26 = gtk_vbox_new (FALSE, 5);
  gtk_widget_show (vbox26);
  gtk_container_add (GTK_CONTAINER (window_transfer_dialog), vbox26);

  image14 = gtk_image_new_from_stock ("gtk-dialog-question", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image14);
  gtk_box_pack_start (GTK_BOX (vbox26), image14, FALSE, TRUE, 0);

  label_transfer_dialog = gtk_label_new ("");
  gtk_widget_show (label_transfer_dialog);
  gtk_box_pack_start (GTK_BOX (vbox26), label_transfer_dialog, FALSE, FALSE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_transfer_dialog), TRUE);

  hbox25 = gtk_hbox_new (FALSE, 3);
  gtk_widget_show (hbox25);
  gtk_box_pack_start (GTK_BOX (vbox26), hbox25, FALSE, FALSE, 0);

  button_transfer_yes = gtk_button_new_from_stock ("gtk-yes");
  gtk_widget_show (button_transfer_yes);
  gtk_box_pack_start (GTK_BOX (hbox25), button_transfer_yes, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, button_transfer_yes, _("Return"), NULL);
  gtk_widget_add_accelerator (button_transfer_yes, "clicked", accel_group,
                              GDK_Return, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  button_transfer_no = gtk_button_new_from_stock ("gtk-no");
  gtk_widget_show (button_transfer_no);
  gtk_box_pack_start (GTK_BOX (hbox25), button_transfer_no, TRUE, TRUE, 0);

  button_transfer_later = gtk_button_new ();
  gtk_widget_show (button_transfer_later);
  gtk_box_pack_start (GTK_BOX (hbox25), button_transfer_later, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, button_transfer_later, _("Esc"), NULL);
  gtk_widget_add_accelerator (button_transfer_later, "clicked", accel_group,
                              GDK_Escape, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  alignment8 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment8);
  gtk_container_add (GTK_CONTAINER (button_transfer_later), alignment8);

  hbox26 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox26);
  gtk_container_add (GTK_CONTAINER (alignment8), hbox26);

  image15 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image15);
  gtk_box_pack_start (GTK_BOX (hbox26), image15, FALSE, FALSE, 0);

  label53 = gtk_label_new_with_mnemonic (_("Decide later"));
  gtk_widget_show (label53);
  gtk_box_pack_start (GTK_BOX (hbox26), label53, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) window_transfer_dialog, "delete_event",
                    G_CALLBACK (on_window_transfer_dialog_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_transfer_yes, "clicked",
                    G_CALLBACK (on_button_transfer_yes_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_transfer_no, "clicked",
                    G_CALLBACK (on_button_transfer_no_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_transfer_later, "clicked",
                    G_CALLBACK (on_button_transfer_later_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_transfer_dialog, window_transfer_dialog, "window_transfer_dialog");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, vbox26, "vbox26");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, image14, "image14");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, label_transfer_dialog, "label_transfer_dialog");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, hbox25, "hbox25");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, button_transfer_yes, "button_transfer_yes");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, button_transfer_no, "button_transfer_no");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, button_transfer_later, "button_transfer_later");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, alignment8, "alignment8");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, hbox26, "hbox26");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, image15, "image15");
  GLADE_HOOKUP_OBJECT (window_transfer_dialog, label53, "label53");
  GLADE_HOOKUP_OBJECT_NO_REF (window_transfer_dialog, tooltips, "tooltips");

  gtk_window_add_accel_group (GTK_WINDOW (window_transfer_dialog), accel_group);

  return window_transfer_dialog;
}

GtkWidget*
create_window_mmatches (void)
{
  GtkWidget *window_mmatches;
  GtkWidget *vbox27;
  GtkWidget *hbox27;
  GtkWidget *label54;
  GtkWidget *entry_mm_file;
  GtkWidget *button_mm_file;
  GtkWidget *button_mm_reload;
  GtkWidget *alignment11;
  GtkWidget *hbox31;
  GtkWidget *image18;
  GtkWidget *label58;
  GtkWidget *button_mm_import;
  GtkWidget *alignment15;
  GtkWidget *hbox37;
  GtkWidget *image22;
  GtkWidget *label62;
  GtkWidget *scrolledwindow5;
  GtkWidget *treeview_mmatches;
  GtkWidget *hbox34;
  GtkWidget *button_mm_save_close;
  GtkWidget *alignment13;
  GtkWidget *hbox33;
  GtkWidget *image20;
  GtkWidget *label60;
  GtkWidget *button_mm_reload_close;
  GtkWidget *alignment14;
  GtkWidget *hbox35;
  GtkWidget *image21;
  GtkWidget *label61;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  window_mmatches = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_container_set_border_width (GTK_CONTAINER (window_mmatches), 5);
  gtk_window_set_position (GTK_WINDOW (window_mmatches), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (window_mmatches), TRUE);
  gtk_window_set_default_size (GTK_WINDOW (window_mmatches), 600, 500);

  vbox27 = gtk_vbox_new (FALSE, 3);
  gtk_widget_show (vbox27);
  gtk_container_add (GTK_CONTAINER (window_mmatches), vbox27);

  hbox27 = gtk_hbox_new (FALSE, 3);
  gtk_widget_show (hbox27);
  gtk_box_pack_start (GTK_BOX (vbox27), hbox27, FALSE, TRUE, 0);

  label54 = gtk_label_new (_("Current file"));
  gtk_widget_show (label54);
  gtk_box_pack_start (GTK_BOX (hbox27), label54, FALSE, FALSE, 0);

  entry_mm_file = gtk_entry_new ();
  gtk_widget_show (entry_mm_file);
  gtk_box_pack_start (GTK_BOX (hbox27), entry_mm_file, TRUE, TRUE, 0);

  button_mm_file = gtk_button_new_from_stock ("gtk-open");
  gtk_widget_show (button_mm_file);
  gtk_box_pack_start (GTK_BOX (hbox27), button_mm_file, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_mm_file, _("Open a memorable matches file"), NULL);

  button_mm_reload = gtk_button_new ();
  gtk_widget_show (button_mm_reload);
  gtk_box_pack_start (GTK_BOX (hbox27), button_mm_reload, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_mm_reload, _("Reload matches from file"), NULL);

  alignment11 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment11);
  gtk_container_add (GTK_CONTAINER (button_mm_reload), alignment11);

  hbox31 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox31);
  gtk_container_add (GTK_CONTAINER (alignment11), hbox31);

  image18 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image18);
  gtk_box_pack_start (GTK_BOX (hbox31), image18, FALSE, FALSE, 0);

  label58 = gtk_label_new_with_mnemonic (_("Reload"));
  gtk_widget_show (label58);
  gtk_box_pack_start (GTK_BOX (hbox31), label58, FALSE, FALSE, 0);

  button_mm_import = gtk_button_new ();
  gtk_widget_show (button_mm_import);
  gtk_box_pack_start (GTK_BOX (hbox27), button_mm_import, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_mm_import, _("Import the matches from a memorable matches file"), NULL);

  alignment15 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment15);
  gtk_container_add (GTK_CONTAINER (button_mm_import), alignment15);

  hbox37 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox37);
  gtk_container_add (GTK_CONTAINER (alignment15), hbox37);

  image22 = gtk_image_new_from_stock ("gtk-paste", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image22);
  gtk_box_pack_start (GTK_BOX (hbox37), image22, FALSE, FALSE, 0);

  label62 = gtk_label_new_with_mnemonic (_("Import file"));
  gtk_widget_show (label62);
  gtk_box_pack_start (GTK_BOX (hbox37), label62, FALSE, FALSE, 0);

  scrolledwindow5 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow5);
  gtk_box_pack_start (GTK_BOX (vbox27), scrolledwindow5, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow5), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow5), GTK_SHADOW_IN);

  treeview_mmatches = gtk_tree_view_new ();
  gtk_widget_show (treeview_mmatches);
  gtk_container_add (GTK_CONTAINER (scrolledwindow5), treeview_mmatches);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_mmatches), FALSE);

  hbox34 = gtk_hbox_new (FALSE, 3);
  gtk_widget_show (hbox34);
  gtk_box_pack_start (GTK_BOX (vbox27), hbox34, FALSE, FALSE, 0);

  button_mm_save_close = gtk_button_new ();
  gtk_widget_show (button_mm_save_close);
  gtk_box_pack_start (GTK_BOX (hbox34), button_mm_save_close, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, button_mm_save_close, _("Save changes to file and close"), NULL);

  alignment13 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment13);
  gtk_container_add (GTK_CONTAINER (button_mm_save_close), alignment13);

  hbox33 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox33);
  gtk_container_add (GTK_CONTAINER (alignment13), hbox33);

  image20 = gtk_image_new_from_stock ("gtk-close", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image20);
  gtk_box_pack_start (GTK_BOX (hbox33), image20, FALSE, FALSE, 0);

  label60 = gtk_label_new_with_mnemonic (_("Save and close"));
  gtk_widget_show (label60);
  gtk_box_pack_start (GTK_BOX (hbox33), label60, FALSE, FALSE, 0);

  button_mm_reload_close = gtk_button_new ();
  gtk_widget_show (button_mm_reload_close);
  gtk_box_pack_start (GTK_BOX (hbox34), button_mm_reload_close, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, button_mm_reload_close, _("Reload matches from file and close"), NULL);

  alignment14 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment14);
  gtk_container_add (GTK_CONTAINER (button_mm_reload_close), alignment14);

  hbox35 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox35);
  gtk_container_add (GTK_CONTAINER (alignment14), hbox35);

  image21 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image21);
  gtk_box_pack_start (GTK_BOX (hbox35), image21, FALSE, FALSE, 0);

  label61 = gtk_label_new_with_mnemonic (_("Reload and close"));
  gtk_widget_show (label61);
  gtk_box_pack_start (GTK_BOX (hbox35), label61, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) window_mmatches, "delete_event",
                    G_CALLBACK (on_window_mmatches_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_mm_file, "clicked",
                    G_CALLBACK (on_button_mm_file_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_mm_reload, "clicked",
                    G_CALLBACK (on_button_mm_reload_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_mm_import, "clicked",
                    G_CALLBACK (on_button_mm_import_clicked),
                    NULL);
  g_signal_connect ((gpointer) treeview_mmatches, "button_press_event",
                    G_CALLBACK (on_treeview_mmatches_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) button_mm_save_close, "clicked",
                    G_CALLBACK (on_button_mm_save_close_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_mm_reload_close, "clicked",
                    G_CALLBACK (on_button_mm_reload_close_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window_mmatches, window_mmatches, "window_mmatches");
  GLADE_HOOKUP_OBJECT (window_mmatches, vbox27, "vbox27");
  GLADE_HOOKUP_OBJECT (window_mmatches, hbox27, "hbox27");
  GLADE_HOOKUP_OBJECT (window_mmatches, label54, "label54");
  GLADE_HOOKUP_OBJECT (window_mmatches, entry_mm_file, "entry_mm_file");
  GLADE_HOOKUP_OBJECT (window_mmatches, button_mm_file, "button_mm_file");
  GLADE_HOOKUP_OBJECT (window_mmatches, button_mm_reload, "button_mm_reload");
  GLADE_HOOKUP_OBJECT (window_mmatches, alignment11, "alignment11");
  GLADE_HOOKUP_OBJECT (window_mmatches, hbox31, "hbox31");
  GLADE_HOOKUP_OBJECT (window_mmatches, image18, "image18");
  GLADE_HOOKUP_OBJECT (window_mmatches, label58, "label58");
  GLADE_HOOKUP_OBJECT (window_mmatches, button_mm_import, "button_mm_import");
  GLADE_HOOKUP_OBJECT (window_mmatches, alignment15, "alignment15");
  GLADE_HOOKUP_OBJECT (window_mmatches, hbox37, "hbox37");
  GLADE_HOOKUP_OBJECT (window_mmatches, image22, "image22");
  GLADE_HOOKUP_OBJECT (window_mmatches, label62, "label62");
  GLADE_HOOKUP_OBJECT (window_mmatches, scrolledwindow5, "scrolledwindow5");
  GLADE_HOOKUP_OBJECT (window_mmatches, treeview_mmatches, "treeview_mmatches");
  GLADE_HOOKUP_OBJECT (window_mmatches, hbox34, "hbox34");
  GLADE_HOOKUP_OBJECT (window_mmatches, button_mm_save_close, "button_mm_save_close");
  GLADE_HOOKUP_OBJECT (window_mmatches, alignment13, "alignment13");
  GLADE_HOOKUP_OBJECT (window_mmatches, hbox33, "hbox33");
  GLADE_HOOKUP_OBJECT (window_mmatches, image20, "image20");
  GLADE_HOOKUP_OBJECT (window_mmatches, label60, "label60");
  GLADE_HOOKUP_OBJECT (window_mmatches, button_mm_reload_close, "button_mm_reload_close");
  GLADE_HOOKUP_OBJECT (window_mmatches, alignment14, "alignment14");
  GLADE_HOOKUP_OBJECT (window_mmatches, hbox35, "hbox35");
  GLADE_HOOKUP_OBJECT (window_mmatches, image21, "image21");
  GLADE_HOOKUP_OBJECT (window_mmatches, label61, "label61");
  GLADE_HOOKUP_OBJECT_NO_REF (window_mmatches, tooltips, "tooltips");

  return window_mmatches;
}

