/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

GtkWidget* create_window_job_offer (void);
GtkWidget* create_window_progress (void);
GtkWidget* create_window_warning (void);
GtkWidget* create_window_digits (void);
GtkWidget* create_window_yesno (void);
GtkWidget* create_window_contract (void);
GtkWidget* create_window_user_management (void);
GtkWidget* create_window_debug (void);
GtkWidget* create_window_help (void);
GtkWidget* create_window_transfer_dialog (void);
GtkWidget* create_window_mmatches (void);
