/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

GtkWidget* create_window_bets (void);
GtkWidget* create_window_splash (void);
GtkWidget* create_window_alr (void);
GtkWidget* create_window_news (void);
