#include <gtk/gtk.h>



gboolean
on_window_league_table_delete_event    (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_lt_b_ok_clicked                     (GtkButton       *button,
                                        gpointer         user_data);
